@@ -6,21 +6,23 @@
 #ifndef GEMMI_MONLIB_HPP_
 #define GEMMI_MONLIB_HPP_
 
-#include <cassert>
 #include <cctype>  // for tolower
 #include <map>
 #include <string>
 #include <vector>
+#include "calculate.hpp"  // for calculate_chiral_volume
 #include "cifdoc.hpp"
-#include "elem.hpp"  // for Element
-#include "numb.hpp"  // for as_number
-#include "util.hpp"  // for fail
-#include "model.hpp" // for Residue, Atom
-#include "chemcomp.hpp" // for ChemComp
-#include "resinfo.hpp" // for ResidueInfo
+#include "elem.hpp"       // for Element
+#include "numb.hpp"       // for as_number
+#include "fail.hpp"       // for fail, unreachable
+#include "model.hpp"      // for Residue, Atom
+#include "chemcomp.hpp"   // for ChemComp
+#include "resinfo.hpp"    // for ResidueInfo
 
 namespace gemmi {
 
+typedef cif::Document (*read_cif_func)(const std::string&);
+
 inline void add_distinct_altlocs(const Residue& res, std::string& altlocs) {
   for (const Atom& atom : res.atoms)
     if (atom.altloc && altlocs.find(atom.altloc) == std::string::npos)
@@ -39,8 +41,9 @@ struct ChemLink {
     std::string mod;
     Group group;
     bool matches_group(Group res) const {
-      return res == group ||
-             (group == Group::Peptide && (int) res <= (int) Group::MPeptide);
+      return group != Group::Null &&
+             (res == group ||
+              (group == Group::Peptide && (int) res <= (int) Group::MPeptide));
     }
     int specificity() const {
       if (!comp.empty())
@@ -61,6 +64,7 @@ struct ChemLink {
         ++cstr;
       switch (ialpha4_id(cstr)) {
         case ialpha4_id("pept"): return Group::Peptide;
+        case ialpha4_id("l-pe"): return Group::Peptide;
         case ialpha4_id("p-pe"): return Group::PPeptide;
         case ialpha4_id("m-pe"): return Group::MPeptide;
         case ialpha4_id("pyra"): return Group::Pyranose;
@@ -98,6 +102,40 @@ struct ChemLink {
     }
     unreachable();
   }
+
+  // If multiple ChemLinks match a bond, the scores can pick the best match.
+  int calculate_score(const Residue& res1, const Residue* res2,
+                      char alt) const {
+    int link_score = side1.specificity() + side2.specificity();
+    // check chirality
+    for (const Restraints::Chirality& chirality : rt.chirs)
+      if (chirality.sign != ChiralityType::Both) {
+        const Atom* a1 = chirality.id_ctr.get_from(res1, res2, alt);
+        const Atom* a2 = chirality.id1.get_from(res1, res2, alt);
+        const Atom* a3 = chirality.id2.get_from(res1, res2, alt);
+        const Atom* a4 = chirality.id3.get_from(res1, res2, alt);
+        if (a1 && a2 && a3 && a4) {
+          double vol = calculate_chiral_volume(a1->pos, a2->pos,
+                                               a3->pos, a4->pos);
+          if (chirality.is_wrong(vol))
+            link_score -= 10;
+        }
+      }
+    // check fixed torsion angle (_chem_link_tor.period == 0)
+    for (const Restraints::Torsion& tor : rt.torsions)
+      if (tor.period == 0) {
+        const Atom* a1 = tor.id1.get_from(res1, res2, alt);
+        const Atom* a2 = tor.id2.get_from(res1, res2, alt);
+        const Atom* a3 = tor.id3.get_from(res1, res2, alt);
+        const Atom* a4 = tor.id4.get_from(res1, res2, alt);
+        double z = 10.;
+        if (a1 && a2 && a3 && a4)
+          z = angle_z(calculate_dihedral(a1->pos, a2->pos, a3->pos, a4->pos),
+                      tor);
+        link_score -= (int) z;
+      }
+    return link_score;
+  }
 };
 
 struct ChemMod {
@@ -117,7 +155,7 @@ struct ChemMod {
   std::vector<AtomMod> atom_mods;
   Restraints rt;
 
-  void apply_to(ChemComp& cc) const;
+  void apply_to(ChemComp& chemcomp) const;
 };
 
 
@@ -134,7 +172,8 @@ inline Restraints read_link_restraints(const cif::Block& block_) {
                               "value_dist", "value_dist_esd"}))
     rt.bonds.push_back({read_aid(row, 0), read_aid(row, 2),
                         bond_type_from_string(row[4]), false,
-                        cif::as_number(row[5]), cif::as_number(row[6])});
+                        cif::as_number(row[5]), cif::as_number(row[6]),
+                        NAN, NAN});
   for (auto row : block.find("_chem_link_angle.",
                              {"atom_1_comp_id", "atom_id_1",
                               "atom_2_comp_id", "atom_id_2",
@@ -184,6 +223,7 @@ inline ResidueInfo::Kind chemcomp_group_to_kind(const std::string& group) {
     switch (ialpha4_id(str)) {
       case ialpha4_id("non-"): return ResidueInfo::ELS;
       case ialpha4_id("pept"): return ResidueInfo::AA;
+      case ialpha4_id("l-pe"): return ResidueInfo::AA;
       case ialpha4_id("p-pe"): return ResidueInfo::PAA;
       case ialpha4_id("m-pe"): return ResidueInfo::MAA;
       case ialpha4_id("dna"): return ResidueInfo::DNA;
@@ -195,9 +235,9 @@ inline ResidueInfo::Kind chemcomp_group_to_kind(const std::string& group) {
 }
 
 template<typename T>
-void insert_comp_list(cif::Document& doc, T& ri_map) {
-  if (cif::Block* list_block = doc.find_block("comp_list")) {
-    for (auto row : list_block->find("_chem_comp.",
+void insert_comp_list(const cif::Document& doc, T& ri_map) {
+  if (const cif::Block* list_block = doc.find_block("comp_list")) {
+    for (auto row : const_cast<cif::Block*>(list_block)->find("_chem_comp.",
                                 {"id", "group", "?number_atoms_nh"})) {
       ResidueInfo ri;
       ri.kind = chemcomp_group_to_kind(row[1]);
@@ -208,7 +248,7 @@ void insert_comp_list(cif::Document& doc, T& ri_map) {
   }
 }
 
-inline void insert_chemlinks(cif::Document& doc,
+inline void insert_chemlinks(const cif::Document& doc,
                              std::map<std::string,ChemLink>& links) {
   if (const cif::Block* list_block = doc.find_block("link_list")) {
     for (auto row : const_cast<cif::Block*>(list_block)->find("_chem_link.",
@@ -226,7 +266,7 @@ inline void insert_chemlinks(cif::Document& doc,
       link.side2.group = ChemLink::read_group(row[7]);
       const cif::Block* block = doc.find_block("link_" + link.id);
       if (!block)
-        fail("inconsisted data_link_list");
+        fail("inconsistent data_link_list");
       link.rt = read_link_restraints(*block);
       links.emplace(link.id, link);
     }
@@ -247,10 +287,13 @@ inline Restraints read_restraint_modifications(const cif::Block& block_) {
   for (auto row : block.find("_chem_mod_bond.",
                              {"function", "atom_id_1", "atom_id_2",
                               "new_type",
-                              "new_value_dist", "new_value_dist_esd"}))
+                              "new_value_dist", "new_value_dist_esd",
+                              "?new_value_dist_nucleus", "?new_value_dist_nucleus_esd"}))
     rt.bonds.push_back({{chem_mod_type(row[0]), row.str(1)}, {1, row.str(2)},
                         bond_type_from_string(row[3]), false,
-                        cif::as_number(row[4]), cif::as_number(row[5])});
+                        cif::as_number(row[4]), cif::as_number(row[5]),
+                        row.has(6) ? cif::as_number(row[6]) : NAN,
+                        row.has(7) ? cif::as_number(row[7]) : NAN});
   for (auto row : block.find("_chem_mod_angle.",
                              {"function", "atom_id_1",
                               "atom_id_2", "atom_id_3",
@@ -285,7 +328,7 @@ inline Restraints read_restraint_modifications(const cif::Block& block_) {
   return rt;
 }
 
-inline void insert_chemmods(cif::Document& doc,
+inline void insert_chemmods(const cif::Document& doc,
                             std::map<std::string, ChemMod>& mods) {
   if (const cif::Block* list_block = doc.find_block("mod_list")) {
     for (auto row : const_cast<cif::Block*>(list_block)->find("_chem_mod.",
@@ -297,7 +340,7 @@ inline void insert_chemmods(cif::Document& doc,
       mod.group_id = row.str(3);
       const cif::Block* block = doc.find_block("mod_" + mod.id);
       if (!block)
-        fail("inconsisted data_mod_list");
+        fail("inconsistent data_mod_list");
       for (auto ra : const_cast<cif::Block*>(block)->find("_chem_mod_atom.",
                                   {"function", "atom_id", "new_atom_id",
                                    "new_type_symbol", "new_type_energy",
@@ -312,26 +355,13 @@ inline void insert_chemmods(cif::Document& doc,
   }
 }
 
-namespace impl {
-template <typename T>
-T& add_or_set(std::vector<T>& items, typename std::vector<T>::iterator it,
-              const T& x) {
-  if (it == items.end()) {
-    items.push_back(x);
-    return items.back();
-  }
-  *it = x;
-  return *it;
-}
-} // namespace impl
-
 inline void ChemMod::apply_to(ChemComp& chemcomp) const {
   // _chem_mod_atom
   for (const AtomMod& mod : atom_mods) {
     auto it = chemcomp.find_atom(mod.old_id);
     switch (mod.func) {
       case 'a':
-        if (chemcomp.find_atom(mod.new_id) == chemcomp.atoms.end())
+        if (!chemcomp.has_atom(mod.new_id))
           chemcomp.atoms.push_back({mod.new_id, mod.el,
                                     std::isnan(mod.charge) ? mod.charge : 0,
                                     mod.chem_type});
@@ -383,7 +413,11 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
     auto it = chemcomp.rt.find_bond(mod.id1.atom, mod.id2.atom);
     switch (mod.id1.comp) {
       case 'a':
-        impl::add_or_set(chemcomp.rt.bonds, it, mod).id1.comp = 1;
+        if (it == chemcomp.rt.bonds.end()) {
+          chemcomp.rt.bonds.push_back(mod);
+          // id1.comp was temporarily set to 'a', set it back to 1
+          chemcomp.rt.bonds.back().id1.comp = 1;
+        }
         break;
       case 'd':
         if (it != chemcomp.rt.bonds.end())
@@ -397,6 +431,10 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
             it->value = mod.value;
           if (!std::isnan(mod.esd))
             it->esd = mod.esd;
+          if (!std::isnan(mod.value_nucleus))
+            it->value_nucleus = mod.value_nucleus;
+          if (!std::isnan(mod.esd_nucleus))
+            it->esd_nucleus = mod.esd_nucleus;
         }
         break;
     }
@@ -407,7 +445,10 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
     auto it = chemcomp.rt.find_angle(mod.id1.atom, mod.id2.atom, mod.id3.atom);
     switch (mod.id1.comp) {
       case 'a':
-        impl::add_or_set(chemcomp.rt.angles, it, mod).id1.comp = 1;
+        if (it == chemcomp.rt.angles.end()) {
+          chemcomp.rt.angles.push_back(mod);
+          chemcomp.rt.angles.back().id1.comp = 1;
+        }
         break;
       case 'd':
         if (it != chemcomp.rt.angles.end())
@@ -430,7 +471,10 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
                                        mod.id3.atom, mod.id4.atom);
     switch (mod.id1.comp) {
       case 'a':
-        impl::add_or_set(chemcomp.rt.torsions, it, mod).id1.comp = 1;
+        if (it == chemcomp.rt.torsions.end()) {
+          chemcomp.rt.torsions.push_back(mod);
+          chemcomp.rt.torsions.back().id1.comp = 1;
+        }
         break;
       case 'd':
         if (it != chemcomp.rt.torsions.end())
@@ -457,7 +501,10 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
                                     mod.id2.atom, mod.id3.atom);
     switch (mod.id1.comp) {
       case 'a':
-        impl::add_or_set(chemcomp.rt.chirs, it, mod).id1.comp = 1;
+        if (it == chemcomp.rt.chirs.end()) {
+          chemcomp.rt.chirs.push_back(mod);
+          chemcomp.rt.chirs.back().id1.comp = 1;
+        }
         break;
       case 'd':
         if (it != chemcomp.rt.chirs.end())
@@ -491,7 +538,6 @@ inline void ChemMod::apply_to(ChemComp& chemcomp) const {
     }
 }
 
-
 struct MonLib {
   cif::Document mon_lib_list;
   std::map<std::string, ChemComp> monomers;
@@ -507,24 +553,30 @@ struct MonLib {
     auto modif = modifications.find(name);
     return modif != modifications.end() ? &modif->second : nullptr;
   }
+  const ResidueInfo* find_residue_info(const std::string& name) const {
+    auto resinfo = residue_infos.find(name);
+    return resinfo != residue_infos.end() ? &resinfo->second : nullptr;
+  }
   const ChemLink* match_link(
       const std::string& comp1, const std::string& atom1,
       const std::string& comp2, const std::string& atom2) const {
     for (auto& ml : links) {
       const ChemLink& link = ml.second;
-      if (link.rt.bonds.empty())
-        continue;
-      const Restraints::Bond& bond = link.rt.bonds[0];
-      if (link.side1.comp == comp1 && link.side2.comp == comp2 &&
-          bond.id1.atom == atom1 && bond.id2.atom == atom2)
-        return &link;
+      // for now we don't have link definitions with >1 bonds
+      if (link.rt.bonds.size() == 1) {
+        const Restraints::Bond& bond = link.rt.bonds[0];
+        if (bond.id1.atom == atom1 && bond.id2.atom == atom2 &&
+            link_side_matches_residue(link.side1, comp1) &&
+            link_side_matches_residue(link.side2, comp2))
+          return &link;
+      }
     }
     return nullptr;
   }
 
   void ensure_unique_link_name(std::string& name) const {
     size_t orig_len = name.size();
-    for (int n = 1; find_link(name) != nullptr; ++n)
+    for (int n = 0; find_link(name) != nullptr; ++n)
       name.replace(orig_len, name.size(), std::to_string(n));
   }
 
@@ -540,45 +592,79 @@ struct MonLib {
     for (const cif::Block& block : doc.blocks)
       add_monomer_if_present(block);
   }
+
+  bool link_side_matches_residue(const ChemLink::Side& side,
+                                 const std::string& res_name) const {
+    if (side.comp != "")
+      return side.comp == res_name;
+    const ResidueInfo* resinfo = find_residue_info(res_name);
+    return resinfo && side.matches_group(ChemLink::group_from_residue_info(*resinfo));
+  }
+
+  std::string path(const char* code=nullptr) const {
+    size_t len = mon_lib_list.source.length();
+    // "list/mon_lib_list.cif" has 21 characters
+    if (len < 21)
+      return {};
+    std::string dir = mon_lib_list.source.substr(0, len-21);
+    if (code)
+      dir += relative_monomer_path(code);
+    return dir;
+  }
+
+  static std::string relative_monomer_path(const std::string& code) {
+    std::string path(1, std::tolower(code[0]));
+    path += '/';  // works also on Windows
+    path += code;
+    // On Windows several names are reserved (CON, PRN, AUX, ...), see
+    // https://docs.microsoft.com/en-us/windows/win32/fileio/naming-a-file
+    // The workaround in CCP4 monomer library is to use CON_CON.cif, etc.
+    if (code.size() == 3)
+      switch (ialpha3_id(code.c_str())) {
+        case ialpha3_id("AUX"):
+        case ialpha3_id("COM"):
+        case ialpha3_id("CON"):
+        case ialpha3_id("LPT"):
+        case ialpha3_id("PRN"):
+          path += '_';
+          path += code;
+      }
+    path += ".cif";
+    return path;
+  }
+
+  void read_monomer_cif(const std::string& path, read_cif_func read_cif) {
+    mon_lib_list = (*read_cif)(path);
+    for (const cif::Block& block : mon_lib_list.blocks)
+      add_monomer_if_present(block);
+    insert_chemlinks(mon_lib_list, links);
+    insert_chemmods(mon_lib_list, modifications);
+    insert_comp_list(mon_lib_list, residue_infos);
+  }
 };
 
-typedef cif::Document (*read_cif_func)(const std::string&);
-
-inline MonLib read_monomer_cif(const std::string& path,
-                               read_cif_func read_cif) {
-  MonLib monlib;
-  monlib.mon_lib_list = (*read_cif)(path);
-  for (const cif::Block& block : monlib.mon_lib_list.blocks)
-    monlib.add_monomer_if_present(block);
-  insert_chemlinks(monlib.mon_lib_list, monlib.links);
-  insert_chemmods(monlib.mon_lib_list, monlib.modifications);
-  insert_comp_list(monlib.mon_lib_list, monlib.residue_infos);
-  return monlib;
-}
-
 inline MonLib read_monomer_lib(std::string monomer_dir,
                                const std::vector<std::string>& resnames,
-                               read_cif_func read_cif) {
+                               read_cif_func read_cif,
+                               const std::string& libin="",
+                               bool ignore_missing=false) {
   if (monomer_dir.empty())
     fail("read_monomer_lib: monomer_dir not specified.");
   if (monomer_dir.back() != '/' && monomer_dir.back() != '\\')
     monomer_dir += '/';
-  MonLib monlib = read_monomer_cif(monomer_dir + "list/mon_lib_list.cif",
-                                   read_cif);
+  MonLib monlib;
+  if (!libin.empty())
+    monlib.read_monomer_cif(libin, read_cif);
+  monlib.read_monomer_cif(monomer_dir + "list/mon_lib_list.cif", read_cif);
   std::string error;
   for (const std::string& name : resnames) {
-    std::string path = monomer_dir;
-    path += std::tolower(name[0]);
-    path += '/';
-    path += name + ".cif";
     try {
-      cif::Document doc = (*read_cif)(path);
+      cif::Document doc = (*read_cif)(monomer_dir + MonLib::relative_monomer_path(name));
       auto cc = make_chemcomp_from_cif(name, doc);
-      monlib.monomers.emplace(name, cc);
+      monlib.monomers.emplace(name, std::move(cc));
     } catch(std::runtime_error& err) {
-      error += "The monomer " + name + " could not be read: ";
-      error += err.what();
-      error += ".\n";
+      if (!ignore_missing)
+        error += "The monomer " + name + " could not be read: " + err.what() + ".\n";
     }
   }
   if (!error.empty())
@@ -600,7 +686,7 @@ struct BondIndex {
   std::map<int, std::vector<AtomImage>> index;
 
   BondIndex(const Model& model_) : model(model_) {
-    for (const_CRA& cra : model.all())
+    for (const_CRA cra : model.all())
       if (!index.emplace(cra.atom->serial, std::vector<AtomImage>()).second)
         fail("duplicated serial numbers");
   }
