@@ -1,7 +1,7 @@
 //
 //  =================================================================
 //
-//    20.01.18   <--  Date of Last Modification.
+//    03.06.21   <--  Date of Last Modification.
 //                   ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //  -----------------------------------------------------------------
 //
@@ -12,7 +12,7 @@
 //  **** Classes :  rvapi::Node - API external functions
 //       ~~~~~~~~~
 //
-//  (C) E. Krissinel 2013-2018
+//  (C) E. Krissinel 2013-2021
 //
 //  =================================================================
 //
@@ -30,7 +30,7 @@ extern "C" {
         INITIALISATION
       ==================  */
 
-  /// \brief Initialisation of the report document.  
+  /// \brief Initialisation of the report document.
   /// \param docId  document Id, which must start with a letter and may
   ///               contain both letters and digits. The Id identifies a
   ///               particular report document, and in most cases it is
@@ -71,7 +71,7 @@ extern "C" {
   ///               on RVAPI setup, this may be either a Url to the
   ///               respective web-server, including the path to
   ///                jsrview directory, or a full path to same
-  ///               directory on local file system. Although the HTML 
+  ///               directory on local file system. Although the HTML
   ///               report may be generated in any directory specified
   ///               by  'outDir' parameter, the bootrstrap HTML page
   ///               will have fixed Uri references to  'jsrview'
@@ -153,7 +153,7 @@ extern "C" {
   /// 'fpath'; the restored document may be appended with new data
   /// and saved again if necessary.
   ///  \param fpath path to file to read the report state from. Note
-  ///               that this file must have been created by 
+  ///               that this file must have been created by
   ///               function rvapi_store_document2(), and there is no
   ///               need to intialise the document before using this
   ///               function.
@@ -373,7 +373,7 @@ extern "C" {
                             const int    colSpan
                           );
 
-  void rvapi_add_fieldset1 ( const char * path, // "holderId/fsetId"                           
+  void rvapi_add_fieldset1 ( const char * path, // "holderId/fsetId"
                              const char * title,
                              const int    row,
                              const int    col,
@@ -750,6 +750,29 @@ extern "C" {
                                   const bool   shown
                                 );
 
+  void rvapi_set_bar_options    ( const char * ysetId, // "ysetId"
+                                  const char * pltId,  // plot id
+                                  const char * gdtId,  // data id
+                                  const char * gwdId,  // graph widget id
+                                  const int    barPadding,   // 0 by default
+                                  const int    barMargin,    // 1 by default
+                                  const int    shadowOffset, // 1 by default
+                                  const int    shadowDepth,  // 2 by default
+                                  const double shadowAlpha,  // 0.5 by default
+                                  const int    shadowAngle,  // 135 by default
+                                  const bool   stackSeries   // false by default
+                                );
+
+  void rvapi_set_bar_options1   ( const char * path,   // "gwdId/gdtId/pltId/ysetId"
+                                  const int    barPadding,   // 0 by default
+                                  const int    barMargin,    // 1 by default
+                                  const int    shadowOffset, // 1 by default
+                                  const int    shadowDepth,  // 2 by default
+                                  const double shadowAlpha,  // 0.5 by default
+                                  const int    shadowAngle,  // 135 by default
+                                  const bool   stackSeries   // false by default
+                                );
+
   void rvapi_set_line_fill      ( const char * ysetId, // "ysetId"
                                   const char * pltId,  // plot id
                                   const char * gdtId,  // data id
@@ -1183,7 +1206,7 @@ extern "C" {
   ///        in task file.
   /// Must be used before initialisatin of RVAPI document.
   void rvapi_set_time_quant ( const int quant );
-  
+
   /// \brief Sets the polling flag.
   /// By default, the polling flag is off and client stops polling
   /// the task file after application finishes. Setting the flag on
@@ -1201,12 +1224,12 @@ extern "C" {
         UTILS
       ==========  */
 
-  
+
   /// \brief RVAPI version number.
   /// \param version  buffer to accept a null-terminated version string
   ///                 in form "major.minor.micro", for example, "1.0.2"
   void rvapi_version          ( char * version );
-  
+
   /// \brief Sets maximum size of task file.
   /// \param max_size  maximum size of task file allowed in kilobytes
   ///                  (50KB by default). Excessively large task files
