@@ -9,6 +9,16 @@ echo "";
 echo "";
 echo "################################ Install CCP-EM ################################";
 
+if [[ "$dir" == *" "* ]]; then
+  echo
+  echo "ERROR: there are spaces in the path to the CCP-EM installation directory!"
+  echo
+  echo "This is not supported. Please try to install again in a location without"
+  echo "spaces in the path, or contact ccpem@stfc.ac.uk for assistance."
+  echo
+  exit 1
+fi
+
 ################### confirm CCP-EM licence ###################
 
 if [ -f $HOME/.agree2ccpemv1 ]; then
@@ -46,14 +56,44 @@ sed "s|\(setenv CCPEM \).*|\1$dir|" include/setup_ccpem.csh.in > setup_ccpem.csh
 # the --minimal option is for quick testing only
 [ "$1" = "--minimal" ] && exit
 
-echo 'Compiling py-files'
+echo 'Compiling py-files...'
 (CCPEM=$dir $dir/bin/ccpem-python -Wignore -m compileall \
  $dir/lib/py2 $dir/lib/python2.7 >/dev/null)
 
 
+# Clear extended file attributes to avoid OS X Gatekeeper problems
+if [ "$(uname)" = "Darwin" ]; then
+  echo "Clearing extended file attributes..."
+  xattr -rc . >/dev/null 2>&1
+fi
+
+# Check for libfontconfig / libfreetype library dependency problems
+# If found, try moving libfreetype files and see if that fixes it
+if [ "$(uname)" = "Linux" ]; then
+#  echo "Checking for common library problems..."
+  if ! $dir/bin/ccpem-python -c "import PyQt4.QtGui" >/dev/null 2>&1; then
+#    echo "Problem found. Trying to fix..."
+    moved_dir=$dir/lib/moved
+    mkdir -p $moved_dir
+    mv $dir/lib/libfreetype.so.* $moved_dir
+    if ! $dir/bin/ccpem-python -c "import PyQt4.QtGui" >/dev/null 2>&1; then
+      echo
+      echo "ERROR: cannot load PyQt GUI libraries. Please see"
+      echo "https://www.ccpem.ac.uk/user_help/known_issues.php"
+      echo "or contact ccpem@stfc.ac.uk for assistance."
+      echo
+      mv $moved_dir/libfreetype.so.* $dir/lib
+#    else
+#      echo "Fixed."
+    fi
+#  else
+#    echo "No problems found."
+  fi
+fi
+
 ################### checks for common problems ###################
 
-if ! $dir/bin/ccpem-python -c "import numpy" >/dev/null; then
+if ! $dir/bin/ccpem-python -c "import numpy" >/dev/null 2>&1; then
     echo
     echo "ERROR: starting an example CCP-EM program failed !!!"
     echo "Please check you downloaded the version for your operating system,"
@@ -62,7 +102,7 @@ if ! $dir/bin/ccpem-python -c "import numpy" >/dev/null; then
 fi
 
 # Try and find CCP4 if on Mac
-for ccp4_ver in 7.1 7.0; do
+for ccp4_ver in 8.0 7.1 7.0; do
   MAC_CCP4=/Applications/ccp4-${ccp4_ver}/bin/ccp4.setup-sh
   if [[ -e $MAC_CCP4 ]]; then
     source $MAC_CCP4
@@ -94,13 +134,13 @@ else
         ccp4_maj=${ccp4_majmin%.*}  # bash substring removal: keep everything before the '.'
         ccp4_min=${ccp4_majmin#*.}  # bash substring removal: keep everything after the '.'
         ccp4_patch=${ccp4_version##*.}  # bash substring removal: keep only the text after the last '.'
-        if [[ "$ccp4_maj" != "7" ]]; then
+        if [[ "$ccp4_maj" -lt 7 ]]; then
             echo
             echo "  Your CCP4 installation (version ${ccp4_version}) is not supported."
-            echo "  This version of CCP-EM only works with CCP4 version 7."
+            echo "  This version of CCP-EM requires CCP4 version 7.0 or newer."
             echo
         # Test patch version numerically in base 10 (to avoid interpretation as octal literal)
-        elif [[ "$ccp4_min" == "0" && "10#$ccp4_patch" -lt 72 ]]; then
+        elif [[ "$ccp4_majmin" == "7.0" && "10#$ccp4_patch" -lt 72 ]]; then
             echo
             echo "  Your CCP4 installation (version ${ccp4_version}) appears to be out of date."
             echo "  We recommend using version 7.0.072 or later for best results."
@@ -128,9 +168,10 @@ if [ "$(uname)" = "Darwin" ]; then
         else
             xq_majmin=${xq_version%.*}  # bash substring removal: keep up to the last '.'
             xq_patch=${xq_version##*.}  # bash substring removal: keep only from the last '.' onwards
-            if [[ "$xq_majmin" != "2.7" || "10#$xq_patch" -lt 11 ]]; then
+            if [[ "$xq_majmin" != "2.8" && "$xq_majmin" != "2.7" \
+                  || "$xq_majmin" = "2.7" && "10#$xq_patch" -lt 11 ]]; then
                 echo
-                echo "  Warning: XQuartz version is too old!"
+                echo "  Warning: XQuartz version is too old or not recognised"
                 echo
                 echo "  Your XQuartz version (version ${xq_version}) is out of date and might cause"
                 echo "  some graphical CCP-EM programs to fail."
@@ -144,10 +185,13 @@ if [ "$(uname)" = "Darwin" ]; then
 fi
 
 echo
-echo "         Before running CCPEM programs from command line,"
+echo "Before running CCPEM programs from command line,"
 echo "         source setup_ccpem.sh"
 echo "         (or setup_ccpem.csh if you use csh)."
 echo
+echo "To install Strudel, please run"
+echo "     install_strudel.sh"
+echo
 
 ################### Install Modeller ###################
 # Only required for linux; modeller found automatically on mac
