@@ -1,5 +1,5 @@
 '''
-USE THIS SCRIPT TO GENERATE LOCAL CROSS CORRELATION SCORES
+USE THIS SCRIPT TO GENERATE LOCAL MANDERS' OVERLAP COEFFICIENT SCORES
 E.g. : Initial and output models from FLEX_EM refinement can be scored against the target map.
 OUTPUTS local scores and PDB with B-factor records replaced with SMOC scores (CAN BE COLORED IN CHIMERA)
 NOTE: that for models with both protein and nucleic acids, the range of local cross correlation values differs for protein and nucleic acid contents and their scores need to be analysed separately.
@@ -32,8 +32,8 @@ print 'use --help for help'
 print '-m [map] for input map'
 print '-p [pdb] for input pdb'
 print '-r [resolution]'
-print '-w [residue window length], length of overlapping residue window used for scoring'
-print '--sf [sigma factor], determines the width of the Gaussian used to describe each atom (default 0.187; other values 0.225,0.356,0.425)'
+#print '-w [residue window length], length of overlapping residue window used for scoring'
+#print '--sf [sigma factor], determines the width of the Gaussian used to describe each atom (default 0.187; other values 0.225,0.356,0.425)'
 print '\n\n###################################'
 #labels for the models [if there are multiple models], fill this if you need customized labels
 list_labels = []
@@ -58,6 +58,7 @@ pdir = tp.args.pdir
 mdir = tp.args.mdir
 plist = tp.args.plist
 mlist = tp.args.mlist
+smlist = tp.args.smlist
 rlist = tp.args.rlist
 rigid_out = tp.args.rigidout
 rigid_out_prefix = 'rigid'
@@ -223,6 +224,15 @@ def get_neigh_residues(list_ca_coord_low,list_ca_coord,seqres,dist=5.0):
     list_flex.sort()
     return list_flex
 
+def compare_tuple(tuple1,tuple2):
+    for val1, val2 in zip(tuple1, tuple2):
+        if type(val2) is float:
+            if round(val1,2) != round(val2,2):
+                return False
+        else:
+            if val1 != val2:
+                return False
+    return True
 
 intermed_file = ""
 slow = 0.50
@@ -235,37 +245,58 @@ if rigidbody_file is not None: rfilepath = os.path.abspath(rigidbody_file)
 blurrer = StructureBlurrer()
 sc = ScoringFunctions()
 fragment_window = True
-if tp.args.dist is not None:
+if tp.args.dist:
     fragment_window = False
-    dist = tp.args.dist
+    score_by_dist = tp.args.dist
+else:
+    score_by_dist = False
 print list_maps
 dict_map_scores = OrderedDict()
 m_count = 0
 dict_str_scores = OrderedDict()
 if mrcfile_import:
     from TEMPy.mapprocess import Filter
+
+def read_mapfile(map_path):
+    if mrcfile_import:
+        mrcobj=mrcfile.open(map_path,mode='r')
+        emmap = Filter(mrcobj)
+        emmap.fix_origin()
+        emmap.set_apix_tempy()
+    else:
+        mrcobj=MapParser.readMRC(map_path)
+        emmap = Filter(mrcobj)
+        emmap.fix_origin()
+    return emmap
+
 #if model map is provided
 sim_map = None
 if sm is not None:
-    #read simulated map file
-    if mrcfile_import:
-        map_file = sm
-        mrcobj=mrcfile.open(map_file,mode='r')
-        sim_map = Filter(mrcobj)
-        sim_map.set_apix_tempy()
-    else:
-        sim_map=MapParser.readMRC(map_file)
+    map_file = sm
+    smlist = [sm]
+    #sim_map = read_mapfile(sm)
 
 for map_file in list_maps:
     #read map file
-    if mrcfile_import:
-        mrcobj=mrcfile.open(map_file,mode='r')
-        emmap = Filter(mrcobj)
-        emmap.set_apix_tempy()
-    else:
-        emmap=MapParser.readMRC(map_file)
+    emmap = read_mapfile(map_file)
+        
     map_name = os.path.basename(map_file).split('.')[0]
     res_map = list_res[m_count]
+
+    if not score_by_dist and tp.args.window is None:
+        if res_map < 2.5:
+            win = 3
+        elif res_map < 3.5:
+            win = 5
+        elif res_map < 5.0:
+            win = 7
+        else: win = 9
+        
+    if m_count == 0 and score_by_dist:
+        print 'Considering voxels by distance'
+    else:
+        print 'Considering voxels by sequence window, size ', win
+
     list_zscores = []
     curdir = os.getcwd()
     rerun_ct=0
@@ -278,6 +309,12 @@ for map_file in list_maps:
     while iter_num > 0:
         dict_chains_scores = OrderedDict()
         out_iter_pdb = list_models[it]
+        if smlist is not None:
+            if len(list_models) == len(smlist):
+                sim_mapfile = smlist[it]
+                if os.path.isfile(sim_mapfile):
+                    sim_map = read_mapfile(sim_mapfile)
+                    print 'Using simulated map: ',sim_mapfile
         model_name = '.'.join(os.path.basename(out_iter_pdb).split('.')[:-1])
         lab  = '_vs_'.join([map_name,model_name])
         if os.path.isfile(out_iter_pdb):
