@@ -394,6 +394,7 @@ class StructureBlurrer:
                 try: dict_chain_CA[currentChain].update(dict_res_CA.copy())
                 except KeyError: dict_chain_CA[currentChain] = dict_res_CA.copy()
                 currentChain = x.chain
+                del dict_res_indices
                 dict_res_indices = {}
             else:
                  #check dict_CA if atom_centre not found for prev res
@@ -455,6 +456,7 @@ class StructureBlurrer:
             try: dict_res_CA[cur_res] = [x.res].extend(ca_coord)
             except AttributeError: 
                     dict_res_CA[cur_res] = [' '].extend(ca_coord)
+        del dict_res_CA, dict_res_indices
         return dict_chain_indices, dict_chain_res,dict_chain_CA, gridtree
     
     #added by aj
@@ -1037,12 +1039,17 @@ class StructureBlurrer:
         #TEMPy class
         if densMap.__class__.__name__ == 'Map':
             if densMap.apix > 1.0:
+                #resample to grid apix 1A
                 x_s = int(densMap.x_size()*densMap.apix)
                 y_s = int(densMap.y_size()*densMap.apix)
                 z_s = int(densMap.z_size()*densMap.apix)
-            else: x_s,y_s,z_s = densMap.x_size(),densMap.y_size(),densMap.z_size()
-            newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap.apix, 'mapname')
-            newMap.apix = (densMap.apix*densMap.x_size())/x_s
+                newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap.apix, 'mapname')
+                newMap.apix = (densMap.apix*densMap.x_size())/x_s
+            else: 
+                #keep the same grid
+                x_s,y_s,z_s = densMap.x_size(),densMap.y_size(),densMap.z_size()
+                newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap.apix, 'mapname')
+                newMap.apix = densMap.apix#(densMap.apix*densMap.x_size())/x_s
             densMap_apix = densMap.apix
         #MapEdit/Filter class
         else:
@@ -1052,28 +1059,36 @@ class StructureBlurrer:
                     x_s = int(densMap.x_size()*densMap_apix)
                     y_s = int(densMap.y_size()*densMap_apix)
                     z_s = int(densMap.z_size()*densMap_apix)
-                else: x_s,y_s,z_s = densMap.x_size(),densMap.y_size(),densMap.z_size()
+                    newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap_apix, 'mapname')
+                    newMap.apix = (densMap_apix*densMap.x_size())/x_s
+                else: 
+                    x_s,y_s,z_s = densMap.x_size(),densMap.y_size(),densMap.z_size()
+                    newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap_apix, 'mapname')
+                    newMap.apix = densMap_apix#(densMap_apix*densMap.x_size())/x_s
             else: 
                 densMap_apix = densMap.apix[0]
                 if densMap.apix[0] > 1.0:
                     x_s = int(densMap.x_size()*densMap.apix[0])
                     y_s = int(densMap.y_size()*densMap.apix[1])
                     z_s = int(densMap.z_size()*densMap.apix[2])
+                    newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap_apix, 'mapname')
+                    newMap.apix = (densMap_apix*densMap.x_size())/x_s
                 else:
                     x_s,y_s,z_s = densMap.x_size(),densMap.y_size(),densMap.z_size()
-            newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap_apix, 'mapname')
-            newMap.apix = (densMap_apix*densMap.x_size())/x_s
+                    newMap = Map(zeros((z_s, y_s, x_s)), densMap.origin, densMap_apix, 'mapname')
+                    newMap.apix = densMap_apix#(densMap_apix*densMap.x_size())/x_s
         ##newMap = densMap.resample_by_box_size([z_s, y_s, x_s])
         ##newMap.fullMap *= 0
-        
+        #apply gaussian filter with sigma based on resolution
         sigma = sigma_coeff*resolution
         sigma = max(1,round(sigma/newMap.apix,0))
         newMap = self.make_atom_overlay_map(newMap, prot)
         gauss_map = gaussian_filter(newMap.fullMap, sigma)
         del newMap.fullMap
         newMap.fullMap = gauss_map
-        newMap = newMap.downsample_map(densMap_apix,grid_shape=densMap.fullMap.shape)
-        del gauss_map
+        if densMap_apix > 1.0:#if grid was resampled before
+            newMap = newMap.downsample_map(densMap_apix,grid_shape=densMap.fullMap.shape)
+            del gauss_map
         if normalise:
             newMap = newMap.normalise()
         newMap.update_header()
