@@ -159,6 +159,9 @@ class MapEdit(object):
             self.origin = self.mrc.header.origin.item()
             self.apix = self.mrc.voxel_size.item()
             self.dim = self.mrc.header.cella.item()
+            self.nxstart = self.mrc.header.nxstart
+            self.nystart = self.mrc.header.nystart
+            self.nzstart = self.mrc.header.nzstart
         elif self.class_name == 'Map':
             self.origin = tuple(self.mrc.origin)
             self.apix = (round(self.mrc.header[10]/self.mrc.header[7],2),
@@ -197,6 +200,9 @@ class MapEdit(object):
                 self.mrc.voxel_size = (
                             self.apix,self.apix,self.apix)
             else: self.mrc.voxel_size = self.apix
+            self.mrc.header.nxstart = self.nxstart
+            self.mrc.header.nystart = self.nystart
+            self.mrc.header.nzstart = self.nzstart
         elif self.class_name == 'Map':
             #origin
             self.mrc.origin[0] = self.origin[0]
@@ -242,7 +248,7 @@ class MapEdit(object):
     #update map header records
     def update_newmap_header(self,newmap):
         """
-        Update newmap header to current values
+        Update newmap (mrcfile obj) header to current values
         """
         if newmap.__class__.__name__ == 'MrcFile':
             #origin
@@ -255,6 +261,10 @@ class MapEdit(object):
             newmap.header.cella.z = self.dim[2]
             #voxel_size
             newmap.voxel_size = self.apix
+            newmap.header.nxstart = self.nxstart
+            newmap.header.nystart = self.nystart
+            newmap.header.nzstart = self.nzstart
+            
         elif newmap.__class__.__name__ == 'Map':
             #origin
             newmap.origin[0] = self.origin[0]
@@ -265,7 +275,7 @@ class MapEdit(object):
     #update map array data
     def update_newmap_data(self,newmap):
         """
-        Update new map data array
+        Update new map (mrcfile) data array
         """
         if newmap.__class__.__name__ == 'MrcFile':
             if str(self.fullMap.dtype) == 'float64':
@@ -277,7 +287,7 @@ class MapEdit(object):
 
     def set_newmap_data_header(self,newmap):
         """
-        Update data and header with current values
+        Update data and header of mrcfile map obj with current values
         """
         self.update_newmap_data(newmap)
         self.update_newmap_header(newmap)
@@ -351,7 +361,7 @@ class MapEdit(object):
     #MODIFY GRID  
     #crop map grid given contour and padding
     def crop_map(self,contour=None,factor_sigma=0.0,ext=None,
-                 inplace=False,nd=3):
+                 inplace=False,nd=3,new_dim=None):
         """
         Crop a map based on a threshold
         Arguments:
@@ -364,64 +374,92 @@ class MapEdit(object):
         """
         ##self.reinitialize_data(inplace)
         #crop based on the give n contour and factor_sigma
-        if not factor_sigma == 0.0: 
-            minval = float(contour) - \
-                    (float(factor_sigma)*self.fullMap.std())
-        else: 
-            minval = float(contour)
-        if ext is None: ext = 10
-        
-        map_data = self.fullMap
-        list_indices = []
-        for i in range(nd):
-            ct1 = 0
-            try:
-                while (np.nanmax(map_data[ct1]) <= minval):
-                    
-                    ct1 += 1
-            except IndexError: pass
-                    
-            ct2 = 0
-            try:
-                while (np.nanmax(map_data[-1-ct2]) <= minval):
-                    ct2 += 1
-            except IndexError: pass
-            #transpose
-            map_data = np.transpose(map_data,(2,0,1))
-            #TODO, substracting 1 is not necessary?
-            list_indices.append([ct1-1,ct2-1])
-        #indices for cropping
-        #z axis
-        zs,ze = max(0,list_indices[0][0]-ext),\
-                min(self.fullMap.shape[0]-list_indices[0][1]+ext,
-                    self.fullMap.shape[0])
-        #x axis
-        xs,xe = max(0,list_indices[1][0]-ext),\
-                min(self.fullMap.shape[2]-list_indices[1][1]+ext,
-                    self.fullMap.shape[2]) 
-        #y axis
-        ys,ye = max(0,list_indices[2][0]-ext),\
-                min(self.fullMap.shape[1]-list_indices[2][1]+ext,
-                    self.fullMap.shape[1])
-        
+        self.fix_origin()
+        if contour is not None:
+            if not factor_sigma == 0.0: 
+                minval = float(contour) - \
+                        (float(factor_sigma)*self.fullMap.std())
+            else: 
+                minval = float(contour)
+            if ext is None: ext = 10
+            
+            map_data = self.fullMap
+            list_indices = []
+            for i in range(nd):
+                ct1 = 0
+                try:
+                    while (np.nanmax(map_data[ct1]) <= minval):
+                        
+                        ct1 += 1
+                except IndexError: pass
+                        
+                ct2 = 0
+                try:
+                    while (np.nanmax(map_data[-1-ct2]) <= minval):
+                        ct2 += 1
+                except IndexError: pass
+                #transpose
+                map_data = np.transpose(map_data,(2,0,1))
+                #TODO, substracting 1 is not necessary?
+                list_indices.append([ct1-1,ct2-1])
+            #indices for cropping
+            #z axis
+            zs,ze = max(0,list_indices[0][0]-ext),\
+                    min(self.fullMap.shape[0]-list_indices[0][1]+ext,
+                        self.fullMap.shape[0])
+            #x axis
+            xs,xe = max(0,list_indices[1][0]-ext),\
+                    min(self.fullMap.shape[2]-list_indices[1][1]+ext,
+                        self.fullMap.shape[2]) 
+            #y axis
+            ys,ye = max(0,list_indices[2][0]-ext),\
+                    min(self.fullMap.shape[1]-list_indices[2][1]+ext,
+                        self.fullMap.shape[1])
+            #delete the reference
+            del map_data
+        elif new_dim is not None:
+            
+            crop_x = int(self.fullMap.shape[2] - new_dim[0])
+            xs = max(0,int(np.ceil(float(crop_x)/2)))
+            xe = min(self.fullMap.shape[2],self.fullMap.shape[2]-int(np.floor(float(crop_x)/2)))
+            
+            crop_y = int(self.fullMap.shape[1] - new_dim[1])
+            ys = max(0,int(np.ceil(float(crop_y)/2)))
+            ye = min(self.fullMap.shape[1],self.fullMap.shape[1]-int(np.floor(float(crop_y)/2)))
+            
+            crop_z = int(self.fullMap.shape[0] - new_dim[2])
+            zs = max(0,int(np.ceil(float(crop_z)/2)))
+            ze = min(self.fullMap.shape[0],self.fullMap.shape[0]-int(np.floor(float(crop_z)/2)))
+            #print xs,xe,ys,ye,zs,ze
+        else: return
         ox = self.origin[0] + xs*self.apix[0]
         oy = self.origin[1] + ys*self.apix[1]
         oz = self.origin[2] + zs*self.apix[2]
-        
+
+#         self.nxstart = int(round(ox/self.apix[0],0))
+#         self.nystart = int(round(ox/self.apix[1],0))
+#         self.nzstart = int(round(ox/self.apix[2],0))
         #cropped data, save a copy to get a contiguous memory block
-        #delete the reference
-        del map_data
+        
         if inplace:
             #new origin
             self.origin = (ox,oy,oz)
             self.fullMap = self.fullMap[zs:ze,ys:ye,xs:xe]
             #set dimensions for new shape
             self.set_dim_apix(self.apix)
+            self.update_header()
         else: 
             newmap = self.copy(deep=False)
             newmap.origin = (ox,oy,oz)
             newmap.fullMap = np.copy(self.fullMap[zs:ze,ys:ye,xs:xe])
             newmap.set_dim_apix(self.apix)
+            newmap.dim = (newmap.fullMap.shape[2] * self.apix[0],
+                          newmap.fullMap.shape[1] * self.apix[1],
+                          newmap.fullMap.shape[0] * self.apix[2])
+            #print newmap.fullMap.shape
+#             newmap.update_header()
+#             newmap.update_data()
+            #print newmap.fullMap.shape, newmap.dim
             return newmap
         #update data and header based on current changes
         ##if inplace: self.set_data_header()
