@@ -6,18 +6,15 @@
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
-
-import sys
 import errno
 import inspect
 import os
 import subprocess
 import platform
-import argparse
 import json
 import re
-import tempfile
-import ccpem_core.gui_ext
+import threading
+
 
 class CCPEMVersion(object):
     def __init__(self):
@@ -39,10 +36,12 @@ class CCPEMVersion(object):
             self.build_time = 'N/A'
             self.name = self.version + '_' + self.git_revision
 
+
 class DictToClass(object):
     def __init__(self, dct):
         self.__dict__.update(dct)
 
+
 def get_home_directory():
     '''
     Return home directory dependent on platform
@@ -72,6 +71,7 @@ def get_home_directory():
 #             ImportError
     return path
 
+
 def check_directory_and_make(directory,
                              verbose=False,
                              auto_suffix=False,
@@ -145,21 +145,26 @@ def atomic_write_json(object, filename, **json_dump_kwargs):
     '''
     # Get the directory for the target file to write
     dir = os.path.dirname(os.path.abspath(filename))
-    # Create a temporary file in that directory
-    temp_file = tempfile.NamedTemporaryFile(suffix='.json', dir=dir, delete=False)
+    if not os.path.exists(dir):
+        os.makedirs(dir)
+    # Create a unique name for the temporary file using the PID and current thread ID
+    pid = os.getpid()
+    thread_id = threading.current_thread().ident
+    temp_name = "{}.tmp{}-{}".format(filename, pid, thread_id)
     try:
-        # Write the JSON to the temporary file, flush it to disk and close it
-        json.dump(object, temp_file.file, **json_dump_kwargs)
-        temp_file.file.flush()
-        os.fsync(temp_file.file.fileno())
-        temp_file.file.close()
+        # Create a temporary file, write the JSON to it and flush to disk
+        with open(temp_name, 'w') as temp_file:
+            # Write the JSON to the temporary file, flush it to disk and close it
+            json.dump(object, temp_file, **json_dump_kwargs)
+            temp_file.flush()
+            os.fsync(temp_file.fileno())
         # Rename the temporary file to the target filename
-        os.rename(temp_file.name, filename)
+        os.rename(temp_name, filename)
     finally:
         try:
             # Unconditionally remove the temporary file, ignoring the error if
             # the file no longer exists
-            os.remove(temp_file.name)
+            os.remove(temp_name)
         except OSError as e:
             if e.errno == errno.ENOENT:
                 pass
@@ -287,7 +292,6 @@ def convert_unicode_to_string(input):
         return input
 
 
-
 def get_git_revision():
     path = os.path.dirname(__file__)
     try:
@@ -326,5 +330,6 @@ def main():
     print version.build_time
     print version.name
 
+
 if __name__ == '__main__':
     main()
