@@ -23,7 +23,7 @@ mrc_ext = 'MRC maps (*.mrc *.mrcs *.map *.ccp4)'
 # Text format
 text_ext = 'Text files (*.txt)'
 # PDB formats
-pdb_ext = 'PDB files (*.pdb *.cif *.ent)'
+pdb_ext = 'PDB files (*.pdb *.ent *.cif *.mmcif)'
 # Ligand CIF library (Refmac)
 lib_ext = 'Ligand files (*.cif *.lib)'
 
