@@ -263,11 +263,12 @@ class MetaDataTable(DataFrame):
                     pass
         pyrvapi.rvapi_flush()
 
-    def set_pyrvapi_graph(self, graph_id, data_id, plot_id_list=None, originalXAxis=False, step=1, ymin = None):
+    def set_pyrvapi_graph(self, graph_id, data_id, plot_id_list=None, overlay_plot_id=None, originalXAxis=False, step=1, ymin = None):
         '''
         Put dataframe info into pyrvapi graph.
-            plot_id_list = list of names for plot id.  If len(list) == 1 all
-            fields plotted on same plot rather than individual plots.
+            plot_id_list = list of names for plot id.  If overlay_plot_id 
+            is set fields plotted on same plot rather than individual 
+            plots.
         '''
         # Add graph data
         #
@@ -311,11 +312,14 @@ class MetaDataTable(DataFrame):
         if plot_id_list is None:
             plot_id_list = self.columns
 
-        for n, col in enumerate(self.columns):
-            if len(plot_id_list) == 1:
+        for n, col in enumerate(plot_id_list):
+            if overlay_plot_id is not None:
+                plot_id = overlay_plot_id
+            elif len(plot_id_list) == 1:
                 plot_id = plot_id_list[0]
             else:
                 plot_id = plot_id_list[n]
+
             # Add dataset
             pyrvapi.rvapi_add_graph_dataset(col,
                                             data_id,
@@ -323,36 +327,34 @@ class MetaDataTable(DataFrame):
                                             col,
                                             col)
             # Add data
-            for i in range(len(self)):
-                if self[col][i] != 'NaN':
+            for i in range(self.shape[0]):
+                if self.iloc[i][col] != 'NaN':
                     if np.issubdtype(self[col].dtype, np.int_):
                         pyrvapi.rvapi_add_graph_int(
                             col,
                             data_id,
                             graph_id,
-                            int(self[col][i])) # int(self[col][i])
+                            int(self.iloc[i][col])) # int(self[col][i])
 
                     else:
                         pyrvapi.rvapi_add_graph_real(
                             col,
                             data_id,
                             graph_id,
-                            float(self[col][i]), # float(self[col][i])
+                            float(self.iloc[i][col]), # float(self[col][i])
                             '')
 
-
             # Add plot and line
             pyrvapi.rvapi_add_graph_plot(plot_id,
                                          graph_id,
                                          col,          # graph widget id
                                          str(self.index.name),
-                                         col)
+                                         col)                # yName
             pyrvapi.rvapi_add_plot_line(plot_id,
                                         data_id, 
                                         graph_id,
                                         'index',
-                                        col)
-
+                                        col)                 # ysetID
 
             if ymin is not None:
                 pyrvapi.rvapi_set_plot_ymin(plot_id, graph_id, ymin)
@@ -360,8 +362,14 @@ class MetaDataTable(DataFrame):
             if originalXAxis:
                 pyrvapi.rvapi_reset_plot_xticks(plot_id, graph_id) # Reset first
 
+                # Add blank ticks at the start (and end, below) of the axis to ensure
+                # all points are plotted, otherwise they can escape off the sides of
+                # the graph
+                pyrvapi.rvapi_add_plot_xtick(plot_id, graph_id, -1, ' ')
+
+                # Now add the real ticks
                 for i in range(0, len(self), step):
-                    if self[col][i] != 'NaN':
+                    if self.iloc[i][col] != 'NaN':
                         if np.issubdtype(self.index.dtype, np.int_):
                             pyrvapi.rvapi_add_plot_xtick (
                                 plot_id,
@@ -374,6 +382,9 @@ class MetaDataTable(DataFrame):
                                 graph_id,
                                 float(i),
                                 '%0.1f' % float(self.index[i]))
+
+                # Add a final blank tick for the end of the axis
+                pyrvapi.rvapi_add_plot_xtick(plot_id, graph_id, i + 1, ' ')
         #
         pyrvapi.rvapi_flush()
 
