@@ -37,6 +37,7 @@ Required arguments:
     voxel size [-p]: used for downsample
     mask file [-ma]: used for mask
     x y z [-pad]: used for pad
+    contour [-thr] or x y z [-cr]: used for crop
 
 Dependencies for system python:
     mrcfile
@@ -64,6 +65,8 @@ def set_argparser():
                         default=None)
     parser.add_argument('-pad', '--pad', nargs='+', help='X Y Z padding',
                         default=None)
+    parser.add_argument('-cr', '--cr', nargs='+', help='X Y Z cropped dimensions',
+                        default=None)
     parser.add_argument('-ori', '--ori', nargs='+', help='X Y Z float origin',
                         default=None)
     parser.add_argument('-out', '--out', help='Output map file',
@@ -111,7 +114,8 @@ class MapPreprocess():
                                  map_apix=self.newapix,
                                  plotfile="processed_powspectra.png")
         self.mrcmap.close()
-    
+        #self.processed_map.close()
+        
     def setup_attributes(self,args):
         self.apix=self.mrcmap.apix
         if not args.apix is None:
@@ -137,6 +141,10 @@ class MapPreprocess():
         self.pad_xyz = (0,0,0)
         if not args.pad is None:
             self.pad_xyz = (int(args.pad[0]),int(args.pad[1]),int(args.pad[2]))
+        self.cropped_xyz = args.cr
+        if not args.cr is None:
+            self.cropped_xyz = (int(args.cr[0]),int(args.cr[1]),int(args.cr[2]))
+            print self.cropped_xyz
         #origin
         self.ori = self.mrcmap.origin
         if not args.ori is None:
@@ -189,8 +197,10 @@ class MapPreprocess():
         return maskedmap
     
     def crop(self,mrcmap,inplace=False):
+        
+        if self.cropped_xyz is not None: self.contour = None
         croppedmap = mrcmap.crop_map(contour=self.contour,factor_sigma=0.1,
-                                     inplace=inplace)
+                                     inplace=inplace,new_dim=self.cropped_xyz)
         if inplace: return mrcmap
         return croppedmap
     
