@@ -65,7 +65,7 @@ rigid_out_prefix = 'rigid'
 mode = tp.args.mode
 sm = tp.args.sim_map
 # the sigma factor determines the width of the Gaussian distribution used to describe each atom
-sim_sigma_coeff = 0.187
+sim_sigma_coeff = 0.225
 if not tp.args.sigfac is None:
     sim_sigma_coeff = tp.args.sigfac
 #score window
@@ -234,6 +234,38 @@ def compare_tuple(tuple1,tuple2):
                 return False
     return True
 
+def save_smoc_csv_plot(pdb_id,smoc_chain_scores):
+    plt = Plot()
+    #pdb_id = os.path.splitext(pdb_id)[0]
+    smoc_csv_file = pdb_id+'_smoc.csv'
+    with open(smoc_csv_file,'w') as smocf:
+        for chain in smoc_chain_scores:
+            if len(smoc_chain_scores[chain]) < 5: continue #skip ambiguities
+            list_resnum = []
+            list_score = []
+            dict_points = {}
+            chain_id_edit = chain
+            if chain.islower():
+                chain_id_edit = chain+'_l'
+            chain_score_txt = pdb_id+'_'+chain_id_edit+'.txt'
+            cs = open(chain_score_txt,'w')
+            for resnum in smoc_chain_scores[chain]:
+                smoc_res = [chain]+[str(resnum)] + [str(round(float(
+                                            smoc_chain_scores[chain][resnum]),3))]
+                smocf.write(','.join(smoc_res)+'\n')
+                cs.write(str(resnum)+'\t'+str(round(float(
+                                            smoc_chain_scores[chain][resnum]),3))+'\n')
+                try:
+                    list_resnum.append(int(resnum))
+                    list_score.append(round(float(
+                                            smoc_chain_scores[chain][resnum]),3))
+                except TypeError:
+                    continue
+            dict_points[chain] = [list_resnum,list_score]
+            smoc_plot = pdb_id+'_'+chain_id_edit+'_smocscore.png'
+            plt.lineplot(dict_points,smoc_plot,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0])
+            cs.close()
+            
 intermed_file = ""
 slow = 0.50
 shigh = 0.25 # fraction of structure fitted reasonably well initially
@@ -250,7 +282,7 @@ if tp.args.dist:
     score_by_dist = tp.args.dist
 else:
     score_by_dist = False
-print list_maps
+    
 dict_map_scores = OrderedDict()
 m_count = 0
 dict_str_scores = OrderedDict()
@@ -341,14 +373,14 @@ for map_file in list_maps:
                 sc.SMOC(emmap,res_map,structure_instance=structure_instance,win=win,
                         rigid_body_file=rfilepath,sim_map=sim_map,
                         sigma_map=sim_sigma_coeff,
-                        sigma_thr=2.0,fragment_score=fragment_window,
+                        sigma_thr=2.5,fragment_score=fragment_window,
                         dist=tp.args.dist)
             else:
                 dict_ch_scores,dict_chain_res, dict_chain_CA = \
                 sc.SMOC(emmap,res_map,structure_instance=structure_instance,win=win,
                         rigid_body_file=rfilepath,sim_map=sim_map,
                         sigma_map=sim_sigma_coeff,
-                        sigma_thr=2.0,fragment_score=fragment_window,
+                        sigma_thr=2.5,fragment_score=fragment_window,
                         dist=tp.args.dist, atom_centre='CB')
         
         if rigid_out:
@@ -419,7 +451,10 @@ for map_file in list_maps:
         pdbid = lab
         sc.set_score_as_bfactor(structure_instance,dict_chains_scores,
                                 chid=ch,
-                                outfile=pdbid+"_sc.pdb")
+                                outfile=pdbid+"_smoc.pdb")
+        #save and plot smoc scores
+        save_smoc_csv_plot(pdbid,dict_chains_scores)
+        
         it = it+1
         iter_num = iter_num-1
         #legendlist.append('iter_'+`it`)
@@ -429,61 +464,60 @@ for map_file in list_maps:
     if rigid_out: rigidf.close()
     m_count += 1
 
-list_chains = dict_chains_scores.keys()
-#plot score per chain
-plt = Plot()
-for ch in dict_chains_scores:
-    it = 0
-    dict_points = OrderedDict()
-    flag_chain = 1
-    #check if chain is there in all models
-    for model in dict_str_scores:
-        if not dict_str_scores[model].has_key(ch):
-            flag_chain = 0
-            break 
-    if flag_chain == 0:
-        print 'Chain absent in one of the models: {}'.format(ch) 
-        continue
-    list_models = dict_str_scores.keys()
-    scoreout = "smoc_"+ch+".txt"
-    if len(list_models) == 1:
-        scoreout = list_models[0]+"smoc_"+ch+".txt"
-    
-    sco = open(scoreout,'w')
-    sco.write("Res_num\t"+'\t'.join(list_models)+"\n")
-    
-    mdl_ini = 0  
-    for model in list_models:
-        ch1 = ch
-        if ch == ' ': ch1 = ''
-        labelname = model+'_'+ch1
-        reslist = []
-        scorelist = []
-        for res in dict_reslist[ch]:
-            flag_res = 1
-            list_ressc = []
-            for model1 in list_models:
-                try: 
-                    res_sc = dict_str_scores[model1][ch][res]
-                except KeyError: 
-                    flag_res = 0
-                    break
-            list_ressc.append(res_sc)
-            if flag_res == 0: continue 
-            reslist.append(int(res))
-            scorelist.append(float(dict_str_scores[model][ch][res]))
-            if mdl_ini == 0: sco.write(str(res)+"\t"+'\t'.join(list_ressc)+"\n")
-        if z_score: 
-            npscorelist = np.array(scorelist,dtype='float')
-            zscorelist = (npscorelist-np.mean(npscorelist))/np.std(npscorelist)
-            dict_points[labelname] = [reslist,zscorelist]
-        else: dict_points[labelname] = [reslist,scorelist]
-        it += 1
-        mdl_ini += 1
-    sco.close()
-    outfile = ch+"_smocscoreplot.png"
-    if len(list_models) == 1:
-        outfile = list_models[0]+ch+"_smocscoreplot.png"
-    
-    plt.lineplot(dict_points,outfile,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0]),#legend_loc='upper right')  
-  
+# list_chains = dict_chains_scores.keys()
+# #plot score per chain
+# plt = Plot()
+# for ch in dict_chains_scores:
+#     it = 0
+#     dict_points = OrderedDict()
+#     flag_chain = 1
+#     #check if chain is there in all models
+#     for model in dict_str_scores:
+#         if not dict_str_scores[model].has_key(ch):
+#             flag_chain = 0
+#             break 
+#     if flag_chain == 0:
+#         print 'Chain absent in one of the models: {}'.format(ch) 
+#         continue
+#     list_models = dict_str_scores.keys()
+#     scoreout = "smoc_"+ch+".txt"
+#     if len(list_models) == 1:
+#         scoreout = list_models[0]+"smoc_"+ch+".txt"
+#     
+#     sco = open(scoreout,'w')
+#     sco.write("Res_num\t"+'\t'.join(list_models)+"\n")
+#     
+#     mdl_ini = 0  
+#     for model in list_models:
+#         ch1 = ch
+#         if ch == ' ': ch1 = ''
+#         labelname = model+'_'+ch1
+#         reslist = []
+#         scorelist = []
+#         for res in dict_reslist[ch]:
+#             flag_res = 1
+#             list_ressc = []
+#             for model1 in list_models:
+#                 try: 
+#                     res_sc = dict_str_scores[model1][ch][res]
+#                 except KeyError: 
+#                     flag_res = 0
+#                     break
+#             list_ressc.append(res_sc)
+#             if flag_res == 0: continue 
+#             reslist.append(int(res))
+#             scorelist.append(float(dict_str_scores[model][ch][res]))
+#             if mdl_ini == 0: sco.write(str(res)+"\t"+'\t'.join(list_ressc)+"\n")
+#         if z_score: 
+#             npscorelist = np.array(scorelist,dtype='float')
+#             zscorelist = (npscorelist-np.mean(npscorelist))/np.std(npscorelist)
+#             dict_points[labelname] = [reslist,zscorelist]
+#         else: dict_points[labelname] = [reslist,scorelist]
+#         it += 1
+#         mdl_ini += 1
+#     sco.close()
+#     outfile = ch+"_smocscoreplot.png"
+#     if len(list_models) == 1:
+#         outfile = list_models[0]+ch+"_smocscoreplot.png"
+#     
+#     plt.lineplot(dict_points,outfile,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0]),#legend_loc='upper right')  
\ No newline at end of file
