@@ -17,8 +17,10 @@ def plot_density_histogram(arr,plotfile='density_histogram.png'):
     assert len(freq) == len(bin_centre)
     
     try:
-        #import matplotlib
+#         import matplotlib
+#         matplotlib.use('agg')
         import matplotlib.pyplot as plt
+        plt.switch_backend('agg')
     except (RuntimeError,ImportError) as e:
         plt = None
         return
