@@ -296,12 +296,9 @@ def run_window_function_including_scaling_mpi(emmap, modmap, mask, wn, apix,
 def write_out_final_volume_window_back_if_required(args, wn, window_bleed_and_pad, LocScaleVol,avg=False,outfile=None,
                                                    emmapobj=None):
 
-    if window_bleed_and_pad:
-        map_shape = [(LocScaleVol.shape[0] - wn), (LocScaleVol.shape[1] - wn), (LocScaleVol.shape[2] - wn)]
-        LocScaleVol = pad_or_crop_volume(LocScaleVol, (map_shape))
-
+    #print LocScaleVol.shape
+    
     LocScaleVol_out = mrcfile.new(outfile,overwrite=True)
-    LocScaleVol_out.set_data(LocScaleVol.astype(np.float32))
     LocScaleVol_out.voxel_size = np.rec.array(( args.apix,  args.apix,  args.apix), dtype=[('x', '<f4'), ('y', '<f4'), ('z', '<f4')])
     
     if not emmapobj is None:
@@ -311,7 +308,19 @@ def write_out_final_volume_window_back_if_required(args, wn, window_bleed_and_pa
         LocScaleVol_out.header.nxstart = emmapobj.header.nxstart
         LocScaleVol_out.header.nystart = emmapobj.header.nystart
         LocScaleVol_out.header.nzstart = emmapobj.header.nzstart
-    else: LocScaleVol_out.header.nxstart, LocScaleVol_out.header.nystart, LocScaleVol_out.header.nzstart = [0,0,0]
+        if window_bleed_and_pad:
+            map_shape = [emmapobj.header.nz, emmapobj.header.ny, emmapobj.header.nx]
+    
+    #print LocScaleVol.shape
+    else: 
+        LocScaleVol_out.header.nxstart, LocScaleVol_out.header.nystart, LocScaleVol_out.header.nzstart = [0,0,0]
+        if window_bleed_and_pad:
+            map_shape = [(LocScaleVol.shape[0] - wn), (LocScaleVol.shape[1] - wn), (LocScaleVol.shape[2] - wn)]
+    LocScaleVol = pad_or_crop_volume(LocScaleVol, (map_shape))
+    
+    #print LocScaleVol.shape
+    
+    LocScaleVol_out.set_data(LocScaleVol.astype(np.float32))
     
     return LocScaleVol_out
 
