@@ -11,7 +11,8 @@
 Objects which should be used as the process API by the rest of the system.
 """
 from .ccpem_pipeline import (CCPEMPipeline,
-                             CCPEMPipelineCustomFinish)
+                             CCPEMPipelineCustomFinish,
+                             CCPEMPipelineCustomRunning)
 from .ccpem_process import (CCPEMProcess,
                             CCPEMProcessCustomFinish)
 from .process_utils import (get_process_status,
