@@ -276,9 +276,14 @@ class CCPEMProcess(object):
         # Command
         c_str = ccpem_utils.print_sub_sub_header(message='Command',
                                                  return_str=True)
-        for arg in self.command:
-            c_str += str(arg)
-            c_str += ' '
+        # Use pipes.quote if available to quote arguments correctly
+        # (for example if they contain spaces or special characters)
+        try:
+            from pipes import quote
+        except ImportError:
+            # If pipes is not available, just use str() instead
+            quote = str
+        c_str += ' '.join(quote(arg) for arg in self.command)
         if self.stdin is not None:
             c_str += ' << eof\n' + self.stdin + '\neof'
         c_str += '\n'
