@@ -16,6 +16,8 @@ import os
 import signal
 import traceback
 
+from ccpem_core import ccpem_utils
+
 
 statuses = ['ready', 'running', 'finished', 'failed']
 
@@ -122,9 +124,7 @@ def set_status(json_filepath, status):
         if status in statuses:
             md = json.load(data_file)
             md['status'] = status
-    jf = open(json_filepath, 'w')
-    json.dump(md, jf)
-    jf.close()
+    ccpem_utils.atomic_write_json(md, json_filepath)
 
 
 def get_process_status(json_filepath):
