@@ -46,6 +46,7 @@ class SetMolprobityResults():
         self.dict_jsonfiles = OrderedDict()
         self.dict_json_cacoord = OrderedDict()
         self.list_chains = []
+        self.model_res = {}
         dict_cootset = {}
         self.add_chain_sections = False
         ct_model = 0
@@ -56,7 +57,13 @@ class SetMolprobityResults():
             #list of residue outliers for each model
             #self.residue_outliers[model_id] = {}
             self.residue_coordinates[model_id] = {}
-        
+            model_info_json = os.path.join(molprocess.location,'model_info.json')
+            with open(model_info_json,'r') as jf:
+                model_info = json.load(jf)
+            resolution = model_info['resolution']
+            if resolution == 0.0:
+                self.model_res[model_id] = 'NA'
+            else: self.model_res[model_id] = resolution
             self.molprobity_cootdata = None
             self.dict_cootfiles[model_id] = os.path.join(
                 molprocess.location,
@@ -133,6 +140,18 @@ class SetMolprobityResults():
             self.add_global_data(table_id,dict_summary,gs,mnum)
             mnum += 1
             #print dict_summary
+        ct_id = 0
+        for modelid in self.model_res:
+            if self.model_res[modelid] == 'NA':
+                issue_line = modelid+": Warning, resolution not found!, \
+                                    using a general reference distribution for percentiles"
+                print_line = "<h3 style='color:orange'>{0}</h3>".format(issue_line)
+                
+            else:
+                issue_line = modelid+": resolution = "+str(self.model_res[modelid])
+                print_line = "<h3 style='color:orange'>{0}</h3>".format(issue_line)
+            pyrvapi.rvapi_add_text(print_line, build_sec, 3+ct_id, 0, 1, 1)
+            ct_id += 1
 
     def set_summary_table(self, tab, section, table_name,gs):
         add_table_to_section(section,table_name)
@@ -196,7 +215,7 @@ class SetMolprobityResults():
                                                          gs.dict_referencerange[statname]))
                     
         pyrvapi.rvapi_flush()
-    
+        
     def set_local_data(self):
         outlier_settings = residue_outlier_settings()
         count_chain = 0
@@ -206,6 +225,7 @@ class SetMolprobityResults():
             #save outlier residues
             mnum = 0
             for mid in self.list_modelids:
+#                 self.residue_outliers['nomap'] = {}
                 if not mid in self.residue_outliers:
                     self.residue_outliers[mid] = {}
                 if not chain in self.residue_outliers[mid]:
@@ -261,6 +281,7 @@ class SetMolprobityResults():
                     elif isinstance(val,str):
                         roundedval = val.strip()
                     outlier.append(roundedval)
+                #print loutlier, outlier
                 if len(outlier) == 0: continue
                 if measure in outlier_settings.data_titles:
                     ct_res += 1
@@ -345,11 +366,15 @@ class SetMolprobityResults():
                         outlier_title_ext = outlier_title
                         flag_pass = 1
                         res_prev = ''
+                        
                         #multiple residues
                         for resdet in resdet_split:
                             #G T   8
                             if measure == 'Backbone torsion suites':
+                                #print residue_details, resdet_split, resdet
+                                if len(resdet.split()) < 3:  continue 
                                 residue_num = str(resdet.split()[2])
+                                
                                 #fix this
                                 try: atom_name = str(resdet.split()[3])
                                 except IndexError: atom_name = ' '
@@ -357,7 +382,7 @@ class SetMolprobityResults():
                                 residue_num = str(resdet.split()[0])
                                 try: atom_name = str(resdet.split()[2])
                                 except IndexError:
-                                    print atom_name
+                                    atom_name = '-'
                             
                             try:
                                 if len(res_prev) > 0 and res_prev != residue_num:
@@ -374,9 +399,11 @@ class SetMolprobityResults():
                             except (KeyError,TypeError) as exc: 
                                 flag_pass = 0
                         if flag_pass == 1:
-                            self.add_outlier_title_for_residues(outlier_title_ext, 
+                            try:
+                                self.add_outlier_title_for_residues(outlier_title_ext, 
                                                                      chain, residue_num,
                                                                      mnum=mnum)
+                            except UnboundLocalError: pass
                     if len(residue_details) == 0: continue
                     list_data.append(residue_details)
             if len(list_data) == 0: continue
