@@ -121,7 +121,8 @@ def add_plot_to_graph(graphwidget_id,data_id,plotname,plotlinename,list_x,list_y
                           OriginalXaxisOrder=False,
                           line_fill=False,
                           line_color=pyrvapi.RVAPI_COLOR_Green,
-                          fill_color=pyrvapi.RVAPI_COLOR_Gold):
+                          fill_color=pyrvapi.RVAPI_COLOR_Gold,
+                          marker_style=pyrvapi.RVAPI_MARKER_filledCircle):
     
     pyrvapi.rvapi_add_graph_dataset1(
                                 graphwidget_id+'/'+data_id+'/x',
@@ -143,7 +144,8 @@ def add_plot_to_graph(graphwidget_id,data_id,plotname,plotlinename,list_x,list_y
                           lnum=lnum,
                           line_color=line_color,
                           line_fill=line_fill,
-                          fill_color=fill_color)
+                          fill_color=fill_color,
+                          marker_style=marker_style)
     if OriginalXaxisOrder:
         set_axis_ticks(graphwidget_id,data_id,plotlinename,
                   list_x,plot_id,xtype)
