@@ -258,9 +258,10 @@ class SetRefmacResults():
         try: plot_filename = '_'.join(pdbid.split('_')[:-1])+'_fsc.png'
         except IndexError: plot_filename = pdbfile+'_fsc.png'
         try:
-            import matplotlib
+            #import matplotlib
             #matplotlib.use('Agg')
             import matplotlib.pyplot as plot
+            plot.switch_backend('agg')
         except ImportError: return
         try: plot.style.use('ggplot')
         except AttributeError: pass
