@@ -36,7 +36,11 @@ class ReduceRun():
         if self.name is None:
             self.name = self.__class__.__name__
         self.pdb_path = pdb_path
-        self.out_path = os.path.join(self.job_location,'reduce_out.pdb')
+        if os.path.splitext(pdb_path)[-1].lower() == '.cif' or \
+            os.path.splitext(pdb_path)[-1].lower() == '.mmcif':
+            self.out_path = os.path.join(self.job_location,'reduce_out.cif')
+        else:
+            self.out_path = os.path.join(self.job_location,'reduce_out.pdb')
         self.set_args()
         #set custom finish
         on_finish_custom = ReduceRunOnFinishCustom()
@@ -272,6 +276,37 @@ class BfactWrapper(object):
             location=self.job_location,
             stdin=None)
 
+class ModelShift(object):
+    '''
+    Set input PDB cell and scale cards to input map.
+    '''
+    def __init__(self,
+                 command,
+                 job_location,
+                 pdb_path,
+                 transvec=None,
+                 name=None):
+        self.job_location = ccpem_utils.get_path_abs(job_location)
+        self.pdb_path = ccpem_utils.get_path_abs(pdb_path)
+        #
+        self.name = name
+        if self.name is None:
+            self.name = self.__class__.__name__
+        #
+        self.args = [
+            '--model', self.pdb_path,
+            '--shift_coordinates',
+            '--trans_vec',','.join([str(t) for t in transvec]),
+            '--output_pdb',
+            '--output_cif',
+            '--output_name',os.path.splitext(pdb_path)[0]+'_shifted'
+        ]
+        
+        self.process = process_manager.CCPEMProcess(
+            name=self.name,
+            command=command,
+            args=self.args,
+            location=self.job_location)
 # class mapprocess_wrapper():
 #     '''
 #     Wrapper for TEMPy Map Processing tool.
@@ -347,7 +382,7 @@ class DSSPRun():
         if self.name is None:
             self.name = self.__class__.__name__
 
-        self.args = [pdb_path, output_dssp]
+        self.args = ['-i',pdb_path,'-o', output_dssp]
         self.process = process_manager.CCPEMProcess(
             name=self.name,
             command=command,
