@@ -24,6 +24,7 @@ from collections import OrderedDict
 from pyrvapi_utils import *
 from smoc.set_smoc_results import SetSMOCResults, SetSCCCResults
 from molprobity.set_molprobity_results import SetMolprobityResults
+from pi_score.set_piscore_results import SetPIscoreResults
 from cablam.set_cablam_results import SetCaBLAMResults
 from refmac.set_refmac_results import SetRefmacResults
 from global_scores.set_scores_results import SetScoresResults
@@ -80,15 +81,27 @@ class PipelineResultsViewer(object):
         #lists of job processes
         self.bfactor_process = []
         self.molprobity_process = []
+        self.piscore_process = []
         self.cablam_process = []
         self.refmac_process = []
         self.scores_process = []
         self.smoc_process = []
+        self.fdr_process = []
+        self.fsc_process = []
+        self.diffmap_process = []
         self.sccc_process = []
         self.dssp_process = []
         self.jpred_process = []
+        dict_local_processes = {}
+        self.list_jobs = []
         #count job types
         count_total_jobs, dict_num_jobs = self.count_job_types()
+        #print count_total_jobs
+        num_local_process_complete = 0
+        if 'SMOC' in dict_num_jobs and dict_num_jobs['SMOC'] > 0 : num_local_process_complete += 1
+        if 'FDR' in dict_num_jobs and dict_num_jobs['FDR'] > 0 : num_local_process_complete += 1
+        if 'FSC' in dict_num_jobs and dict_num_jobs['FSC'] > 0 : num_local_process_complete += 1
+        if 'Diffmap' in dict_num_jobs and dict_num_jobs['Diffmap'] > 0 : num_local_process_complete += 1
         #print 'Total number of jobs: ', count_total_jobs, dict_num_jobs
         #set coot script
         cs = SetCootScript(self.pipeline.location)
@@ -103,15 +116,17 @@ class PipelineResultsViewer(object):
         self.residue_coordinates = {}
         #output report for global results
         gr = open('global_report.txt','w')
-            
+        
+        flag_process_complete= 0#local processes
         self.list_failed_jobs = []
         self.list_finished_jobs = []
         self.list_complete = []
         dssp_dict=None
         #set timeout for results
-        timeout = time.time() + 60*60
+        timeout = time.time() + 15*60
         flag_add_tabs = True
         flag_complete = False
+        dict_local_fail = {}
         # get the process that finished and generate results
         while len(self.list_failed_jobs)+len(self.list_finished_jobs) < count_total_jobs:
             if time.time() > timeout: break
@@ -121,10 +136,24 @@ class PipelineResultsViewer(object):
                     status = job.get_status()
                     #skip failed jobs
                     if status not in ['finished','running','ready']: 
-                        if not job.name in self.list_failed_jobs:
+                        if not job.name in self.list_failed_jobs and \
+                            not 'Refmac (masked)' in job.name:
                             self.list_failed_jobs.append(job.name)
+                            if 'SMOC' in job.name:
+                                try: dict_local_fail['SMOC'] += 1
+                                except KeyError:
+                                    dict_local_fail['SMOC'] = 1
+                                if dict_num_jobs['SMOC'] == dict_local_fail['SMOC'] : num_local_process_complete -= 1
+                            if 'FDR' in job.name:
+                                try: dict_local_fail['FDR'] += 1
+                                except KeyError:
+                                    dict_local_fail['FDR'] = 1
+                                if dict_num_jobs['FDR'] == dict_local_fail['FDR'] : num_local_process_complete -= 1
                         print 'Job failed ',job.name
-                        continue
+                        if 'SMOC' in job.name or 'FDR' in job.name:
+                            if flag_process_complete < num_local_process_complete:
+                                continue
+                        else: continue
                     #skip running jobs
                     if status in ['running','ready']:
                         continue
@@ -132,11 +161,13 @@ class PipelineResultsViewer(object):
                     if 'Results' in job.name:
                         continue
                     #add finished jobs to list
-                    if not job.name in self.list_finished_jobs:
+                    #print job.name, 'job loop'
+                    if not job.name in self.list_finished_jobs and \
+                        not 'Refmac (masked)' in job.name:
                         self.list_finished_jobs.append(job.name)
                     else: continue
                     time.sleep(2)
-                    #print job.name
+                    
                     if 'Bfactor' in job.name and \
                         'Bfactor' not in self.list_complete:
                         self.bfactor_process.append(job)
@@ -154,6 +185,8 @@ class PipelineResultsViewer(object):
                                                       glob_reportfile=gr)
                             self.update_list_chains(bfa.list_chains)
                             gc.collect()
+                            
+                            
                     if 'Molprobity' in job.name and \
                             'Molprobity' not in self.list_complete:
                         self.molprobity_process.append(job)
@@ -178,7 +211,9 @@ class PipelineResultsViewer(object):
                             gc.collect()
              
                     if 'Refmac' in job.name and \
-                        'Refmac' not in self.list_complete:
+                        'Refmac' not in self.list_complete and\
+                        'Refmac (masked)' not in job.name:
+                        #print job.name, dict_num_jobs['Refmac']
                         self.refmac_process.append(job)
                         flag_complete = self.check_job_set_complete('Refmac',
                                                         dict_num_jobs['Refmac'])
@@ -208,27 +243,55 @@ class PipelineResultsViewer(object):
                                  
                             gc.collect()
                     
-                    if 'SMOC' in job.name and \
-                        'SMOC' not in self.list_complete:
+                    if ('SMOC' in job.name and \
+                        'SMOC' not in self.list_complete) or \
+                        ('FDR' in job.name and \
+                        'FDR' not in self.list_complete):
                         #print job.name, status
-                        self.smoc_process.append(job)
-                        flag_complete = self.check_job_set_complete('SMOC',
+                        
+                        
+                        if 'SMOC' in job.name: 
+                            self.smoc_process.append(job)
+                            flag_complete = self.check_job_set_complete('SMOC',
                                                         dict_num_jobs['SMOC'])
-                        if flag_complete == 1:
+                            #print 'smoc',flag_complete, dict_num_jobs['SMOC']
+                            flag_process_complete += flag_complete
+                            dict_local_processes['smoc'] = self.smoc_process
+                        elif 'FDR' in job.name: 
+                            self.fdr_process.append(job)
+                            flag_complete = self.check_job_set_complete('FDR',
+                                                        dict_num_jobs['FDR'])
+                            #print 'fdr',flag_complete, dict_num_jobs['FDR']
+                            flag_process_complete += flag_complete
+                            dict_local_processes['fdr'] = self.fdr_process
+                        elif 'FSC' in job.name: 
+                            self.fsc_process.append(job)
+                            dict_local_processes['fsc'] = self.fsc_process
+                        elif 'Diffmap' in job.name: 
+                            self.diffmap_process.append(job)
+                            dict_local_processes['diffmap'] = self.diffmap_process
+                        
+                        if flag_process_complete == num_local_process_complete:
                             if flag_add_tabs:
                                 #add tabs
                                 self.add_global_local_tabs()
                                 flag_add_tabs = False
-                            sm = SetSMOCResults(self.smoc_process, 
-                                                self.list_chains,
+                            sm = SetSMOCResults(dict_local_processes = dict_local_processes,
+                                                list_chains=self.list_chains,
                                                 pipeline_location=self.pipeline.location,
                                                 cootset_instance=cs,
                                                 glob_reportfile=gr)
-                            if len(sm.residue_outliers) != 0: 
-                                self.list_summary_methods.append('smoc')
-                                self.residue_outliers['smoc'] = sm.residue_outliers
-                                self.update_coordinates(sm.residue_coordinates)
-                             
+                            for process_name in sm.residue_outliers:
+                                if len(sm.residue_outliers[process_name]) != 0: 
+                                    self.list_summary_methods.append(process_name)
+                                    for mapid in sm.residue_outliers[process_name]:
+                                        if mapid[-1] == '0':#main map
+                                            self.residue_outliers[process_name] = sm.residue_outliers[process_name][mapid]
+                            #print 'update coordinates', time.time()
+                            for mapid in sm.residue_coordinates:
+                                if mapid[-1] == '0':#main map
+                                    self.update_coordinates(sm.residue_coordinates[mapid])
+                            #print 'update chain list', time.time()
                             self.update_list_chains(sm.list_chains)
                                  
                             gc.collect()
@@ -239,6 +302,30 @@ class PipelineResultsViewer(object):
                         #self.smoc_process.append(job)
                         flag_complete = self.check_job_set_complete('SCCC',
                                                         dict_num_jobs['SCCC'])
+                    
+                    if 'PI-score' in job.name and \
+                            'PI-score' not in self.list_complete:
+                        self.piscore_process.append(job)
+                        # all jobs of this type are completed?
+                        flag_complete = self.check_job_set_complete('PI-score',
+                                                        dict_num_jobs['PI-score'])
+                        if flag_complete == 1:
+                            if flag_add_tabs:
+                                #add tabs
+                                self.add_global_local_tabs()
+                                flag_add_tabs = False
+                            p = SetPIscoreResults(self.piscore_process,
+                                                      self.list_chains,
+                                                      cootset_instance=cs,
+                                                      glob_reportfile=gr)
+                            self.update_list_chains(p.list_chains)
+#                             if len(p.residue_outliers) != 0: 
+#                                 self.list_summary_methods.append('piscore')
+#                                 self.residue_outliers['piscore'] = mp.residue_outliers
+#                                 self.update_coordinates(mp.residue_coordinates)
+                            #collect non-ref/deleted items from the object
+                            gc.collect()
+
                     if 'CABLAM' in job.name and \
                             'CABLAM' not in self.list_complete:
                         self.cablam_process.append(job)
@@ -294,20 +381,22 @@ class PipelineResultsViewer(object):
                                 self.update_coordinates(jp.residue_coordinates)
                             gc.collect()
                     pyrvapi.rvapi_flush()
+                    
         gr.flush()
         gr.close()
-        
+        #print self.residue_coordinates
+        #print self.list_complete
         if len(self.list_finished_jobs) == 0 or len(self.list_complete) == 0:
             pyrvapi.rvapi_add_tab( global_tab, "", True)
             pyrvapi.rvapi_add_section("results_section","",global_tab,0,0,1,1,True )
             pyrvapi.rvapi_add_text("Jobs failed", "results_section", 1, 0, 1, 1)
             pyrvapi.rvapi_flush()
         #if no local outliers
-        elif len(self.residue_outliers) == 0:
+        elif len(self.residue_outliers) == 0 and not 'PI-score' in self.list_complete:
             pyrvapi.rvapi_add_section("localresults_section","",local_tab,0,0,1,1,True )
             pyrvapi.rvapi_add_text("No local outliers", "localresults_section", 1, 0, 1, 1)
             pyrvapi.rvapi_flush()
-        else:
+        elif not 'PI-score' in self.list_complete or len(self.list_complete) > 2:
              
             #cluster functions class
             self.cl_out = cluster_residues()
@@ -343,7 +432,7 @@ class PipelineResultsViewer(object):
                     try: dict_num_jobs['Bfactor'] += 1
                     except KeyError:
                         dict_num_jobs['Bfactor'] = 1
-                elif 'Refmac' in job.name:
+                elif 'Refmac' in job.name and 'Refmac (masked)' not in job.name:
                     try: dict_num_jobs['Refmac'] += 1
                     except KeyError:
                         dict_num_jobs['Refmac'] = 1
@@ -355,6 +444,18 @@ class PipelineResultsViewer(object):
                     try: dict_num_jobs['SMOC'] += 1
                     except KeyError:
                         dict_num_jobs['SMOC'] = 1
+                elif 'FDR' in job.name:
+                    try: dict_num_jobs['FDR'] += 1
+                    except KeyError:
+                        dict_num_jobs['FDR'] = 1
+                elif 'FSC' in job.name:
+                    try: dict_num_jobs['FSC'] += 1
+                    except KeyError:
+                        dict_num_jobs['FSC'] = 1
+                elif 'Diffmap' in job.name:
+                    try: dict_num_jobs['Diffmap'] += 1
+                    except KeyError:
+                        dict_num_jobs['Diffmap'] = 1
                 elif 'CABLAM' in job.name:
                     try: dict_num_jobs['CABLAM'] += 1
                     except KeyError:
@@ -367,7 +468,14 @@ class PipelineResultsViewer(object):
                     try: dict_num_jobs['Jpred'] += 1
                     except KeyError:
                         dict_num_jobs['Jpred'] = 1
-                if not 'Results' in job.name: count_total_jobs += 1
+                elif 'PI-score' in job.name:
+                    try: dict_num_jobs['PI-score'] += 1
+                    except KeyError:
+                        dict_num_jobs['PI-score'] = 1
+                if not 'Results' in job.name and not job.name in self.list_jobs \
+                and not 'Refmac (masked)' in job.name: 
+                    count_total_jobs += 1
+                    self.list_jobs.append(job.name)
         return count_total_jobs, dict_num_jobs
 
     def check_job_set_complete(self,job_name, num_jobs):
@@ -432,6 +540,11 @@ class PipelineResultsViewer(object):
             chain_table_flag = False
             #methods
             for met in self.list_summary_methods[1:]:
+#                 for mapid in self.residue_outliers[met]:
+#                     if not mapid in dict_model_outlier: 
+#                             dict_model_outlier[mapid] = {}
+#                     if not mapid in self.dict_cluster_number: 
+#                             self.dict_cluster_number[mapid] = {}
                 for pdbid in self.residue_outliers[met]:
                     if not chain in self.residue_outliers[met][pdbid]: continue
                     if not pdbid in dict_model_outlier: 
@@ -468,7 +581,12 @@ class PipelineResultsViewer(object):
         '''
         list_method_indices = [self.rsumm.data_titles.index(met) for met in self.list_summary_methods]
         
+#         for mapid in dict_model_outlier:
         for pdbid in dict_model_outlier:
+#                 if mapid == 'nomap':
+            tid = pdbid
+#                 else:
+#                     tid = mapid+'_'+pdbid
             dict_outlier = dict_model_outlier[pdbid]
             outlier_res = dict_outlier.keys()
             outlier_res.sort()
@@ -514,7 +632,7 @@ class PipelineResultsViewer(object):
                     data_array.append(dict_outlier[res])
             
             table_id = "summarytable"+chain+pdbid
-            table_name = "Outlier summary table: "+pdbid
+            table_name = "Outlier summary table: "+tid
             list_horz_headers = [self.rsumm.list_horz_headers[index] for index in list_method_indices]
             list_horz_headers = ['Cluster']+list_horz_headers
             list_horz_headers_tips = [self.rsumm.list_horz_header_tooltips[index] for index in list_method_indices]
@@ -625,12 +743,20 @@ class PipelineResultsViewer(object):
                             elif len(self.residue_coordinates[pdbid][chain][resnum]) != 3:
                                 self.residue_coordinates[pdbid][chain][resnum] = res_coordinate
     
+    def merge_coordinates(self):
+        #merge geometry outlier coordinates with map specific outliers
+        for mapid in self.residue_coordinates:
+            if mapid != 'nomap' and 'nomap' in self.residue_coordinates:
+                self.update_coordinates(self.residue_coordinates['nomap'],mapid)
+        if 'nomap' in self.residue_coordinates:
+            del self.residue_coordinates['nomap']
+                                         
     def cluster_outliers(self):
         '''
         Cluster outlier residues based on spatial coordinates
         Uses scipy kdtree
         '''
-        
+        list_res_clusters = []
         self.dict_residue_clusters = {}
         #get outlier residues from residue_outliers dict
 #         for chain in self.list_chains:
@@ -650,7 +776,9 @@ class PipelineResultsViewer(object):
 #                         list_coord.append(self.residue_outliers[met][pdbid][chain][res])
 #                         list_res.append(str(res))
 #                     
-                    
+#         for mapid in self.residue_coordinates:
+#             if not mapid in self.dict_residue_clusters:
+#                     self.dict_residue_clusters[mapid] = {}
         for pdbid in self.residue_coordinates:
             if not pdbid in self.dict_residue_clusters:
                 self.dict_residue_clusters[pdbid] = {}
@@ -661,6 +789,7 @@ class PipelineResultsViewer(object):
                     if str(res) in list_res: continue
                     list_coord.append(self.residue_coordinates[pdbid][chain][res])
                     list_res.append(str(res)) #resid chain
+                #print pdbid, chain, list_res
                 if len(list_coord) > 0:
                     list_res_clusters = self.cl_out.get_cluster_outliers(list_res, list_coord)
                     list_res_clusters.sort(key=len,reverse=True)
@@ -672,6 +801,8 @@ class PipelineResultsViewer(object):
         Save outlier clusters in a dictionary for coot fixing
         '''
         for pdbid in self.dict_residue_clusters:
+#                 cl_id = mapid+':'+pdbid
+#                 if mapid == 'nomap': cl_id = pdbid
             if not pdbid in self.dict_coot_outlier_clusters:
                 self.dict_coot_outlier_clusters[pdbid] = {}
             try:
@@ -709,7 +840,7 @@ class PipelineResultsViewer(object):
                                 continue
                             #add method name to outlier type
                             if self.list_summary_methods[met_index] in \
-                                        ['cablam','smoc','jpred']:
+                                        ['cablam','smoc','fdr','jpred']:
                                 outlier_types[met_index] = \
                                     self.list_summary_methods[met_index] + \
                                     ' '+ outlier_types[met_index]
@@ -733,6 +864,7 @@ class PipelineResultsViewer(object):
                 if flag_cluster: 
                     self.dict_cluster_number[pdbid][0] += 1 #model
                     self.dict_cluster_number[pdbid][1] += 1 #chain
+            #break # compute coot data for the first map based outliers only
 
     def add_cootdata(self):
         '''
@@ -749,8 +881,15 @@ class PipelineResultsViewer(object):
         '''
         dict_df = {}
         for met in self.list_summary_methods[1:]:
+#             for mapid in self.residue_outliers[met]:
+#                 self.residue_outliers[met][mapid] = {}
             for pdbid in self.residue_outliers[met]:
-                if not pdbid in dict_df: dict_df[pdbid] = {}
+#                 if mapid == 'nomap':
+                df_id = pdbid
+#                 else:
+#                     df_id = mapid+':'+pdbid
+                if not df_id in dict_df:
+                    dict_df[df_id] = {}
                 for chain in self.residue_outliers[met][pdbid]:
                     for res in self.residue_outliers[met][pdbid][chain]:
                         outlier_det = self.residue_outliers[met][pdbid][chain][res]
@@ -762,12 +901,12 @@ class PipelineResultsViewer(object):
                         except ValueError: 
                             res_key = res.strip()
                         
-                        try: dict_df[pdbid][(chain,res_key)][met] = outlier_string
+                        try: dict_df[df_id][(chain,res_key)][met] = outlier_string
                         except KeyError:
-                            dict_df[pdbid][(chain,res_key)] = {}
-                            dict_df[pdbid][(chain,res_key)][met] = outlier_string
-        for pdbid in dict_df:
-            self.set_df_csv(dict_df[pdbid], pdbid)
+                            dict_df[df_id][(chain,res_key)] = {}
+                            dict_df[df_id][(chain,res_key)][met] = outlier_string
+        for df_id in dict_df:
+            self.set_df_csv(dict_df[df_id], df_id)
 
     def add_new_residue_outlier_set(self,residue_outliers,dict_outlier,
                                     pdbid,method='molprobity'):
