@@ -55,7 +55,7 @@ class cryoEF_ResultsViewer():
         pyrvapi.rvapi_flush()
         plot_angles = os.path.join(self.pipeline.location,'angles.png')
         if os.path.isfile(plot_angles):
-            pyrvapi.rvapi_add_text("<img src={} alt='' style=width:450px;height:350px;>".format(plot_angles),
+            pyrvapi.rvapi_add_text("<img src='{}' alt='' style=width:450px;height:350px;>".format(plot_angles),
                                    "results_section", 1, 0, 1, 1)
         pyrvapi.rvapi_flush()
         #pyrvapi.rvapi_add_tab( 'cryoEF_recommendations', "cryoEF:recommendations", True)
