@@ -356,11 +356,7 @@ def unet_model_fn(features, labels, mode):
                 maskedScore_tp = tf.boolean_mask(expScore_tp, tf.logical_not(tf.is_nan(expScore_tp)))
                 maskedScore_fp = tf.boolean_mask(expScore_fp, tf.logical_not(tf.is_nan(expScore_fp)))
                 maskedScore_fn = tf.boolean_mask(expScore_fn, tf.logical_not(tf.is_nan(expScore_fn)))
-
-                # XXX Check!
-                print '\n\nThis should be checked for python2.7 version!'
                 eval_metric_ops = {
-                #eval_metric_ops = {**eval_metric_ops,
                     "accuracy/{}_truePositive".format(type):  tf.metrics.mean(maskedScore_tp),
                     "accuracy/{}_falsePositive".format(type): tf.metrics.mean(maskedScore_fp),
                     "accuracy/{}_falseNegative".format(type): tf.metrics.mean(maskedScore_fn),
@@ -392,6 +388,8 @@ def main(argv):
     ################################################################################
     parser = argparse.ArgumentParser(description="HARUSPEX V2019-01-16")
     parser.add_argument('-s', '--steps',    metavar='<STEPS>', default=30000, type=int, action='store', help="Set steps.")
+    parser.add_argument('-n_cpu', '--n_cpu', metavar='<Number cpus>', default=None, type=int, action='store', help="Set number of CPUs.")
+    parser.add_argument('-p_mem', '--p_mem', metavar='<Percentage gpu memory>', default=100, type=float, action='store', help="Set GPU memory fraction.")
     parser.add_argument('-n', '--network',  default=os.path.join(os.path.dirname(sys.argv[0]), str(date.today())), metavar='<PATH>', action='store', help="Set UNET path.")
     parser.add_argument('-p', '--datasrc',  default=None, metavar='<PATH>', action='store', help="Set data path.")
     parser.add_argument('-o', '--output',   default="./", metavar='<PATH>', action='store', help="Output directory for evaluation/listing.")
@@ -401,11 +399,13 @@ def main(argv):
     parser.add_argument('-O', '--original', default=False, const=True,  action='store_const', help="Disable input data augmentation.")
     parser.add_argument('-R', '--reverse',  default=True,  const=False, action='store_const', help="Reverse sorting for secondary structure views.")
     parser.add_argument('-Z', '--no-zoom',  default=False, const=True,  action='store_const', help="Do not rescale voxel size to [1.0; 1.2] Angstrom.")
+    parser.add_argument('-F', '--zoom',     default=True,  const=True,  action='store_const', help="Force rescale voxel size to 1.1 Angstrom.")
     parser.add_argument('-r', '--random',   default=False, const=True,  action='store_const', help="Randomly shuffle views before applying limit.")
     parser.add_argument('-d', '--density',  default=False, const=True,  action='store_const', help="Multiply predictions with density before saving.")
     parser.add_argument('-m', '--nomrc',    default=False, const=True,  action='store_const', help="Do not save mrc output during map-prediction.")
     parser.add_argument('-V', '--vectors',  default=False, const=True,  action='store_const', help="Save slice vectors as .json file.")
-    
+
+
     parser.add_argument('command', type=str, help="Command.")
     parser.add_argument('dataset', type=str, help="For prediction: Source file or list of mrc files. For training: Dataset directory or list.", default=None)
     
@@ -506,8 +506,7 @@ def main(argv):
 
             print("load data...")
             for it, pack in enumerate(viewList):
-                # XXX fix
-#                 print("\r -> loading ({:5}/{}) - {} ... ".format(it+1, len(viewList), pack), end="")
+                print("\r -> loading ({:5}/{}) - {} ... ".format(it+1, len(viewList), pack))
                 sys.stdout.flush()
 
                 sourcePath = os.path.join(args.datasrc, "{}-{}_view-{}_{}_source.npz".format(*pack))
@@ -572,21 +571,22 @@ def main(argv):
         if not os.path.isdir(args.network):
             os.makedirs(args.network)
 
-        # run config
-        print 'TEST CPU Setup'
-        # Includes hyperthreading, keep one core available for other
-        # programs
-        print 'Total CPUs available:', multiprocessing.cpu_count()
-        n_cpu = (multiprocessing.cpu_count() - 1)
-        print 'CPUs to use in Haruspex: ', n_cpu
-
         # Optimise for use as app in CCP-EM
         # See:
         # https://software.intel.com/en-us/articles/tips-to-improve-performance-for-popular-deep-learning-frameworks-on-multi-core-cpus
+        n_cpu = args.n_cpu
+        if n_cpu is None:
+            n_cpu = multiprocessing.cpu_count()
+        print 'CPUs to use in Haruspex: ', n_cpu
+        gpu_memory_fraction = args.p_mem
+        print 'GPU memory fraction : ', gpu_memory_fraction
+        gpu_options = tf.GPUOptions(
+            per_process_gpu_memory_fraction=gpu_memory_fraction)
         proto_config = tf.ConfigProto(
             intra_op_parallelism_threads=n_cpu,
             inter_op_parallelism_threads=2,
             allow_soft_placement=True,
+            gpu_options=gpu_options,
             device_count={'CPU':n_cpu})
         proto_config.gpu_options.allow_growth = True
 
@@ -645,9 +645,7 @@ def main(argv):
                 mrcPool = [args.dataset]
             else:
                 with open(args.dataset, 'r') as lFd:
-                    #FIXME: There is a better way to pass/construct this path
                     mrcPool = [os.path.join(args.datasrc, "EMD-{0}/map/emd_{0}.map".format(x.strip().split('-')[0])) for x in lFd.readlines() if x.strip()[0] != '#']
-
             mrcPool.sort()
 
             for mrcPath in mrcPool:
@@ -678,8 +676,17 @@ def main(argv):
                 oldVoxelSize, oldCellVec = voxelSize, cellVec
                 rescaledFlag = False
                 originalMrcData = mrcData
-                if not args.no_zoom and (np.max(voxelSize) > 1.2 or np.min(voxelSize) < 1.0):
-                    print(" -> VoxelSize {} out of [1.0; 1.2] bounds. Rescaling to 1.1 A/V.".format(voxelSize))
+
+                rescale = False
+                # Force rescale...
+                if args.zoom:
+                    rescale = True
+                # ...or rescale if input map is <1.0 or >1.2 A/V 
+                elif not args.no_zoom and (np.max(voxelSize) > 1.2 or np.min(voxelSize) < 1.0):
+                    rescale = True
+                if rescale:
+                    print("\n\n ->  Rescaling")
+                    print(" -> VoxelSize {}. Rescaling to 1.1 A/V.".format(voxelSize))
                     targetScale = np.asarray([1.1, 1.1, 1.1], dtype=np.float)
                     zoomFactor = np.divide(voxelSize, targetScale)
                     print(" ... previous shape, vector, voxel: {}, {}, {}".format(str(mrcData.shape), str(cellVec), str(voxelSize)))
@@ -701,8 +708,7 @@ def main(argv):
                     ftl = np.minimum(np.multiply(midx, 20), np.subtract(mrcData.shape, 40))
                     bbr = np.add(ftl, 40)
                     
-                    # XXX Fix
-#                     print("\r {} -> {:6}/{} -> {}".format(str(midx), idx, gridSize, str(ftl)), end="")
+                    print("\r {} -> {:6}/{} -> {}".format(str(midx), idx, gridSize, str(ftl)))
                     sourceArray[idx] = mrcData[ftl[0]:bbr[0], ftl[1]:bbr[1], ftl[2]:bbr[2]]
 
                 print("")
@@ -711,24 +717,16 @@ def main(argv):
                 pred_results = annotator.predict(input_fn=eval_input_fn)
 
                 print("Rebuilding annotated mrc maps...")
-#                 annotatedMap = np.zeros((*mrcData.shape, 4), dtype=np.float32)
-                # XXX Fix
                 am_shape = mrcData.shape + (4,)
                 annotatedMap = np.zeros(am_shape, dtype=np.float32)
-            
-                print 'XXX Test'
-                print am_shape
-                print mrcData.shape
                 for i, pmap in enumerate(pred_results):
                     x = i % gridShape[2]
                     y = i // gridShape[2] % gridShape[1]
                     z = i // (gridShape[2] * gridShape[1])
                     ftl = np.minimum(np.add(np.multiply([z,y,x], 20), 10), np.subtract(mrcData.shape, 40)).astype(np.int)
                     bbr = np.add(ftl, 20)
-                    # Fix XXX
-#                     print("\r {:6}/{} -> {}, {}, {}...     ".format(i, gridSize, z,y,x), end="")
+                    print("\r {:6}/{} -> {}, {}, {}...     ".format(i, gridSize, z,y,x))
                     annotatedMap[ftl[0]:bbr[0], ftl[1]:bbr[1], ftl[2]:bbr[2], :] = pmap["probabilities"]
-
                 print("")
 
                 # return to original scaling (same as training data generation!)
