@@ -9,6 +9,7 @@
 
 
 import os
+import shutil
 from loc_scale import np_locscale_fft
 import mrcfile
 from ccpem_core.ccpem_utils import ccpem_argparser
@@ -18,11 +19,10 @@ from ccpem_core.tasks import task_utils
 from ccpem_core.tasks.refmac import refmac_task
 from ccpem_core import settings
 from ccpem_core.tasks.bin_wrappers import mapmask
-from ccpem_core.tasks.bin_wrappers import fft
 from ccpem_core.model_tools.gemmi_utils import shift_coordinates, remove_atomic_charges
 from ccpem_core.map_tools.TEMPy import map_preprocess
 from ccpem_core.tasks.model2map.model2map_task import mapprocess_wrapper, \
-                sf2mapWrapper, PDBSetCell
+                sf2mapWrapper
 
 
 mrc_axis = {1: 'x',
@@ -70,8 +70,7 @@ class LocScale(task_utils.CCPEMTask):
     def parser(self):
         parser = ccpem_argparser.ccpemArgParser()
         #
-        job_title = parser.add_argument_group()
-        job_title.add_argument(
+        parser.add_argument(
             '-job_title',
             '--job_title',
             help='Short description of job',
@@ -79,8 +78,7 @@ class LocScale(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
-        job_location = parser.add_argument_group()
-        job_location.add_argument(
+        parser.add_argument(
             '-job_location',
             '--job_location',
             help='Directory to run job',
@@ -88,8 +86,7 @@ class LocScale(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
-        target_map = parser.add_argument_group()
-        target_map.add_argument(
+        parser.add_argument(
             '-target_map',
             '--target_map',
             help='Target map to be auto sharpened (mrc format)',
@@ -97,8 +94,7 @@ class LocScale(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
-        reference_model_map = parser.add_argument_group()
-        reference_model_map.add_argument(
+        parser.add_argument(
             '-reference_map',
             '--reference_map',
             help=(
@@ -108,8 +104,7 @@ class LocScale(task_utils.CCPEMTask):
             type=str,
             default=None)
         #
-        mask_map = parser.add_argument_group()
-        mask_map.add_argument(
+        parser.add_argument(
             '-mask_map',
             '--mask_map',
             help='Mask map (mrc format)',
@@ -137,7 +132,7 @@ class LocScale(task_utils.CCPEMTask):
         parser.add_argument(
             '-reference_model',
             '--reference_model',
-            help='Reference model (PDB format)',
+            help='Reference model (PDB or mmCIF format)',
             metavar='Reference model',
             type=str,
             default=None)
@@ -259,9 +254,10 @@ class LocScale(task_utils.CCPEMTask):
                     ori_z = map_nzstart*apix[2]
                 
             ##self.pdb_edit_path = self.args.pdb_path.value
-            self.pdb_edit_path = os.path.join(self.job_location,
-                                    os.path.splitext(os.path.basename(
-                                        self.args.reference_model.value))[0]+'_fix.pdb')
+            orig_name = os.path.basename(self.args.reference_model.value)
+            orig_name_parts = os.path.splitext(orig_name)
+            fix_name = orig_name_parts[0] + '_fix' + orig_name_parts[1]
+            self.pdb_edit_path = os.path.join(self.job_location, fix_name)
             #translate model to origin 0 if nstart is 0
             if fix_map_model and not all(o == 0. for o in (ori_x,ori_y,ori_z)):
                 trans_vector = [-ori_x,
@@ -276,23 +272,24 @@ class LocScale(task_utils.CCPEMTask):
                                           self.pdb_edit_path)
                 
             # Set PDB cryst from mtz
-            self.process_pdb_set = PDBSetCell(
-                command=self.commands['pdbset'],
+            self.process_set_unit_cell = refmac_task.SetModelCell(
                 job_location=self.job_location,
-                name='Set PDB cell',
+                name='Set model unit cell',
                 pdb_path=self.pdb_edit_path,
                 map_path=self.map_edit_path)
-            pl = [[self.process_pdb_set.process]]
+            pl.append([self.process_set_unit_cell.process])
 
-            self.pdb_set_path = os.path.join(
-                self.job_location,
-                'pdbset.pdb')
+            if os.path.splitext(self.args.reference_model.value)[-1].lower() in ['.cif','.mmcif'] or \
+                 os.stat(self.args.reference_model.value).st_size > 10000000:
+                pdb_set_path = self.process_set_unit_cell.cifout_path
+            else:
+                pdb_set_path = self.process_set_unit_cell.pdbout_path
 
             # Calculate mtz from pdb 
             self.refmac_sfcalc_crd_process = refmac_task.RefmacSfcalcCrd(
                 job_location=self.job_location,
                 name='SF calc from coord',
-                pdb_path=self.pdb_set_path,
+                pdb_path=pdb_set_path,
                 lib_in=self.args.lib_in(),
                 resolution=self.args.resolution())
             self.refmac_sfcalc_mtz = os.path.join(
@@ -318,22 +315,6 @@ class LocScale(task_utils.CCPEMTask):
                 mtz_path=self.refmac_sfcalc_mtz,
                 map_path=self.reference_map)
             pl.append([self.sf2map_process.process])
-#             # Convert calc mtz to map
-#             self.fft_process = fft.FFT(
-#                 job_location=self.job_location,
-#                 map_nx=map_nx,
-#                 map_ny=map_ny,
-#                 map_nz=map_nz,
-#                 # For now only use x,y,z
-# #                 fast=mrc_axis[int(map_mapc)],
-# #                 medium=mrc_axis[int(map_mapr)],
-# #                 slow=mrc_axis[int(map_maps)],
-#                 fast='X',
-#                 medium='Y',
-#                 slow='Z',
-#                 mtz_path=self.refmac_sfcalc_mtz,
-#                 map_path=self.reference_map)
-#             pl.append([self.fft_process.process])
             #set origin and remove background
             self.reference_map_processed = os.path.join(
                 self.job_location,
