@@ -28,22 +28,29 @@ class Model2Map(task_utils.CCPEMTask):
     '''
     task_info = task_utils.CCPEMTaskInfo(
         name='model2map',
-        author='G. Murshudov, R. Nicholas, T.Burnley, C.Palmer, A.Joseph',
+        author='G. Murshudov, R. Nicholas, T. Burnley, C. Palmer, A. Joseph',
         version='1.0',
         description=(
             '''
-            Tool for atomic model to MRC map conversion using pdbset (CCP4), 
-            Refmac5 (CCP4), gemmi, mrcfile and TEMPy mapprocess. 
+            Tool for atomic model to MRC map conversion using
+            Refmac5 (CCP4), gemmi, mrcfile and TEMPy mapprocess. Refmac5 uses 
+            electron scattering factors and considers the map resolution and 
+            atomic B-factors to generate map.<br>
+            References:<br>
+            <a href="http://scripts.iucr.org/cgi-bin/paper?S1399004714021683"> 
+            Brown et al, 2015</a><br>
+            <a href="http://scripts.iucr.org/cgi-bin/paper?S2059798318007313">
+            Nicholls et al. 2017</a>
             '''
                     ),
         short_description=(
             'Model to map coversion'),
         documentation_link='',
-        references=None)
+        references=('http://scripts.iucr.org/cgi-bin/paper?S1399004714021683',
+                    'http://scripts.iucr.org/cgi-bin/paper?S2059798318007313'))
 
     commands = {
         'refmac': settings.which(program='refmac5'),
-        'pdbset':  settings.which(program='pdbset'),
         'ccpem-gemmi':settings.which(program='gemmi'),
         'ccpem-mapprocess':
         ['ccpem-python', os.path.realpath(map_preprocess.__file__)]}
@@ -91,7 +98,7 @@ class Model2Map(task_utils.CCPEMTask):
             '--pdb_path',
             help=('Synthetic map will be created and difference maps '
                   'calculated using this'),
-            metavar='Input PDB',
+            metavar='Input atomic model',
             type=str,
             default=None)
         #
@@ -130,6 +137,14 @@ class Model2Map(task_utils.CCPEMTask):
             type=str,
             default=None)
         
+        map_path.add_argument(
+            '-map_edit_path',
+            '--map_edit_path',
+            help='Edited map (mrc format)',
+            metavar='Edited input map',
+            type=str,
+            default=None)
+                
         return parser
     
     def edit_argsfile(self,args_file):
@@ -140,7 +155,7 @@ class Model2Map(task_utils.CCPEMTask):
                     
         with open(args_file,'w') as f:
             json.dump(json_args,f)
-
+    
     def fix_model_for_refmac(self,pdb_path,pdb_edit_path,trans_vector,
                              remove_charges=False):
         shift_coordinates(pdb_path,pdb_edit_path,trans_vector,remove_charges)
@@ -149,45 +164,17 @@ class Model2Map(task_utils.CCPEMTask):
         pl = []
         fix_map_model = True
         self.map_edit_path = None
+        self.args.map_edit_path.value = None
         #use Refmac for model map conversion
         #if a target map is given
         if self.args.map_path.value != None and \
                 os.path.isfile(self.args.map_path.value):
-            with mrcfile.open(self.args.map_path.value, 'r') as mrc:
-                map_nx = mrc.header.nx
-                map_ny = mrc.header.ny
-                map_nz = mrc.header.nz
-                map_nxstart = mrc.header.nxstart
-                map_nystart = mrc.header.nystart
-                map_nzstart = mrc.header.nzstart
-                map_mapc = mrc.header.mapc
-                map_mapr = mrc.header.mapr
-                map_maps = mrc.header.maps
-                ori_x = mrc.header.origin.x
-                ori_y = mrc.header.origin.y
-                ori_z = mrc.header.origin.z
-                cella = (mrc.header.cella.x,mrc.header.cella.y,
-                         mrc.header.cella.z)
-                apix = mrc.voxel_size.item()
-            self.map_edit_path = self.args.map_path.value
-            #fix map and model when nstart is non-zero
-            if ori_x == 0. and ori_y == 0. and ori_z == 0.:
-                if map_nxstart != 0 or map_nystart != 0 or map_nzstart != 0:
-                    map_edit = os.path.splitext(
-                        os.path.basename(self.args.map_path.value))[0]+'_fix.mrc'
-                    self.map_edit_path = os.path.join(
-                                    self.job_location,map_edit)
-                    # fix origin to agree with nstart
-                    shutil.copyfile(self.args.map_path.value,self.map_edit_path)
-                    assert os.path.isfile(self.map_edit_path)
-                    with mrcfile.open(self.map_edit_path,'r+') as mrc:
-                        mrc.header.origin.x = map_nxstart*apix[0]
-                        mrc.header.origin.y = map_nystart*apix[1]
-                        mrc.header.origin.z = map_nzstart*apix[2]
-                    ori_x = map_nxstart*apix[0]
-                    ori_y = map_nystart*apix[1]
-                    ori_z = map_nzstart*apix[2]
-                    
+            self.args.map_edit_path.value = self.args.map_path.value
+            self.args.map_edit_path.value, fix_map_model, self.cella, \
+            (ori_x_shift,ori_y_shift,ori_z_shift), (map_nx,map_ny,map_nz), (map_ori_x,map_ori_y,map_ori_z)= \
+                fix_map_model_refmac(self.args.map_path.value,self.args.map_edit_path.value,
+                                     self.job_location)
+            #print ori_x_shift,ori_y_shift,ori_z_shift, map_ori_x,map_ori_y,map_ori_z
 #                     #reset map path
 #                     self.args.map_path.value = self.map_edit_path
         else:
@@ -202,19 +189,26 @@ class Model2Map(task_utils.CCPEMTask):
             ori,map_n = set_map_grid(self.args.pdb_path.value,apix,edge=edge)
             map_nx,map_ny,map_nz = map_n
             max_dim = max(map_n)
-            ori_x,ori_y,ori_z = ori
-            cella = (map_nx*apix,map_ny*apix,map_nz*apix)
+            ori_x_shift,ori_y_shift,ori_z_shift = ori
+            map_ori_x,map_ori_y,map_ori_z = ori_x_shift,ori_y_shift,ori_z_shift
+            self.cella = (map_nx*apix,map_ny*apix,map_nz*apix)
             #cella = (max_dim*apix,max_dim*apix,max_dim*apix)
             
         ##self.pdb_edit_path = self.args.pdb_path.value
-        self.pdb_edit_path = os.path.join(self.job_location,
+        if os.path.splitext(self.args.pdb_path.value)[-1].lower() in ['.cif','.mmcif']:
+            self.pdb_edit_path = os.path.join(self.job_location,
+                                os.path.splitext(os.path.basename(
+                                    self.args.pdb_path.value))[0]+'_fix.cif')
+        else:
+            self.pdb_edit_path = os.path.join(self.job_location,
                                 os.path.splitext(os.path.basename(
                                     self.args.pdb_path.value))[0]+'_fix.pdb')
-        #translate model to origin 0 if nstart is 0
-        if fix_map_model and not all(o == 0. for o in (ori_x,ori_y,ori_z)):
-            trans_vector = [-ori_x,
-                            -ori_y,
-                            -ori_z]
+
+        #translate model to origin 0 if origin is non zero or nstart is zero
+        if fix_map_model and not all(o == 0. for o in (ori_x_shift,ori_y_shift,ori_z_shift)):
+            trans_vector = [-ori_x_shift,
+                            -ori_y_shift,
+                            -ori_z_shift]
             self.fix_model_for_refmac(self.args.pdb_path.value,
                                       self.pdb_edit_path,trans_vector,
                                       remove_charges=True)
@@ -233,19 +227,23 @@ class Model2Map(task_utils.CCPEMTask):
         self.reference_map = os.path.join(
             self.job_location,
             model_map_filename+'_refmac.mrc')
-        # Set PDB cryst from mtz
-        self.process_pdb_set = PDBSetCell(
-            command=self.commands['pdbset'],
+        
+        # Set cell parameters and scale of model
+        self.process_set_unit_cell = refmac_task.SetModelCell(
             job_location=self.job_location,
-            name='Set PDB cell',
+            name='Set model unit cell ',
             pdb_path=self.pdb_edit_path,
-            cella = cella,
-            map_path=self.map_edit_path)
-        pl = [[self.process_pdb_set.process]]
+            cella = self.cella,
+            map_path=self.args.map_edit_path.value)
+        pl = [[self.process_set_unit_cell.process]]
 
-        self.pdb_set_path = os.path.join(
-            self.job_location,
-            'pdbset.pdb')
+        if os.path.splitext(self.args.pdb_path.value)[-1].lower() in ['.cif','.mmcif'] or \
+             os.stat(self.args.pdb_path.value).st_size > 10000000:
+            self.pdb_set_path = self.process_set_unit_cell.cifout_path
+            self.refmac_refined = self.process_set_unit_cell.cifout_path
+        else:
+            self.pdb_set_path = self.process_set_unit_cell.pdbout_path
+            self.refmac_refined = self.process_set_unit_cell.pdbout_path
 
         # Calculate mtz from pdb 
         self.refmac_sfcalc_crd_process = refmac_task.RefmacSfcalcCrd(
@@ -297,14 +295,14 @@ class Model2Map(task_utils.CCPEMTask):
         self.reference_map_processed = os.path.join(
                 self.job_location,
                 model_map_filename+'_syn.mrc')
-        if not all(o == 0. for o in (ori_x,ori_y,ori_z)):
+        if not all(o == 0. for o in (map_ori_x,map_ori_y,map_ori_z)):
             self.mapprocess_wrapper = mapprocess_wrapper(
                             job_location=self.job_location,
                             command=self.commands['ccpem-mapprocess'],
                             map_path=self.reference_map,
                             list_process=['shift_origin','threshold'],
-                            map_origin=(ori_x,ori_y,ori_z),
-                            map_contour=0.02,
+                            map_origin=(map_ori_x,map_ori_y,map_ori_z),
+                            map_contour=0.09,
                             out_map=self.reference_map_processed
                             )
         else:
@@ -313,8 +311,8 @@ class Model2Map(task_utils.CCPEMTask):
                             command=self.commands['ccpem-mapprocess'],
                             map_path=self.reference_map,
                             list_process=['threshold'],
-                            map_origin=(ori_x,ori_y,ori_z),
-                            map_contour=0.02,
+                            map_origin=(map_ori_x,map_ori_y,map_ori_z),
+                            map_contour=0.09,
                             out_map=self.reference_map_processed
                             )
         pl.append([self.mapprocess_wrapper.process])
@@ -332,69 +330,62 @@ class Model2Map(task_utils.CCPEMTask):
             title=self.args.job_title.value)
         self.pipeline.start()
 
-class PDBSetCell(object):
-    '''
-    Set input PDB cell and scale cards to input dimensions.
-    '''
-    def __init__(self,
-                 command,
-                 job_location,
-                 pdb_path,
-                 map_path=None,
-                 cella=None,
-                 name=None):
-        self.job_location = ccpem_utils.get_path_abs(job_location)
-        self.pdb_path = ccpem_utils.get_path_abs(pdb_path)
-        self.pdbout_path = os.path.join(self.job_location,
-                                        'pdbset.pdb')
-        self.cell_info = None
-        self.stdin = None
-        #
-        if map_path is None:
-            self.cell_info = [cella[0],
-                              cella[1],
-                              cella[2],
-                              90.0,
-                              90.0,
-                              90.0]
-                                  
-        else:
-            self.map_path = ccpem_utils.get_path_abs(map_path)
-            self.get_cell_parameters()
-        self.set_stdin()
-        self.set_args()
-        self.name = name
-        if self.name is None:
-            self.name = self.__class__.__name__
-        self.process = process_manager.CCPEMProcess(
-            name=self.name,
-            command=command,
-            args=self.args,
-            location=self.job_location,
-            stdin=self.stdin)
+def fix_map_model_refmac(mapfile,mapeditfile,job_location):
+    ori_x = ori_y = ori_z = 0.
+    fix_map_model = True
+    with mrcfile.open(mapfile, mode='r',permissive=True) as mrc:
+        map_nx = mrc.header.nx
+        map_ny = mrc.header.ny
+        map_nz = mrc.header.nz
+        map_nxstart = mrc.header.nxstart
+        map_nystart = mrc.header.nystart
+        map_nzstart = mrc.header.nzstart
+        map_mapc = mrc.header.mapc
+        map_mapr = mrc.header.mapr
+        map_maps = mrc.header.maps
+        ori_x = mrc.header.origin.x
+        ori_y = mrc.header.origin.y
+        ori_z = mrc.header.origin.z
+        cella = (mrc.header.cella.x,mrc.header.cella.y,
+                 mrc.header.cella.z)
+        apix = mrc.voxel_size.item()
+        map_dim = (map_nx,map_ny,map_nz)
+    map_ori_x = ori_x
+    map_ori_y = ori_y
+    map_ori_z = ori_z
+    
+    #fix map origin when nstart is non-zero
+    #if ori_x == 0. and ori_y == 0. and ori_z == 0.:
+    if map_nxstart != 0 or map_nystart != 0 or map_nzstart != 0:
+        #fix origin (for Refmac5)
+        map_edit = os.path.splitext(
+                    os.path.basename(mapfile))[0]+'_fix.mrc'
+        mapeditfile = os.path.join(job_location,map_edit)
+        shutil.copyfile(mapfile,mapeditfile)
+        try: assert os.path.isfile(mapeditfile)
+        except AssertionError:
+            mapeditfile,fix_map_model, cella,(ori_x,ori_y,ori_z), (map_nx,map_ny,map_nz)
+        #edit float origin
+        with mrcfile.open(mapeditfile,'r+') as mrc:
+            mrc.header.origin.x = map_nxstart*apix[0]
+            mrc.header.origin.y = map_nystart*apix[1]
+            mrc.header.origin.z = map_nzstart*apix[2]
+            mrc.header.nxstart = 0
+            mrc.header.nystart = 0
+            mrc.header.nzstart = 0
+            
+        map_ori_x = map_nxstart*apix[0]
+        map_ori_y = map_nystart*apix[1]
+        map_ori_z = map_nzstart*apix[2]
+        
+        ori_x = map_ori_x
+        ori_y = map_ori_y
+        ori_z = map_ori_z
+            
+            
+    return mapeditfile,fix_map_model, cella,[ori_x,ori_y,ori_z], \
+        (map_nx,map_ny,map_nz), [map_ori_x,map_ori_y,map_ori_z]
 
-    def get_cell_parameters(self):
-        if os.path.exists(path=self.map_path):
-            with mrcfile.open(self.map_path, header_only=True) as map:
-                self.cell_info = [map.header.cella.x,
-                                  map.header.cella.y,
-                                  map.header.cella.z,
-                                  map.header.cellb.alpha,
-                                  map.header.cellb.beta,
-                                  map.header.cellb.gamma]
-
-    def set_args(self):
-        self.args = ['xyzin', self.pdb_path]
-        self.args += ['xyzout', self.pdbout_path]
-
-    def set_stdin(self):
-        if self.cell_info is not None:
-            self.stdin = 'CELL '
-            for p in self.cell_info:
-                self.stdin += ' {0}'.format(p)
-            #self.stdin += "\nEXCLUDE HEADERS" #exclude header records
-            self.stdin += "\nSPACEGROUP P1"
-            self.stdin += '\nend'
 
 class sf2mapWrapper():
     '''
@@ -444,6 +435,7 @@ class mapprocess_wrapper():
                  map_contour=None,
                  map_apix=None,
                  map_pad=None,
+                 cropped_dim=None,
                  map_origin=None,
                  mask_path=None,
                  out_map=None,
@@ -474,6 +466,12 @@ class mapprocess_wrapper():
             pad_args.extend(list(map_pad))
             if len(map_pad) > 0: self.args += pad_args#' '.join(
                                                     #[str(p) for p in map_pad])]
+        #padding
+        if cropped_dim is not None:
+            
+            crop_args = ['-cr']
+            crop_args.extend(list(cropped_dim))
+            if len(cropped_dim) > 0: self.args += crop_args
         #new origin
         if map_origin is not None:
             origin_args = ['-ori']
