@@ -114,7 +114,7 @@ class MolRep(task_utils.CCPEMTask):
         parser.add_argument(
             '-keywords',
             '--keywords',
-            help='Keywords for advanced options.  Select file or define text',
+            help='MOLREP keywords for advanced options.',
             type=str,
             metavar='Keywords',
             default='')
