@@ -66,7 +66,7 @@ class PipelineResultsViewer(object):
                     self.mrc2mtz_process = job
                 if 'Refmac refine (global)' in job.name:
                     self.refine_process.append(job)
-                if 'Refmac refine (local)' in job.name:
+                if 'Refmac refine (masked)' in job.name:
                     self.refine_process.append(job)
                 if 'Nautilus build' in job.name:
                     self.nautilus_process.append(job)
@@ -154,8 +154,10 @@ class PipelineResultsViewer(object):
         plot1 = API.graph_plot(
             graphWid1, 'Completeness after each cycle', 'Cycle', yaxlabel)
         plot1.reset_xticks()
-        for i in range(0, xmax, 1):
-            plot1.add_xtick(i + 1, '%d' % (i + 1))
+        plot1.add_xtick(0, ' ')
+        for i in range(1, xmax + 1, 1):
+            plot1.add_xtick(i, str(i))
+        plot1.add_xtick(i + 1, ' ')
         dx_y1 = API.plot_line(plot1, brdata, dx, dy1)
         dx_y2 = API.plot_line(plot1, brdata, dx, dy2)
         if process == 'Buccaneer':
@@ -164,8 +166,10 @@ class PipelineResultsViewer(object):
             plot2 = API.graph_plot(
                 graphWid1, 'Average FSC after each cycle', 'Cycle', 'Percentage (%)')
             plot2.reset_xticks()
-            for i in range(0, xmax, 1):
-                plot2.add_xtick(i + 1, '%d' % (i + 1))
+            plot2.add_xtick(0, ' ')
+            for i in range(1, xmax + 1, 1):
+                plot2.add_xtick(i, str(i))
+            plot2.add_xtick(i + 1, ' ')
             dx_dy3 = API.plot_line(plot2, brdata, dx, dy3)
         API.flush()
 
