@@ -39,7 +39,8 @@ class Nautilus(task_utils.CCPEMTask):
                 'cnautilus': which('cnautilus'),
                 'sftools': which('sftools'),
                 'freerflag': which('freerflag'),
-                'libg': which('libg')
+                'libg': which('libg'),
+                'ccpem-python': which('ccpem-python')
                 }
 
     def __init__(self,
@@ -156,10 +157,10 @@ class Nautilus(task_utils.CCPEMTask):
             default=None)
         # added
         parser.add_argument(
-            '-local_refinement_on',
-            '--local_refinement_on',
-            help='Refine around radius of supplied molecule only',
-            metavar='Local refine',
+            '-masked_refinement_on',
+            '--masked_refinement_on',
+            help='Trim map around supplied model file and perform refinement with this sub-volume.',
+            metavar='Masked refinement',
             type=bool,
             default=False)
         #
@@ -173,7 +174,7 @@ class Nautilus(task_utils.CCPEMTask):
         parser.add_argument(
             '-keywords',
             '--keywords',
-            help='Keywords for advanced options.  Select file or define text',
+            help='Nautilus keywords for advanced options.',
             type=str,
             metavar='Keywords',
             default='')
@@ -181,7 +182,7 @@ class Nautilus(task_utils.CCPEMTask):
         parser.add_argument(
             '-refmac_keywords',
             '--refmac_keywords',
-            help='Refmac keywords for advanced options. Select file or define text',
+            help='REFMAC keywords for advanced options.',
             type=str,
             metavar='Refmac Keywords',
             default='')
@@ -258,7 +259,7 @@ class Nautilus(task_utils.CCPEMTask):
         refine_keywords += add_refmac_keywords(self.args.refmac_keywords.value)
 
         # Run Nautilus pipeline
-        # Nautilus->LIBG->{1}->Refmac->repeat...{1}=maptomtz local
+        # Nautilus->LIBG->{1}->RefmacServalcat->repeat...{1}=maptomtz local
         for i in range(1, (self.args.ncycle.value + 1)):
             # 1st cycle Nautilus
             if i == 1:
@@ -298,49 +299,33 @@ class Nautilus(task_utils.CCPEMTask):
             else:
                 sharp = -1.0 * self.args.map_sharpen()
             # Run RefmacRefine (global/local)
-            if self.args.local_refinement_on():
-                self.process_maptomtz_local = refmac_task.RefmacMapToMtz(
-                    command=self.commands['refmac'],
-                    name='Map to MTZ (local) {0}'.format(str(i)),
-                    resolution=self.args.resolution.value,
-                    mode='Local',
-                    job_location=self.job_location,
-                    lib_path=self.args.lib_in.value,
-                    map_path=self.args.input_map.value,
-                    pdb_path=self.process_nautilus_pipeline.pdbout,
-                    blur_array=blur_array,
-                    sharp_array=sharp_array,
-                    mrad=self.args.mask_radius.value)
-                pl.append([self.process_maptomtz_local.process])
-                # Refinement parameters: Local
-                mode = 'Local'
-                name = 'Refmac refine (local) {0}'.format(str(i))
-                pdb_path_a = self.process_maptomtz_local.pdbout_path
-                mtz_path_a = 'masked_fs.mtz'
+            if self.args.masked_refinement_on():
+                # Refinement parameters: Masked
+                mode = 'Masked'
+                name='Refmac refine (masked) via Servalcat {0}'.format(str(i))
             else:
                 # Refinement parameters: Global
                 mode = 'Global'
-                name = 'Refmac refine (global) {0}'.format(str(i))
-                pdb_path_a = self.process_nautilus_pipeline.pdbout
-                mtz_path_a = self.process_free_r_flags.hklout
+                name = 'Refmac refine (global) via Servalcat {0}'.format(str(i))
 
-            self.process_refine = refmac_task.RefmacRefine(
-                command=self.commands['refmac'],
+            self.process_refine = refmac_task.RefmacRefineServal(
+                command=self.commands['ccpem-python'],
                 job_location=self.job_location,
-                pdb_path=pdb_path_a,
-                mtz_path=mtz_path_a,
+                pdb_path=self.process_nautilus_pipeline.pdbout,
+                map_path=self.args.input_map(),
+                halfmap_paths=[None, None],
+                mask_for_fofc=None,
                 resolution=self.args.resolution.value,
-                pdbout_path=os.path.join(
-                    self.job_location, 'refined{0}.pdb'.format(str(i))),
+                weight_auto=True,
                 mode=mode,
                 name=name,
                 sharp=sharp,
                 ncycle=self.args.ncycle_refmac.value,
-                output_hkl=True,
                 symmetry_auto=False,
                 keywords=refine_keywords,
                 libg_restraints=True,
-                libg_restraints_path=[self.process_libg.libg_restraints_path])
+                libg_restraints_path=[self.process_libg.libg_restraints_path],
+                pdbout_path='refined{0}.pdb'.format(str(i)))
             pl.append([self.process_refine.process])
 
         custom_finish = NautilusResultsOnFinish(
