@@ -132,7 +132,7 @@ class ProSMART(task_utils.CCPEMTask):
         parser.add_argument(
             '-keywords',
             '--keywords',
-            help='Keywords for advanced options.  Select file or define text',
+            help='Additional ProSMART arguments for advanced options.',
             type=str,
             default='')
         #
