@@ -2,7 +2,7 @@
 #Generate difference maps with amplitude scaling/matching, remove dusts 
 
 import sys
-from TEMPy.StructureParser import PDBParser
+from TEMPy.StructureParser import PDBParser, mmCIFParser
 from TEMPy.StructureBlurrer import StructureBlurrer
 import os, subprocess
 from ccpem_core.tasks.tempy.difference_map.diffmap_argparser import DiffMapParser
@@ -37,7 +37,10 @@ def model_contour(p,res=4.0,emmap=False,t=-1.):
     return modelmap,contour,modelinstance
 def blur_model(p,res=4.0,emmap=None):
     print 'Reading the model'
-    structure_instance=PDBParser.read_PDB_file('pdbfile',p,hetatm=True,water=False)
+    if os.splitext(p)[-1].lower() in ['.cif','.mmcif']:
+        structure_instance=mmCIFParser.read_PDB_file('pdbfile',p)
+    else:
+        structure_instance=PDBParser.read_PDB_file('pdbfile',p,hetatm=True,water=False)
     print 'Generating map from the model'
     blurrer = StructureBlurrer()
     if res is None: sys.exit('Map resolution required..')
@@ -99,7 +102,7 @@ def set_args_local_scale(args,outfile,mpi=False,
     else: args.avg = True
     args.outfile = outfile
     args.window_size = args.window
-    args.mpi = mpi
+    #args.mpi = mpi
     args.verbose = verbose
     if args.apix is None:
         args.apix = apix
@@ -353,7 +356,7 @@ def main():
                                  '-p',str(round(spacing,3)),
                                  '-o',outfile]
                 set_args_local_scale(tp.args, outfile, map1='map1.mrc', map2='map2.mrc',
-                                     apix=round(spacing,3),mask='mask.mrc')
+                                     apix=round(spacing,3),mask='mask.mrc',mpi=True)
                 gc.collect()
             else:
                 if tp.args.mask is None:
@@ -412,7 +415,7 @@ def main():
             else:
                 list_args += ['-ma',tp.args.mask]
             if tp.args.window != None:
-                list_args += ['-w',tp.args.window]
+                list_args += ['-w',str(tp.args.window)]
             list_args += ['-v','True']
             print ' '.join(list_args)
             if refsc:
