@@ -15,7 +15,7 @@ from ccpem_core import process_manager
 from ccpem_core.tasks import task_utils
 from ccpem_core.tasks.tempy.difference_map import difference_map
 from ccpem_core.tasks.refmac import refmac_task
-from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper, PDBSetCell
+from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper
 from ccpem_core.tasks.bin_wrappers import fft
 from ccpem_core.map_tools.TEMPy import map_preprocess, get_map_density, \
                         attribute_map_values
@@ -29,7 +29,7 @@ class DifferenceMap(task_utils.CCPEMTask):
     CCPEM TEMPy difference map wrapper.
     '''
     task_info = task_utils.CCPEMTaskInfo(
-        name='TEMPyDifferenceMap',
+        name='TEMPy Difference Map',
         author='A. Joseph, M. Topf, M. Winn',
         version='1.1',
         description=(
@@ -51,12 +51,15 @@ class DifferenceMap(task_utils.CCPEMTask):
             This is done to remove small isolated densities that usually 
             correspond to noise in the differences. A fractional difference threshold 
             is used to mask first before dusting. The threshold can be set.<br>
+            References:<br>
+            <a href="https://www.ncbi.nlm.nih.gov/pmc/articles/PMC7254831/"> 
+            Joseph et al, 2019</a><br>
             <br>
             '''),
         short_description=(
             'Difference map calculation'),
         documentation_link='',
-        references=None)
+        references='https://www.ncbi.nlm.nih.gov/pmc/articles/PMC7254831/')
 
     commands = {'ccpem-diffmap':
         ['ccpem-python', os.path.realpath(difference_map.__file__)],
@@ -152,7 +155,7 @@ class DifferenceMap(task_utils.CCPEMTask):
             '--pdb_path',
             help=('Synthetic map will be created and difference maps '
                   'calculated using this'),
-            metavar='Input PDB',
+            metavar='Input atomic model',
             type=str,
             default=None)
         #
@@ -392,9 +395,15 @@ class DifferenceMap(task_utils.CCPEMTask):
                     self.job_location,
                     model_map_filename+'_refmac.mrc')
                 
-                self.pdb_edit_path = os.path.join(self.job_location,
+                if os.path.splitext(self.args.pdb_path.value)[-1].lower() in ['.cif','.mmcif']:
+                    self.pdb_edit_path = os.path.join(self.job_location,
+                                        os.path.splitext(os.path.basename(
+                                            self.args.pdb_path.value))[0]+'_fix.cif')
+                else:
+                    self.pdb_edit_path = os.path.join(self.job_location,
                                         os.path.splitext(os.path.basename(
                                             self.args.pdb_path.value))[0]+'_fix.pdb')
+
                 #translate model to origin 0
                 if fix_map_model and not all(o == 0. for o in (ori_x,ori_y,ori_z)):
                     trans_vector = [-ori_x,
@@ -411,18 +420,20 @@ class DifferenceMap(task_utils.CCPEMTask):
 #                     args_file = os.path.join(self.job_location,
 #                                  'args.json')
 #                     self.edit_argsfile(args_file)
-                # Set PDB cryst from mtz
-                self.process_pdb_set = PDBSetCell(
-                    command=self.commands['pdbset'],
+                        # Set cell parameters and scale of model
+                self.process_set_unit_cell = refmac_task.SetModelCell(
                     job_location=self.job_location,
-                    name='Set PDB cell',
+                    name='Set model unit cell ',
                     pdb_path=self.pdb_edit_path,
                     map_path=self.map_edit_path)
-                pl = [[self.process_pdb_set.process]]
+                pl = [[self.process_set_unit_cell.process]]
 
-                self.pdb_set_path = os.path.join(
-                    self.job_location,
-                    'pdbset.pdb')
+                if os.path.splitext(self.args.pdb_path.value)[-1].lower() in ['.cif','.mmcif'] or \
+                     os.stat(self.args.pdb_path.value).st_size > 10000000:
+                    self.pdb_set_path = self.process_set_unit_cell.cifout_path
+                else:
+                    self.pdb_set_path = self.process_set_unit_cell.pdbout_path
+            
 
                 # Calculate mtz from pdb 
                 self.refmac_sfcalc_crd_process = refmac_task.RefmacSfcalcCrd(
@@ -658,7 +669,7 @@ class TEMPyDifferenceMap(object):
         if threshold_fraction is not None:
             self.args += ['-tf',threshold_fraction]
         if window_size is not None:
-            self.args += ['-w',window_size]
+            self.args += ['-w',str(window_size)]
         if dust_prob is not None:
             self.args += ['-dp',dust_prob]
         if mpi:
