@@ -122,23 +122,39 @@ class GlobScoreResultsViewer(object):
         build_table = 'sec1/table1'
         pyrvapi.rvapi_add_table1(build_table,'TEMPy scores', 1, 0, 1, 1, False)
         pyrvapi.rvapi_put_horz_theader('table1','Atomic model','',0)
-        dict_scores_tooltip = {'overlap':'fraction of overlap w.r.t smaller volume',
+        dict_scores_tooltip = {'overlap_map':'fraction of overlap w.r.t map',
+                               'overlap_model':'fraction of overlap w.r.t model',
                                'correlation': 'cross correlation coefficient',
                                'mi': 'mutual information',
                                'local_correlation': 'cross correlation coefficent'\
                                 ' calculated on the volume of overlap',
                                 'local_mi': 'mutual information score'\
                                 ' calculated on the volume of overlap',
-                                'ccc_ov': 'combined local_correlation and overlap score',
-                                'mi_ov': 'combined mutual information and overlap score'}
-        ct_sc = 1
-        for col in self.sccc_dataframe.columns:
-            pyrvapi.rvapi_put_horz_theader('table1',col,dict_scores_tooltip[col],ct_sc)
-            ct_sc += 1
+                                'ccc_ov': 'combined local_correlation and overlap_model score',
+                                'mi_ov': 'combined mutual information and overlap_model score'}
+        num_models = len(self.sccc_dataframe.index)
+        ct_sc = len(self.sccc_dataframe.columns)
+        ct_col = 0
+        for j in range(1,ct_sc+1):
+            if j == 4: continue#skip MI
+            if num_models < 3:
+                if j > ct_sc-2: continue #skip combined overlap scores
+            col = self.sccc_dataframe.columns[j-1]
+            ct_col += 1
+            pyrvapi.rvapi_put_horz_theader('table1',col,dict_scores_tooltip[col],ct_col)
+            
+            
+        
         for i in range(len(self.sccc_dataframe.index)):
             index = self.sccc_dataframe.index[i]
             pyrvapi.rvapi_put_table_string ( 'table1',index,i,0 )
-            for j in range(1,ct_sc):
+            ct_col = 0
+            for j in range(1,ct_sc+1):
+                #print i,index,j,self.sccc_dataframe.columns[j-1]
+                if j == 4: continue#skip MI
+                if num_models < 3:
+                    if j > ct_sc-2: continue #skip combined overlap scores
                 col = self.sccc_dataframe.columns[j-1]
-                pyrvapi.rvapi_put_table_string ( 'table1','%0.3f' % round(self.sccc_dataframe[col][index],3),i,j )
+                ct_col += 1
+                pyrvapi.rvapi_put_table_string ( 'table1','%0.3f' % round(self.sccc_dataframe[col][index],3),i,ct_col)
         pyrvapi.rvapi_flush()
