@@ -22,15 +22,15 @@ from ccpem_core.tasks.ribfind import ribfind_task
 from ccpem_core.map_tools.TEMPy import map_preprocess
 from ccpem_core.model_tools.gemmi_utils import shift_coordinates, remove_atomic_charges
 from ccpem_core import settings
-import mrcfile
-from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper, PDBSetCell
+import mrcfile, shutil
+from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper, fix_map_model_refmac
 
 class GlobScore(task_utils.CCPEMTask):
     '''
     CCPEM / TEMPy global fit scores wrapper.
     '''
     task_info = task_utils.CCPEMTaskInfo(
-        name='TEMPyGlobScore',
+        name='TEMPy GlobScore',
         author='A. Joseph, M.Topf, M. Winn',
         version='1.1',
         description=(
@@ -122,8 +122,8 @@ class GlobScore(task_utils.CCPEMTask):
         parser.add_argument(
             '-input_pdbs',
             '--input_pdbs',
-            help='One or more models to score against map',
-            metavar='Input PDB',
+            help='One or more models (PDB/CIF) to score against map',
+            metavar='Input atomic models',
             type=str,
             nargs='*',
             default=None)
@@ -131,8 +131,8 @@ class GlobScore(task_utils.CCPEMTask):
         parser.add_argument(
             '-input_pdb_chains',
             '--input_pdb_chains',
-            help='Input PDB chain(s)',
-            metavar='Input PDB chain selections',
+            help='Input atomic model chain(s)',
+            metavar='Input atomic model chain selections',
             type=str,
             nargs='*',
             default=None)
@@ -252,6 +252,7 @@ class GlobScore(task_utils.CCPEMTask):
         #fix map and model when nstart is non-zero
         if ori_x == 0. and ori_y == 0. and ori_z == 0.:
             if map_nxstart != 0 or map_nystart != 0 or map_nzstart != 0:
+                fix_map_model = False
                 #set nstart to 0 and fix origin (for Refmac5)
                 map_edit = os.path.splitext(
                             os.path.basename(mapfile))[0]+'_fix.mrc'
@@ -267,26 +268,28 @@ class GlobScore(task_utils.CCPEMTask):
                     mrc.header.origin.y = map_nystart*apix[1]
                     mrc.header.origin.z = map_nzstart*apix[2]
                     
-                ori_x = map_nxstart*apix[0]
-                ori_y = map_nystart*apix[1]
-                ori_z = map_nzstart*apix[2]
-                #fix_map_model = False
+                ori_x = 0.0#map_nxstart*apix[0]
+                ori_y = 0.0#map_nystart*apix[1]
+                ori_z = 0.0#map_nzstart*apix[2]
+                
         return fix_map_model, (ori_x,ori_y,ori_z), (map_nx,map_ny,map_nz)
 
 
     def run_pipeline(self, job_id=None, db_inject=None):
         
+        self.mapprocess_task = None
         pl = []
         # Set args
         args_file = os.path.join(self.job_location,
                                  'args.json')
+        self.args.sim_maps = []
+        self.args.map_edit_path = self.args.map_path.value
+        fix_map_model = True
+        self.args.map_edit_path, fix_map_model, self.cella, self.origin_vector, self.map_dim, self.nstart_ori = fix_map_model_refmac(
+                                    self.args.map_path.value,self.args.map_edit_path,
+                                    self.job_location)
         #use Refmac for model map conversion
         if self.args.use_refmac.value:
-            self.args.sim_maps = []
-            self.args.map_edit_path = self.args.map_path.value
-            fix_map_model = True
-            fix_map_model, self.origin_vector, self.map_dim = self.fix_map_model_refmac(
-                                        self.args.map_path.value)
             ori_x = self.origin_vector[0]
             ori_y = self.origin_vector[1]
             ori_z = self.origin_vector[2]
@@ -306,13 +309,12 @@ class GlobScore(task_utils.CCPEMTask):
                     modelid = model_map_filename[:4]+'_'+model_map_filename[-4:]
                 else:
                     modelid = model_map_filename
-                    
-                pdb_edit_path = os.path.join(self.job_location,
+                #translate model to nstart 0
+                if fix_map_model and (self.origin_vector[0] != 0. or self.origin_vector[1] != 0. \
+                        or self.origin_vector[2] != 0.):
+                    pdb_edit_path = os.path.join(self.job_location,
                                         os.path.splitext(os.path.basename(
                                             pdb_path))[0]+'_fix.pdb')
-                #translate model to nstart 0
-                if self.origin_vector[0] != 0. or self.origin_vector[1] != 0. \
-                        or self.origin_vector[2] != 0.:
                     trans_vector = (-self.origin_vector[0],
                                 -self.origin_vector[1],
                                 -self.origin_vector[2])
@@ -323,13 +325,12 @@ class GlobScore(task_utils.CCPEMTask):
                     remove_atomic_charges(pdb_path,
                                       pdb_edit_path)
                 # Set PDB cryst from mtz
-                self.process_pdb_set = PDBSetCell(
-                    command=self.commands['pdbset'],
+                self.process_set_unit_cell = refmac_task.SetModelCell(
                     job_location=self.job_location,
-                    name='Set PDB cell '+modelid,
+                    name='Set model unit cell '+modelid,
                     pdb_path=pdb_edit_path,
                     map_path=self.args.map_edit_path)
-                pl.append([self.process_pdb_set.process])
+                pl.append([self.process_set_unit_cell.process])
     
                 self.pdb_set_path = os.path.join(
                     self.job_location,
@@ -394,7 +395,7 @@ class GlobScore(task_utils.CCPEMTask):
                                     map_path=reference_map,
                                     list_process=['shift_origin','threshold'],
                                     map_origin=(ori_x,ori_y,ori_z),
-                                    map_contour=0.02,
+                                    map_contour=0.09,
                                     #map_resolution=self.args.map_resolution.value,
                                     out_map=reference_map_processed,
                                     name='MapProcess '+modelid
@@ -406,7 +407,7 @@ class GlobScore(task_utils.CCPEMTask):
                                     map_path=reference_map,
                                     list_process=['threshold'],
                                     map_origin=(ori_x,ori_y,ori_z),
-                                    map_contour=0.02,
+                                    map_contour=0.09,
                                     #map_resolution=self.args.map_resolution.value,
                                     out_map=reference_map_processed,
                                     name='MapProcess '+modelid
