@@ -18,7 +18,7 @@ import os, re
 import json, glob
 import pandas as pd
 from ccpem_core.TEMPy.MapParser import MapParser
-from ccpem_core.TEMPy.StructureParser import PDBParser
+from ccpem_core.TEMPy.StructureParser import PDBParser, mmCIFParser
 from TEMPy.RigidBodyParser import RBParser
 from ccpem_core.TEMPy.ScoringFunctions import ScoringFunctions
 from TEMPy.ShowPlot import Plot
@@ -27,7 +27,6 @@ from ccpem_core.tasks.tempy.smoc import smoc_results
 from collections import OrderedDict
 from TEMPy.mapprocess import Filter
 import numpy as np
-from TEMPy.mapprocess import Filter
 mrcfile_import=True
 try:
     import mrcfile
@@ -192,9 +191,9 @@ def edit_argsfile(args_file,rigid_body_file):
 def process_smoc_scores(map_path,
                         map_resolution,
                         pdb_path_list,
-                        rigid_body_path,
-                        fragment_length,
-                        directory,
+                        rigid_body_path=None,
+                        fragment_length=9,
+                        directory=os.getcwd(),
                         syn_map_list=[],
                         distance_or_fragment_selection='Distance'):
                         #local_distance=5.0):
@@ -224,22 +223,29 @@ def process_smoc_scores(map_path,
     for pdb_path in pdb_path_list:
         pdb_id = os.path.splitext(os.path.basename(pdb_path))[0]+'_'+str(l)
         # Read structure
-        try:
-            structure = PDBParser.read_PDB_file(
-            structure_id=pdb_id,
-            filename=pdb_path,
-            hetatm=True,
-            water=False)
-        except:
-            structure = PDBParser.read_PDB_file(
-            structure_id=pdb_id,
-            filename=pdb_path,
-            hetatm=False,
-            water=False)
+        if os.path.splitext(pdb_path)[-1].lower() in ['.cif','.mmcif']:
+            structure = mmCIFParser.read_mmCIF_file(
+                structure_id=pdb_id,
+                filename=pdb_path,
+                hetatm=False,
+                water=False)
+        else:
+            try:
+                structure = PDBParser.read_PDB_file(
+                structure_id=pdb_id,
+                filename=pdb_path,
+                hetatm=True,
+                water=False)
+            except:
+                structure = PDBParser.read_PDB_file(
+                structure_id=pdb_id,
+                filename=pdb_path,
+                hetatm=False,
+                water=False)
         # Get scores
         if len(syn_mapobj_list) > 0:
             modelmap = syn_mapobj_list[l-1]
-            smoc_chain_scores = get_smoc_score(
+            smoc_chain_scores, smoc_chain_CA = get_smoc_score(
                 em_map=em_map,
                 map_resolution=map_resolution,
                 structure=structure,
@@ -250,7 +256,7 @@ def process_smoc_scores(map_path,
                 distance_or_fragment_selection=distance_or_fragment_selection)
             
         else:
-            smoc_chain_scores = get_smoc_score(
+            smoc_chain_scores, smoc_chain_CA = get_smoc_score(
                 em_map=em_map,
                 map_resolution=map_resolution,
                 structure=structure,
@@ -258,8 +264,7 @@ def process_smoc_scores(map_path,
                 fragment_length=fragment_length,
                 #local_distance=local_distance,
                 distance_or_fragment_selection=distance_or_fragment_selection)
-        #save scores
-        save_smoc_csv_plot(pdb_id,smoc_chain_scores)
+        
          #set scores as b-factors for coloring
         scored_pdb_file = os.path.join(
             directory,pdb_id+'_smoc.pdb')
@@ -270,6 +275,11 @@ def process_smoc_scores(map_path,
                 outfile=scored_pdb_file)
         except: 
             pass
+        #save scores
+        smoc_csv_file = pdb_id+'_smoc.csv'
+        smocf = open(smoc_csv_file,'w')
+        smocf.write(','.join(['#chain','residue','score','z_local','z_global'])+'\n')
+        
         # Put residue scores into dataframe
         for chain, scores in smoc_chain_scores.iteritems():
             if chain.isspace():
@@ -279,62 +289,63 @@ def process_smoc_scores(map_path,
             list_resnum = scores.keys()
             list_resscore = scores.values()
             list_resname = []
-#             list_CAx = []
-#             list_CAy = []
-#             list_CAz = []
-#             for rnum in list_resnum:
-#                 try: list_resname.append(smoc_chain_CA[chain][rnum][0])
-#                 except (KeyError,TypeError) as e: 
-#                     list_resname.append(' ')
-#                 try: list_CAx.append(smoc_chain_CA[chain][rnum][1])
-#                 except (KeyError,TypeError) as e: 
-#                     list_CAx.append(0.0)
-#                 try: list_CAy.append(smoc_chain_CA[chain][rnum][2])
-#                 except (KeyError,TypeError) as e: 
-#                     list_CAy.append(0.0)
-#                 try: list_CAz.append(smoc_chain_CA[chain][rnum][3])
-#                 except (KeyError,TypeError) as e: 
-#                     list_CAz.append(0.0)
+            list_CAx = []
+            list_CAy = []
+            list_CAz = []
+            for rnum in list_resnum:
+                try: list_resname.append(smoc_chain_CA[chain][rnum][0])
+                except (KeyError,TypeError) as e: 
+                    list_resname.append(' ')
+                try: list_CAx.append(smoc_chain_CA[chain][rnum][1])
+                except (KeyError,TypeError) as e: 
+                    list_CAx.append(0.0)
+                try: list_CAy.append(smoc_chain_CA[chain][rnum][2])
+                except (KeyError,TypeError) as e: 
+                    list_CAy.append(0.0)
+                try: list_CAz.append(smoc_chain_CA[chain][rnum][3])
+                except (KeyError,TypeError) as e: 
+                    list_CAz.append(0.0)
+            dict_results = {}
+            dict_results['residue'] = list_resnum
+            dict_results['smoc'] = list_resscore
+            dict_results['CAx'] = list_CAx
+            dict_results['CAy'] = list_CAy
+            dict_results['CAz'] = list_CAz
+            outlier_bool, list_z_local, list_z_global = select_outliers_by_z(dict_results,'smoc',z_cutoff=-1.5)
+            #save csv files
+            save_smoc_csv_plot(smocf,pdb_id,chain,list_resnum,list_resscore,list_z_local,list_z_global)
+            
             dict_smocdata = OrderedDict()
             dict_smocdata = {
                     (pdb_id+chainfix, residue_label):list_resnum, 
 #                     (pdb_id+chainfix, resname_label): list_resname,
-                    (pdb_id+chainfix, score_label):list_resscore, 
-#                     (pdb_id+chainfix, CAx_label): list_CAx,
-#                     (pdb_id+chainfix, CAy_label): list_CAy,
+                    (pdb_id+chainfix, score_label):list_resscore ,
+                    (pdb_id+chainfix, 'z_local'): list_z_local,
+                    (pdb_id+chainfix, 'z_global'): list_z_global,
 #                     (pdb_id+chainfix, CAz_label): list_CAz,
                             }
             df = pd.DataFrame(dict_smocdata)
             smoc_frames.append(df)
         l += 1
+        smocf.close()
     return pd.concat(smoc_frames, axis=1)
 
-def save_smoc_csv_plot(pdb_id,smoc_chain_scores):
+def save_smoc_csv_plot(smocf,pdb_id,chain,list_resnum,list_score,list_z_local,list_z_global):
     plt = Plot()
-    #pdb_id = os.path.splitext(pdb_id)[0]
-    smoc_csv_file = pdb_id+'_smoc.csv'
-    with open(smoc_csv_file,'w') as smocf:
-        for chain in smoc_chain_scores:
-            if len(smoc_chain_scores[chain]) < 5: continue #skip ambiguities
-            list_resnum = []
-            list_score = []
-            dict_points = {}
-            for resnum in smoc_chain_scores[chain]:
-                smoc_res = [chain]+[str(resnum)] + [str(round(float(
-                                            smoc_chain_scores[chain][resnum]),3))]
-                smocf.write(','.join(smoc_res)+'\n')
-                try:
-                    list_resnum.append(int(resnum))
-                    list_score.append(round(float(
-                                            smoc_chain_scores[chain][resnum]),3))
-                except TypeError:
-                    continue
-            dict_points[chain] = [list_resnum,list_score]
-            chain_id_edit = chain
-            if chain.islower():
-                chain_id_edit = chain+'_l'
-            smoc_plot = pdb_id+'_'+chain_id_edit+'_smocscore.png'
-            plt.lineplot(dict_points,smoc_plot,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0])
+    if len(list_resnum) < 5: return #skip ambiguities
+    dict_points = {}
+    for i in range(len(list_resnum)):
+        smoc_res = [chain,str(list_resnum[i]),str(round(float(
+                                            list_score[i]),3)),
+                                            str(list_z_local[i]),
+                                            str(list_z_global[i])]
+        smocf.write(','.join(smoc_res)+'\n')
+    dict_points[chain] = [list_resnum,list_score]
+    chain_id_edit = chain
+    if chain.islower():
+        chain_id_edit = chain+'_l'
+    smoc_plot = pdb_id+'_'+chain_id_edit+'_smocscore.png'
+    plt.lineplot(dict_points,smoc_plot,xlabel='Residue_num',ylabel='SMOC',marker=False,lstyle=False,leg_pos=1.8)#,ylim=[-0.1,1.0])
             
 def process_sccc_scores(map_path,
                         map_resolution,
@@ -431,7 +442,7 @@ def get_smoc_score(em_map,
     else: fragment_score=True
     # Calculate SMOC scores
     score_class = ScoringFunctions()
-    chain_scores, chain_residues = score_class.SMOC(
+    chain_scores, chain_residues, chain_ca = score_class.SMOC(
         map_target=em_map,
         resolution_densMap=map_resolution,
         structure_instance=structure,
@@ -441,10 +452,10 @@ def get_smoc_score(em_map,
         fragment_score=fragment_score,
         sim_map=sim_map,
         #dist=local_distance,
-        sigma_thr=2.5,
+        sigma_thr=2.0,
         calc_metric='smoc',
-        get_coord=False)
-    return chain_scores
+        get_coord=True)
+    return chain_scores, chain_ca
 
 def get_sccc_score(em_map,
                    map_resolution,
@@ -478,6 +489,100 @@ def read_mapfile(map_path):
 def import_smoc_scores_from_csv(path):
     return pd.read_csv(path, index_col=0)
 
+def select_outliers_by_z(dict_results, process_name, z_cutoff = -2.5):
+    list_smoc = dict_results[process_name]
+    array_smoc = np.array(list_smoc)
+    #use z = 0 for a very narrow distribution
+    if np.median(list_smoc) > 0.6 and np.std(list_smoc) < 0.05:
+        list_z_global = [0.0]*len(list_smoc)
+        #print list_z_global
+    else:
+        list_z_global = calc_z_median(list_smoc)
+    #print len(list_smoc),len(list_z_global)
+    #if coords are available, set z score locally
+    if 'CAx' in dict_results and 'CAy' in dict_results and \
+        'CAz' in dict_results:
+        indi = zip(dict_results['CAx'], dict_results['CAy'], dict_results['CAz'])
+        try: 
+            from scipy.spatial import cKDTree
+            gridtree = cKDTree(indi)
+        except ImportError:
+            try:
+                from scipy.spatial import KDTree
+                gridtree = KDTree(indi)
+            except ImportError: 
+                gridtree = None
+        list_z_local = []
+        if gridtree is not None:
+            list_z = []
+            for l in xrange(len(list_smoc)):
+                ca_coord = indi[l]
+                val = list_smoc[l]
+                list_neigh = get_indices_sphere(gridtree,ca_coord,dist=12.0)
+                list_smoc_local = array_smoc[list_neigh]
+                if np.median(list_smoc_local) > 0.6 and np.std(list_smoc_local) < 0.05:
+                    z_local = 0.0
+                else:
+                    z_local = calc_z_median(list_smoc_local,val)
+                #res_index = list_neigh.index(l)
+                list_z_local.append(z_local)
+                list_z.append(z_local < z_cutoff)
+            
+    else:
+        list_z_local = [0.]*len(list_z_global) #when no local z is calculated
+        z = calc_z_median(array_smoc)
+        list_z = z < z_cutoff
+    #print len(list_z),len(list_z_local),len(list_z_global)
+    #print list_z, list_z_local, list_z_global
+    return list_z, list_z_local, list_z_global
+
+def calc_z(list_vals,val=None):
+    if val is not None:
+        try:
+            list_vals.remove(val) #remove val from list
+        except: pass
+    sum_mapval = np.sum(list_vals)
+    mean_mapval = sum_mapval/len(list_vals)
+    #median_mapval = np.median(list_vals)
+    std_mapval = np.std(list_vals)
+    if val is None:
+        if std_mapval == 0.:
+            z = [0.0]*len(list_vals)
+        else:
+            z = np.round((np.array(list_vals) - mean_mapval)/std_mapval,2)
+    else:
+        if std_mapval == 0.:
+            z = 0.0
+        else:
+            z = (val - mean_mapval)/std_mapval
+    return z
+ 
+def calc_z_median(list_vals,val=None):
+    if val is not None:
+        try:
+            list_vals.remove(val)
+        except: pass
+    sum_smoc = np.sum(list_vals)
+    median_smoc = np.median(list_vals)
+    mad_smoc = np.median(np.absolute(np.array(list_vals)-median_smoc))
+    if val is None:
+        if mad_smoc == 0.:
+            z = [0.0]*len(list_vals)
+        else:
+            z = np.around((np.array(list_vals) - median_smoc)/mad_smoc,2)
+    else:
+        if mad_smoc == 0.:
+            z = 0.0
+        else:
+            z = round(((val - median_smoc)/mad_smoc),2)
+    return z    
+
+def get_indices_sphere(gridtree,coord,dist=5.0):
+    list_points = gridtree.query_ball_point(\
+                [coord[0],coord[1],coord[2]], 
+                dist)
+    return list_points
+
 
 if __name__ == '__main__':
     if len(sys.argv) <= 1:
