@@ -12,10 +12,11 @@ import os,sys
 import shutil
 import pyrvapi
 from ccpem_core import ccpem_utils
+bokeh_flag = 1
 try:
     from bokeh.plotting import figure as bokeh_figure, output_file as bokeh_output_file, save as bokeh_save
 except ImportError:
-    bokeh = None
+    bokeh_flag = 0
 
 class SMOCResultsViewer1(object):
     def __init__(self, smoc_dataframe, directory):
@@ -29,7 +30,7 @@ class SMOCResultsViewer1(object):
         self.smoc_dataframe = smoc_dataframe
 
         # Set results
-        if bokeh is not None:
+        if bokeh_flag == 1:
             self.index = None
             self.set_bokeh_page()
             self.set_results()
@@ -74,7 +75,7 @@ class SMOCResultsViewer1(object):
         
 
 class SMOCResultsViewer(object):
-    def __init__(self, smoc_dataframe, directory):
+    def __init__(self, smoc_dataframe, directory, set_results=True):
         self.directory = os.path.join(directory,
                                       'rvapi_data')
         if os.path.exists(self.directory):
@@ -86,12 +87,10 @@ class SMOCResultsViewer(object):
 
         # Set results
         self.index = None
-        self.set_pyrvapi_page()
-        self.set_results()
-
-    def set_results(self):
-        self.set_results_summary()
-        self.set_results_graphs()
+        if set_results:
+            self.set_pyrvapi_page()
+            self.set_results_summary()
+            self.set_results_graphs()
 
     def set_pyrvapi_page(self):
         # Setup index.html
@@ -105,11 +104,11 @@ class SMOCResultsViewer(object):
                                     None, None, None, None)
         pyrvapi.rvapi_flush()
 
-    def set_results_summary(self):
+    def set_results_summary(self,section_name='sec1'):
         # Setup refine_results (summary, graphs and output files)
         pyrvapi.rvapi_add_header('SMOC results')
         pyrvapi.rvapi_add_tab('tab2', 'SMOC Scores', True)
-        pyrvapi.rvapi_add_section('sec1', 'Results', 'tab2', 0, 0, 1, 1,
+        pyrvapi.rvapi_add_section(section_name, 'Results', 'tab2', 0, 0, 1, 1,
                                   True)
         pyrvapi.rvapi_add_text(
             'Local fragment Score based on Manders\' Overlap Coefficient (SMOC)',
@@ -118,9 +117,9 @@ class SMOCResultsViewer(object):
         # See flex-em results for example of setting a datatable here.
         pyrvapi.rvapi_flush()
 
-    def set_results_graphs(self):
+    def set_results_graphs(self,section_name='sec1'):
         # Refinement statistics vs cycle
-        pyrvapi.rvapi_append_loggraph1('sec1/graphWidget1')
+        pyrvapi.rvapi_append_loggraph1(section_name+'/graphWidget1')
         # Add graph data
         pyrvapi.rvapi_add_graph_data1('graphWidget1/data1',
                                       'SMOC Scores')
@@ -134,6 +133,7 @@ class SMOCResultsViewer(object):
         dict_chain = {}
         # Get data
         for pdb in self.smoc_dataframe.columns.levels[0]:
+            #print pdb
             #add plots for each chain
             chain = pdb.split('_')[-1]
             if chain == '': chain = ' '
@@ -157,15 +157,16 @@ class SMOCResultsViewer(object):
                 pdb)
 
             pdb_df = self.smoc_dataframe[pdb].dropna(axis=0, how='any')
-
+        
             for index, row in pdb_df.iterrows():
                 pyrvapi.rvapi_add_graph_int1(
                     'graphWidget1/data1/x'+pdb,
-                    int(row['residue']))
+                    int(row['resnum']))
                 pyrvapi.rvapi_add_graph_real1(
                     'graphWidget1/data1/y1'+pdb,
                     float(row['smoc']),
                     '%g')
+                #print row['resnum'], row['smoc']
 
             pyrvapi.rvapi_add_plot_line1('graphWidget1/data1/plot'+`dict_chain[chain]`,
                                          'x'+pdb,
@@ -176,7 +177,8 @@ class SMOCResultsViewer(object):
         pyrvapi.rvapi_flush()
         
 class SCCCResultsViewer(object):
-    def __init__(self, pd_dataframe, directory):
+    
+    def __init__(self, pd_dataframe, directory, set_results=True):
         self.directory = os.path.join(directory,
                                       'rvapi_data')
         if os.path.exists(self.directory):
@@ -188,12 +190,10 @@ class SCCCResultsViewer(object):
 
         # Set results
         self.index = None
-        self.set_pyrvapi_page()
-        self.set_results()
-
-    def set_results(self):
-        self.set_results_summary()
-        self.set_results_tables()
+        if set_results:
+            self.set_pyrvapi_page()
+            self.set_results_summary()
+            self.set_results_tables()
 
     def set_pyrvapi_page(self):
         # Setup index.html
