@@ -19,7 +19,7 @@ from ccpem_core.process_manager import job_register
 from ccpem_core.tasks.ribfind import ribfind_task
 from ccpem_core import settings
 from ccpem_core.tasks.refmac import refmac_task
-from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper, PDBSetCell
+from ccpem_core.tasks.model2map.model2map_task import sf2mapWrapper, fix_map_model_refmac
 from ccpem_core.tasks.bin_wrappers import fft
 import mrcfile
 from ccpem_core.model_tools.gemmi_utils import shift_coordinates, remove_atomic_charges
@@ -30,7 +30,7 @@ class SMOC(task_utils.CCPEMTask):
     CCPEM / TEMPy difference map wrapper.
     '''
     task_info = task_utils.CCPEMTaskInfo(
-        name='TEMPy-LocScore',
+        name='TEMPy LocScore',
         author='A. Joseph, M. Topf',
         version='1.1',
         description=(
@@ -135,9 +135,9 @@ class SMOC(task_utils.CCPEMTask):
         parser.add_argument(
             '-input_pdbs',
             '--input_pdbs',
-            help=('Input pdb(s)'
+            help=('Input pdb/cif(s)'
                   'ensure same residue numbering in all'),
-            metavar='Input PDB',
+            metavar='Input atomic models',
             type=str,
             nargs='*',
             default=None)
@@ -419,7 +419,11 @@ class SMOC(task_utils.CCPEMTask):
         # Set args
         args_file = os.path.join(self.job_location,
                                  'args.json')
-        
+        fix_map_model = True
+        self.args.map_edit_path = self.args.map_path.value
+        self.args.map_edit_path, fix_map_model, cella, self.origin_vector, self.map_dim, self.nstart_ori = fix_map_model_refmac(
+                                        self.args.map_path.value,self.args.map_edit_path,
+                                        self.job_location)
         #use Refmac for model map conversion
         if self.args.use_refmac.value:
             self.args.sim_maps = []
@@ -494,13 +498,12 @@ class SMOC(task_utils.CCPEMTask):
                     remove_atomic_charges(pdb_path,
                                       pdb_edit_path)
                 # Set PDB cryst from mtz
-                self.process_pdb_set = PDBSetCell(
-                    command=self.commands['pdbset'],
+                self.process_set_unit_cell = refmac_task.SetModelCell(
                     job_location=self.job_location,
-                    name='Set PDB cell '+modelid,
+                    name='Set model unit cell '+modelid,
                     pdb_path=pdb_edit_path,
                     map_path=self.args.map_edit_path)
-                pl.append([self.process_pdb_set.process])
+                pl.append([self.process_set_unit_cell.process])
     
                 self.pdb_set_path = os.path.join(
                     self.job_location,
