@@ -108,7 +108,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
     Main window class to hold job history and task launch buttons.
     '''
     def __init__(self,
-                 splash=None, 
+                 splash=None,
                  show_warning=True,
                  args=None,
                  parent=None):
@@ -187,7 +187,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         msg.setWindowTitle('CCP-EM task warning')
         errors = 'Task errors:'
         for key, value in self.tasks.errors.iteritems():
-            print str(value)
+            print("CCP-EM: Error loading task {}: {}".format(key, value))
             errors += '\n{0} : {1}'.format(key, value)
         msg.setInformativeText(errors)
         dont_show = QtGui.QCheckBox("Don't show this again")
@@ -353,17 +353,20 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         self.add_task_button('MRC-Allspace', self.tasks.mrcallspacea)
         self.add_task_button('MRC-Tif', self.tasks.mrc2tif)
         self.add_task_button('Nautilus', self.tasks.nautilus)
+        self.add_task_button('Privateer', self.tasks.privateer)
         self.add_task_button('ProSHADE', self.tasks.proshade)
         self.add_task_button('ProSMART', self.tasks.prosmart)
-        self.add_task_button('Refmac5', self.tasks.refmac)
+        self.add_task_button('Refmac Servalcat', self.tasks.refmac)
         self.add_button('RELION', 'Open RELION in a chosen project directory', self.handle_run_relion)
         self.add_task_button('Ribfind', self.tasks.ribfind)
         self.add_task_button('Shake', self.tasks.shake)
+        self.add_task_button('Strudel Score', self.tasks.strudel)
         self.add_task_button('SymmetryExpand', self.tasks.sym_expand)
         self.add_task_button('TEMPy: DiffMap', self.tasks.tempy_diff_map)
         self.add_task_button('TEMPy: Local score', self.tasks.tempy_smoc)
         self.add_task_button('TEMPy: Scores', self.tasks.tempy_scores)
         self.add_task_button('Validation: model', self.tasks.model_validation)
+        self.add_task_button('FDR model validation', self.tasks.fdr_validation)
 
         # Separator
         self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
@@ -379,7 +382,7 @@ class CCPEMMainWindow(QtGui.QMainWindow):
         self.task_buttons_layout.addWidget(ccpem_widgets.CCPEMMenuSeparator())
 
         ### Information
-        
+
         # About button
         self.add_button('About', 'Information about CCP-EM setup', self.handle_about_button)
 
@@ -444,7 +447,9 @@ class CCPEMMainWindow(QtGui.QMainWindow):
                 modeller.info.version)
         else:
             info_str += '\nModeller\nNot available\n'
-        info_str += '\nUser settings\n'
+
+        info_str += (u'\nUser settings \u2013 to edit, click the Edit button below'
+                     u' or open the file listed in "--location" using a text editor.\n')
         info_str +=  self.args.output_args_as_text()
 
         # Task errors
@@ -544,8 +549,8 @@ class MainWindowProjectView(database_widget.CCPEMProjectTableView):
         self.tasks = main_window.tasks
 
     def clone_custom(self, args_json):
-        task_class = self.tasks.get_task_class(program=self.program)
-        window_class = self.tasks.get_window_class(program=self.program)
+        task_class, window_class = \
+            self.tasks.get_task_and_window_classes(name=self.program, fuzzy=True)
         task = task_class(
             parent=self,
             args_json=args_json,
@@ -559,8 +564,8 @@ class MainWindowProjectView(database_widget.CCPEMProjectTableView):
         program_index = index.sibling(index.row(),
                                       self.model.fieldIndex('program'))
         program = str(self.model.data(program_index).toString())
-        task_class = self.tasks.get_task_class(program=program)
-        window_class = self.tasks.get_window_class(program=program)
+        task_class, window_class = \
+            self.tasks.get_task_and_window_classes(name=program, fuzzy=True)
         task_file = os.path.join(path, process_manager.task_filename)
         if task_class is not None and os.path.exists(task_file):
             window_utils.relaunch_task_window(
@@ -569,11 +574,9 @@ class MainWindowProjectView(database_widget.CCPEMProjectTableView):
                 task_file=task_file,
                 main_window=self.main_window)
         else:
-            message = 'No task found'
-            QtGui.QMessageBox.warning(
-                self,
-                'CCP-EM warning',
-                message)
+            message = ('Job type "{}" not found\n\n'.format(program) +
+                       'Perhaps the job was created by an older version of CCP-EM?')
+            QtGui.QMessageBox.warning(self, 'CCP-EM warning', message)
 
 class MainWindowProjectWidget(project_widget.CCPEMProjectsWidget):
     def __init__(self, main_window, ccpem_projects):
