@@ -75,27 +75,41 @@ CCP-EM project name must be unique with only one project per directory\n''')
                'Selected directory does not have write permission')
 
     def accept(self):
-        warnings = ''
+        errors = ''
         directory = str(self.path_edit.text())
         name = str(self.name_edit.text())
         # Check name
         if name in self.projects.project_names:
-            warnings += '\nProject name already exists'
+            errors += '\nProject name already exists'
         # Check directory
         if directory in self.projects.project_paths:
-            warnings += '\nDirectory already has project'
+            errors += '\nDirectory already has project'
         elif not os.path.exists(directory):
             directory = ccpem_utils.check_directory_and_make(
                 directory,
                 auto_suffix=False,
                 verbose=False)
             if directory is None:
-                warnings += '\nDirectory cannot be made please try again'
-        if warnings != '':
+                errors += '\nDirectory cannot be made please try again'
+        if errors != '':
             QtGui.QMessageBox.critical(self,
                                       'Error',
-                                      warnings)
+                                      errors)
             return
+        if ' ' in directory:
+            cont = QtGui.QMessageBox.warning(
+                self,
+                'Warning',
+                'Warning! Your selected project path contains spaces.\n\nThis will'
+                ' cause some CCP-EM features to fail, though most of the main tasks'
+                ' should still work correctly.\n\nYou can continue anyway if you'
+                ' choose, but we suggest you cancel and select a path with no spaces to'
+                ' ensure CCP-EM works properly. Continue anyway?',
+                buttons=(QtGui.QMessageBox.Ok | QtGui.QMessageBox.Cancel),
+                defaultButton=QtGui.QMessageBox.Cancel
+            )
+            if cont == QtGui.QMessageBox.Cancel:
+                return
         self.project.name = name
         self.project.path = directory
         self.project.user = str(self.user_edit.text())
