@@ -14,12 +14,16 @@ from PyQt4 import QtGui
 from ccpem_core import ccpem_utils
 from ccpem_gui import project_database
 
+
 class CCPEMDatabase(object):
     '''
     CCPEMDatabase object.  Sqlite database, at present stores:
         job history
         programs
     '''
+    # Set filename for project database
+    ccpem_db_filename = '.ccpemDB.sqlite'
+
     def __init__(self, database_path, max_connections=100):
         super(CCPEMDatabase, self).__init__()
         # Self complied PyQt requires plugins directory to be set
