@@ -7,7 +7,7 @@
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
 
-import shutil
+import shutil, glob
 import subprocess
 import time
 
@@ -70,6 +70,8 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
             required=False,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_input)
+        self.map_input.value_line.editingFinished.connect(
+                        self.check_input_for_methods)
         # Map resolution
         self.map_resolution = window_utils.NumberArgInput(
             parent=self,
@@ -78,14 +80,14 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
             required=False,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_resolution)
-        # -> Use Refmac for model-map conversion
-        self.use_refmac = window_utils.CheckArgInput(
-            parent=self,
-            arg_name='use_refmac',
-            args=self.args,
-            label_width=245)
-        self.args_widget.args_layout.addWidget(self.use_refmac)
-        self.use_refmac.value_line.stateChanged.connect(self.set_modelmap)
+#         # -> Use Refmac for model-map conversion
+#         self.use_refmac = window_utils.CheckArgInput(
+#             parent=self,
+#             arg_name='use_refmac',
+#             args=self.args,
+#             label_width=245)
+#         self.args_widget.args_layout.addWidget(self.use_refmac)
+#         self.use_refmac.value_line.stateChanged.connect(self.set_modelmap)
         # Ligand library input for Refmac5
         self.lib_input = window_utils.FileArgInput(
             parent=self,
@@ -119,23 +121,31 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
             parent=self,
             arg_name='map_contour_level',
             required=False,
-            args=self.args)
+            args=self.args,
+            decimals=6)
         self.args_widget.args_layout.addWidget(self.map_contour_level)
         
         self.check_input_for_methods()
         #add to layout
         method_options_frame.add_extension_widget(self.run_molprobity)
         method_options_frame.add_extension_widget(self.run_cablam)
+        method_options_frame.add_extension_widget(self.run_piscore)
         method_options_frame.add_extension_widget(self.run_scores)
         method_options_frame.add_extension_widget(self.run_smoc)
+        method_options_frame.add_extension_widget(self.run_fdr)
+#         method_options_frame.add_extension_widget(self.run_fsc)
+#         method_options_frame.add_extension_widget(self.run_diffmap)
         method_options_frame.add_extension_widget(self.run_refmac)
         method_options_frame.add_extension_widget(self.run_jpred)
         
+        
         self.run_scores.value_line.stateChanged.connect(self.set_run_methods)
         self.run_smoc.value_line.stateChanged.connect(self.set_run_methods)
+        self.run_fdr.value_line.stateChanged.connect(self.set_run_methods)
+#         self.run_fsc.value_line.stateChanged.connect(self.set_run_methods)
+#         self.run_diffmap.value_line.stateChanged.connect(self.set_run_methods)
 #         self.run_jpred.value_line.stateChanged.connect(self.set_run_methods)
-        self.map_input.value_line.editingFinished.connect(
-                        self.check_input_for_methods)
+        
         self.map_resolution.value_line.editingFinished.connect(
                         self.check_input_for_methods)
         # N cpu
@@ -155,33 +165,53 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
         self.args_widget.args_layout.addWidget(self.results_parallel)
         
         self.handle_run_results_in_parallel()
-        self.set_modelmap()
+        #self.set_modelmap()
         
     def set_methods_button(self):
         self.run_molprobity = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_molprobity',
-            args=self.args)
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_molprobity.metavar)*15))
         self.run_cablam = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_cablam',
-            args=self.args)
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_cablam.metavar)*15))
+        self.run_piscore = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='run_piscore',
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_cablam.metavar)*15))
         self.run_scores = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_scores',
-            args=self.args)
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_scores.metavar)*15))
         self.run_smoc = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_smoc',
-            args=self.args)
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_smoc.metavar)*15))
+#         self.run_fsc = window_utils.CheckArgInput(
+#             parent=self,
+#             arg_name='run_fsc',
+#             args=self.args)
         self.run_refmac = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_refmac',
-            args=self.args)
+            args=self.args,
+            label_width=220)#=min(200,len(self.task.args.run_refmac.metavar)*15))
+        self.run_fdr = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='run_fdr',
+            args=self.args,
+            label_width=220)#min(200,len(self.task.args.run_fdr.metavar)*15))
         self.run_jpred = window_utils.CheckArgInput(
             parent=self,
             arg_name='run_jpred',
-            args=self.args)
+            args=self.args,
+            label_width=220)#min(200,len(self.task.args.run_jpred.metavar)*15))
         #self.run_molprobity.value_line.setChecked(True)
         #self.run_cablam.value_line.setChecked(True)
         #TODO: check why the checkboxes are cropped by default
@@ -190,40 +220,56 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
                                 "QCheckBox::indicator { height: 22px;}")       
         self.run_cablam.value_line.setStyleSheet(
                                 "QCheckBox::indicator { height: 22px;}")
+        self.run_piscore.value_line.setStyleSheet(
+                                "QCheckBox::indicator { height: 22px;}")
         self.run_scores.value_line.setStyleSheet(
                                 "QCheckBox::indicator { height: 22px;}")
         self.run_smoc.value_line.setStyleSheet(
                                 "QCheckBox::indicator { height: 22px;}")
         self.run_refmac.value_line.setStyleSheet(
                                 "QCheckBox::indicator { height: 22px;}")
+        self.run_fdr.value_line.setStyleSheet(
+                                "QCheckBox::indicator { height: 22px;}")
+#         self.run_fsc.value_line.setStyleSheet(
+#                                 "QCheckBox::indicator { height: 22px;}")
         self.run_jpred.value_line.setStyleSheet(
                                 "QCheckBox::indicator { height: 22px;}")
 
-    def set_modelmap(self):
-        if self.use_refmac.value_line.isChecked():
-            self.task.args.use_refmac.value = True
-            self.lib_input.show()
-        else:
-            self.task.args.use_refmac.value = False
-            self.lib_input.hide()
+#     def set_modelmap(self):
+#         if self.use_refmac.value_line.isChecked():
+#             self.task.args.use_refmac.value = True
+#             self.lib_input.show()
+#         else:
+#             self.task.args.use_refmac.value = False
+#             self.lib_input.hide()
 
     def check_input_for_methods(self):
         if self.task.args.map_path.value is None or \
             self.task.args.map_resolution.value is None:
             self.run_scores.setEnabled(False)
             self.run_smoc.setEnabled(False)
+            self.run_fdr.setEnabled(False)
+#             self.run_fsc.setEnabled(False)
+#             self.run_diffmap.setEnabled(False)
             self.run_refmac.setEnabled(False)
-            self.use_refmac.setEnabled(False)
-            self.task.args.use_refmac.value = False
+#             self.use_refmac.setEnabled(False)
+#             self.task.args.use_refmac.value = False
             self.task.args.map_contour_level.value = None
             self.map_contour_level.hide()
         else:
-            self.run_scores.setEnabled(True)
-            self.run_smoc.setEnabled(True)
-            self.run_refmac.setEnabled(True)
-            self.use_refmac.setEnabled(True)
-            if self.use_refmac.value_line.isChecked():
-                self.task.args.use_refmac.value = True
+            self.map_resolution.required=True
+            self.map_resolution.set_required(True)
+            if self.task.args.map_resolution.value is not None:
+                self.run_scores.setEnabled(True)
+                self.run_smoc.setEnabled(True)
+                self.run_fdr.setEnabled(True)
+    #             self.run_fsc.setEnabled(True)
+    #             self.run_diffmap.setEnabled(True)
+    
+                self.run_refmac.setEnabled(True)
+#             self.use_refmac.setEnabled(True)
+#             if self.use_refmac.value_line.isChecked():
+#                 self.task.args.use_refmac.value = True
             if self.run_scores.value_line.isChecked():
                 self.map_contour_level.show()
         
@@ -231,6 +277,15 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
         if self.run_smoc.value_line.isChecked():
             self.handle_run_tempy_smoc()
         else: self.task.args.run_smoc.value = False
+        if self.run_fdr.value_line.isChecked():
+            self.handle_run_fdr()
+        else: self.task.args.run_fdr.value = False
+#         if self.run_fsc.value_line.isChecked():
+#             self.handle_run_fsc()
+#         else: self.task.args.run_fsc.value = False
+#         if self.run_diffmap.value_line.isChecked():
+#             self.handle_run_diffmap()
+#         else: self.task.args.run_diffmap.value = False
         if self.run_scores.value_line.isChecked():
             self.handle_run_tempy_scores()
             self.map_contour_level.show()
@@ -253,7 +308,12 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
         self.task.args.run_jpred.value = True
     def handle_run_refmac(self):
         self.task.args.run_refmac.value = True
-
+    def handle_run_fdr(self):
+        self.task.args.run_fdr.value = True
+#     def handle_run_fsc(self):
+#         self.task.args.run_fsc.value = True
+#     def handle_run_diffmap(self):
+#         self.task.args.run_diffmap.value = True
     def handle_run_tempy_smoc(self):
         self.task.args.run_smoc.value = True
     def handle_run_tempy_scores(self):
@@ -344,6 +404,9 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
     def set_rv_view(self,rv_index):
         self.rv_view = QtWebKit.QWebView()
         self.rv_view.load(QtCore.QUrl(rv_index))
+        self.rv_view.setMinimumHeight(300)
+        rvapi_layout = QtGui.QHBoxLayout()
+        self.rv_view.setLayout(rvapi_layout)
         
     def count_jobs_failed(self):
         '''
@@ -491,6 +554,24 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
                         path=refmac_output,
                         description='Refmac log: '+mapid+':'+pdbid,
                         selected=False)
+                fdr_dir = os.path.join(self.task.job_location,mapid,pdbid)
+                for ranked_residues in glob.glob(os.path.join(fdr_dir, '*_FDR_ranked_residues.csv')):
+
+        #        output_model = os.path.join(self.pipeline.location, '*_BACKBONE_average.pdb')
+                    self.launcher.add_file(
+                        path=ranked_residues,
+                        file_type='standard',
+                        description='Residues with FDR scores',
+                        selected=False)
+                for output_model in glob.glob(os.path.join(fdr_dir, '*_FDR__attribute.txt')):
+
+        #        output_model = os.path.join(self.pipeline.location, '*_BACKBONE_average.pdb')
+                    self.launcher.add_file(
+                        path=output_model,
+                        file_type='standard',
+                        description='Chimera attribute file (FDR)',
+                        selected=False)
+                            
             outlier_summary_file = os.path.join(
                 self.task.job_location,
                 pdbid+'_outliersummary.txt')
@@ -561,12 +642,13 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
         if not os.path.isfile(coot_script):
             coot_script = os.path.join(self.task.job_location,
                                     'molprobity_coot.py')
+        #print coot_script
         if os.path.isfile(coot_script):
             coot_args = ['--pdb',self.dict_cootpdbs[pdbid]]
             try: coot_args += ['--map',self.task.list_maps[0]]
             except (AttributeError,IndexError) as exc:
                 pass
-            coot_args += ['-c',coot_script]
+            coot_args += ['--script',coot_script]
             
             #print coot_args
             gui_process.run_coot(coot_args)
@@ -584,9 +666,6 @@ class ValidateWindow(window_utils.CCPEMTaskWindow):
         for p in range(len(self.task.list_pdbs)):
             self.dict_cootpdbs[self.task.list_pdbids[p]] = self.task.list_pdbs[p]
         #print self.dict_cootscripts
-    #overide error log tabs 
-    def check_error_logs(self):
-        pass
 
 def main():
     '''
