@@ -162,15 +162,15 @@ class BuccaneerWindow(window_utils.CCPEMTaskWindow):
             args=self.args)
         pipeline_control_frame.add_extension_widget(ref_ncyle_input)
 
-        # Local refinement option
-        self.local_refinement_input = window_utils.ChoiceArgInput(
+        # Masked refinement option
+        self.masked_refinement_input = window_utils.ChoiceArgInput(
             parent=self,
-            arg_name='local_refinement_on',
+            arg_name='masked_refinement_on',
             args=self.args)
         pipeline_control_frame.add_extension_widget(
-            self.local_refinement_input)
+            self.masked_refinement_input)
 
-        # Local refinement on, mask radius
+        # Masked refinement on, mask radius
         self.mask_radius_input = window_utils.NumberArgInput(
             parent=self,
             decimals=1,
@@ -253,7 +253,7 @@ class BuccaneerWindow(window_utils.CCPEMTaskWindow):
             self.set_nonprotein_radius)
         self.show_nonprotein_radius_option()
         self.set_nonprotein_radius()
-        self.local_refinement_input.value_line.currentIndexChanged.connect(
+        self.masked_refinement_input.value_line.currentIndexChanged.connect(
             self.set_mask_radius)
         self.set_mask_radius()
         self.libg_input.value_line.currentIndexChanged.connect(
@@ -273,7 +273,7 @@ class BuccaneerWindow(window_utils.CCPEMTaskWindow):
             self.npradius_input.hide()
 
     def set_mask_radius(self):
-        if self.args.local_refinement_on.value:
+        if self.args.masked_refinement_on.value:
             self.mask_radius_input.show()
         else:
             self.mask_radius_input.hide()
