@@ -74,14 +74,14 @@ class BuccaneerTest(unittest.TestCase):
         # Needed this to add the appropriate number to stdout filename
         stdout_suffix = run_task.args.ncycle.value
         assert os.path.basename(
-            stdout_ref) == 'refmacrefineglobal' + str(stdout_suffix) + '_stdout.txt'
+            stdout_ref) == 'refmacrefineglobalviaservalcat' + str(stdout_suffix) + '_stdout.txt'
         assert os.path.basename(
             stdout_buc) == 'buccaneerbuild' + str(stdout_suffix) + '_stdout.txt'
 
         # Wait for job to finish
         run_time = 0
-        timeout = 500
-        delay = 5.0
+        timeout = 300
+        delay = 5
         while not job_completed and run_time < timeout:
             print('Buccaneer running for {0} secs (timeout = {1})'.format(
                 run_time,
@@ -117,14 +117,14 @@ class BuccaneerTest(unittest.TestCase):
         # Check program.xml produced
         assert xmlout_found, 'xml output not found!'
 
-    def test_buccaneer_windows_integration_localref(self):
+    def test_buccaneer_windows_integration_maskedref(self):
         '''
-        Test Buccaneer auto building pipeline with REFMAC's local refinement via GUI.
+        Test Buccaneer auto building pipeline with REFMAC's masked refinement via GUI.
         '''
-        ccpem_utils.print_header(message='Unit test - Buccaneer (Local refinement on)')
+        ccpem_utils.print_header(message='Unit test - Buccaneer (masked refinement on)')
         # Unit test args contain relative paths, must change to this directory
         os.chdir(os.path.dirname(os.path.realpath(__file__)))
-        args_path = os.path.join(self.test_data, 'Performancetest_args.json')
+        args_path = os.path.join(self.test_data, 'unittest_args_masked.json')
         run_task = buccaneer_task.Buccaneer(
             job_location=self.test_output,
             args_json=args_path)
@@ -142,24 +142,24 @@ class BuccaneerTest(unittest.TestCase):
         xmlout_found = False
         stdout_suffix = run_task.args.ncycle.value
         # Global & local refine stdout (i.e. last job in pipeline)
-        if run_task.args.local_refinement_on:
+        if run_task.args.masked_refinement_on:
             stdout_ref = run_task.pipeline.pipeline[-1][-1].stdout
-            stdout_mtmtz = run_task.pipeline.pipeline[-2][-1].stdout
-            stdout_buc = run_task.pipeline.pipeline[-3][-1].stdout
-            assert os.path.basename(stdout_ref) == 'refmacrefinelocal' + str(stdout_suffix) + '_stdout.txt'
-            assert os.path.basename(stdout_mtmtz) == 'maptomtzlocal' + str(stdout_suffix) + '_stdout.txt'
+            #stdout_mtmtz = run_task.pipeline.pipeline[-2][-1].stdout
+            stdout_buc = run_task.pipeline.pipeline[-2][-1].stdout
+            assert os.path.basename(stdout_ref) == 'refmacrefinemaskedviaservalcat' + str(stdout_suffix) + '_stdout.txt'
+            #assert os.path.basename(stdout_mtmtz) == 'maptomtzmasked' + str(stdout_suffix) + '_stdout.txt'
             assert os.path.basename(stdout_buc) == 'buccaneerbuild' + str(stdout_suffix) + '_stdout.txt'
         else:
             stdout_ref = run_task.pipeline.pipeline[-1][-1].stdout
             stdout_buc = run_task.pipeline.pipeline[-2][-1].stdout
             stdin_buc = run_task.pipeline.pipeline[-2][-1].stdin
-            assert os.path.basename(stdout_ref) == 'refmacrefineglobal' + str(stdout_suffix) + '_stdout.txt'
+            assert os.path.basename(stdout_ref) == 'refmacrefineglobalviaservalcat' + str(stdout_suffix) + '_stdout.txt'
             assert os.path.basename(stdout_buc) == 'buccaneerbuild' + str(stdout_suffix) + '_stdout.txt'
 
         # Wait for job to finish
         run_time = 0
-        timeout = 500
-        delay = 50.0
+        timeout = 300
+        delay = 5
         while not job_completed and run_time < timeout:
             print('Buccaneer running for {0} secs (timeout = {1})'.format(
                 run_time,
@@ -176,7 +176,10 @@ class BuccaneerTest(unittest.TestCase):
                         # Check Buccaneer output exists
                         buccaneer_pdb = \
                             run_task.process_buccaneer_pipeline.pdbout
-                        if os.path.exists(buccaneer_pdb):
+                        refined_pdb = \
+                            run_task.process_refine.pdbout_path
+                        if os.path.exists(buccaneer_pdb) and \
+                           os.path.exists(refined_pdb):
                             job_completed = True
                         # Get result summary
                         result_print = getResultLines(stdout_buc)
@@ -194,6 +197,10 @@ class BuccaneerTest(unittest.TestCase):
         assert job_completed
         # Check program.xml produced
         assert xmlout_found, 'xml output not found!'
+        # Check if output refined{lastcyc}.pdb is produced
+        assert os.path.exists('refined{0}.pdb'.format(stdout_suffix))
+        # Check if output build{lastcyc}.pdb is produced
+        assert os.path.exists('build{0}.pdb'.format(stdout_suffix))
         # Read RVAPI table to check end result
         filename = os.path.join(
             self.test_output,
