@@ -5,7 +5,8 @@
 #     CCP-EM Program Suite Licence Agreement as a CCP-EM Application.
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
-
+#
+import difflib
 import os
 
 
@@ -53,7 +54,7 @@ class CCPEMTasks(object):
 
         # Check ccp4 flags
         ccp4_flag_errors = self.check_ccp4_environment()
-        if ccp4_flag_errors is not None: 
+        if ccp4_flag_errors is not None:
             self.errors['CCP4 flags'] = ccp4_flag_errors
 
         # AceDRG
@@ -116,7 +117,7 @@ class CCPEMTasks(object):
                 window=cryoEF_window.cryoEFWindow)
         except Exception as e:
             self.errors['cryoEF'] = e
-            
+
         # Dock-EM
         self.dock_em = None
         try:
@@ -178,7 +179,7 @@ class CCPEMTasks(object):
                 window=loc_scale_window.LocScaleWindow)
         except Exception as e:
             self.errors['LocScale'] = e
-        
+
         #Model2Map
         if alpha:
             self.model2map = None
@@ -191,7 +192,7 @@ class CCPEMTasks(object):
                     window=model2map_window.Model2MapWindow)
             except Exception as e:
                 self.errors['Model2Map'] = e
-            
+
         # MapProcess
         self.map_process = None
         try:
@@ -256,13 +257,13 @@ class CCPEMTasks(object):
         self.mrcallspacea = None
         try:
             from ccpem_core.tasks.mrc_allspacea import mrc_allspacea_task
-            
+
 #             if mrc_allspacea_task.MrcAllspacea.commands:
 #                 message = mrc_allspacea_task.MrcAllspacea.task_info.name + ' command not found: '
 #                 for command in mrc_allspacea_task.MrcAllspacea.commands:
 #                     message += command
 #                 raise AssertionError(message)
-                
+
             from ccpem_gui.tasks.mrc_allspacea import mrc_allspacea_window
             self.mrcallspacea = CCPEMTaskWrapper(
                 name=mrc_allspacea_task.MrcAllspacea.task_info.name,
@@ -283,6 +284,19 @@ class CCPEMTasks(object):
         except Exception as e:
             self.errors['Nautilus'] = e
 
+
+        # Privateer
+        self.privateer = None
+        try:
+            from ccpem_core.tasks.privateer import privateer_task
+            from ccpem_gui.tasks.privateer import privateer_window
+            self.privateer = CCPEMTaskWrapper(
+                name=privateer_task.Privateer.task_info.name,
+                task=privateer_task.Privateer,
+                window=privateer_window.PrivateerWindow)
+        except Exception as e:
+            self.errors['Privateer'] = e
+            
         # ProSMART
         self.prosmart = None
         try:
@@ -342,7 +356,19 @@ class CCPEMTasks(object):
                 window=shake_window.ShakeWindow)
         except Exception as e:
             self.errors['Shake'] = e
-
+        
+        # Shake
+        self.strudel = None
+        try:
+            from ccpem_core.tasks.strudel import strudel_task
+            from ccpem_gui.tasks.strudel import strudel_window
+            self.strudel = CCPEMTaskWrapper(
+                name=strudel_task.Strudel.task_info.name,
+                task=strudel_task.Strudel,
+                window=strudel_window.StrudelWindow)
+        except Exception as e:
+            self.errors['Strudel Score'] = e
+            
         # Tempy Diff Map
         self.tempy_diff_map = None
         try:
@@ -414,25 +440,44 @@ class CCPEMTasks(object):
         except Exception as e:
             self.errors['ProShade'] = e
 
-    def get_task_class(self, program):
-        '''
-        Return task class from program name.
-        '''
-        for task in self.__dict__.values():
-            if isinstance(task, CCPEMTaskWrapper):
-                if task.name == program:
-                    return task.task
-        return None
+        # ProShade CHANGE TO FDR
+        self.fdr_validation = None
+        try:
+            from ccpem_core.tasks.fdr_validation import fdr_validation_task
+            from ccpem_gui.tasks.fdr_validation import fdr_validation_window
+            self.fdr_validation = CCPEMTaskWrapper(
+                name=fdr_validation_task.FDRValidationTask.task_info.name,
+                task=fdr_validation_task.FDRValidationTask,
+                window=fdr_validation_window.FDRValidationWindow )
+        except Exception as e:
+            self.errors['FDR-validation'] = e
 
-    def get_window_class(self, program):
+    def get_task_and_window_classes(self, name, fuzzy=False):
         '''
-        Return window class from program name.
+        Return task wrapper from program name.
+
+        If fuzzy, try to find a close match to the name if there is no exact match.
+        This allows tasks to be found even if the name has changed slightly between
+        CCP-EM versions.
         '''
-        for task in self.__dict__.values():
-            if isinstance(task, CCPEMTaskWrapper):
-                if task.name == program:
-                    return task.window
-        return None
+        all_task_wrappers = {
+            task_wrapper.name: task_wrapper
+            for task_wrapper in self.__dict__.values()
+            if isinstance(task_wrapper, CCPEMTaskWrapper)
+        }
+        task_wrapper = all_task_wrappers.get(name)
+        if task_wrapper is None and fuzzy:
+            matches = difflib.get_close_matches(
+                name,
+                all_task_wrappers.keys(),
+                cutoff=0.9
+            )
+            if len(matches) > 0:
+                task_wrapper = all_task_wrappers[matches[0]]
+        if task_wrapper is not None:
+            return task_wrapper.task, task_wrapper.window
+        else:
+            return None, None
 
     def check_ccp4_environment(self):
         '''
@@ -451,4 +496,3 @@ class CCPEMTasks(object):
             return 'CCP4 flags not set : {0}'.format(' '.join(missing_flags))
         else:
             return None
-
