@@ -6,12 +6,14 @@
 #     A copy of the CCP-EM licence can be obtained by writing to the
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
-
 import os
 import json
+
 from ccpem_core.tasks.choyce import choyce_task
 from ccpem_gui.utils import window_utils
 from ccpem_gui.utils import command_line_launch
+from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.test_data.tasks import choyce as test_data
 try:
     import modeller
     modeller_available = True
@@ -23,6 +25,8 @@ class ChoyceWindow(window_utils.CCPEMTaskWindow):
     '''
     Choyce window.
     '''
+    gui_test_args = get_test_data_path(test_data, 'unittest_args.json')
+
     def __init__(self,
                  task,
                  parent=None):
@@ -57,10 +61,6 @@ class ChoyceWindow(window_utils.CCPEMTaskWindow):
             args=self.args)
         self.args_widget.args_layout.addWidget(fasta_input)
 
-        # Only a few inputs therefore add stretch to stop spreading across
-        # view area
-        self.args_widget.args_layout.addStretch(2)
-
         # Add files to launcher
         self.launcher.add_file(
             arg_name='seqeunce_path',
