@@ -241,9 +241,6 @@ class cryoEFWindow(window_utils.CCPEMTaskWindow):
             results_dock_layout.addWidget(self.rv_view)
             self.results_dock.raise_()
 
-    #overide error log tabs 
-    def check_error_logs(self):
-        pass
 def main():
     '''
     Launch standalone task runner.
