@@ -644,16 +644,7 @@ Here you can enter/check some final run parameters, and launch the full DockEM r
         if self.status == 'finished':
             self.chimera_view_setup()
         else:
-            args = []
-            for pdb in self.launcher.mg_files['pdb']:
-                args.append(pdb)
-            for map_ in self.launcher.mg_files['map']:
-                args.append(map_)
-            for mtz in self.launcher.mg_files['mtz']:
-                args.append(mtz)
-            for cif in self.launcher.mg_files['cif']:
-                args.append(cif)
-            gui_process.run_chimera(args=args)
+            self.launcher.run_selected_chimera()
 
     def set_on_job_running_custom(self):
         if self.review_dock is not None:
