@@ -7,13 +7,6 @@
 #     CCP-EM Secretary, RAL Laboratory, Harwell, OX11 0FA, UK.
 #
 
-
-
-# XXX ToDo
-# 1) Refmac bfactor sharpening -> get overall sharpening value via Arjen's code
-# 2) Refine model+b's
-
-
 '''
 Task window for LocScale.
 '''
@@ -29,13 +22,6 @@ from ccpem_core.ccpem_utils import get_test_data_path
 from ccpem_core.test_data.tasks import loc_scale as test_data
 
 
-# XXX To Do
-# Set modes:
-# -> (1) Provide reference map
-#    -> Need - reference map, target map, mask?
-# -> (2) Provide reference PDB
-#    -> Need - reference pdb, target map, mask?
-
 class LocScaleWindow(window_utils.CCPEMTaskWindow):
     '''
     LocScale window.
@@ -123,7 +109,8 @@ class LocScaleWindow(window_utils.CCPEMTaskWindow):
             self.set_n_mpi_visible)
 
         # Container widget for controls for number of MPI processes
-        # This needs to be a widget (and not just a layout) so it can be shown and hidden easily
+        # This needs to be a widget (and not just a layout) so it can be 
+        # shown and hidden easily
         self.mpi_widget = QtGui.QWidget()
         mpi_layout = QtGui.QHBoxLayout()
         self.mpi_widget.setLayout(mpi_layout)
@@ -150,13 +137,6 @@ class LocScaleWindow(window_utils.CCPEMTaskWindow):
         # Add horizontal stretch so buttons don't expand sideways
         mpi_layout.addStretch()
 
-#         refine_bfactor_input = window_utils.ChoiceArgInput(
-#             parent=self,
-#             arg_name='refine_bfactors',
-#             args=self.args,
-#             required=False)
-#         self.args_widget.args_layout.addWidget(refine_bfactor_input)
-
         # Extended options
         extended_options_frame = window_utils.CCPEMExtensionFrame(
             button_name='Extended options',
@@ -206,7 +186,8 @@ class LocScaleWindow(window_utils.CCPEMTaskWindow):
         self.n_mpi_input.set_arg_value(QtCore.QThread.idealThreadCount())
 
     def set_n_mpi_half_cores(self):
-        self.n_mpi_input.set_arg_value(QtCore.QThread.idealThreadCount() / 2)
+        self.n_mpi_input.set_arg_value(
+            QtCore.QThread.idealThreadCount() / 2)
 
     def set_n_mpi_visible(self):
         if self.args.use_mpi():
@@ -247,5 +228,4 @@ def main():
         window_class=LocScaleWindow)
 
 if __name__ == '__main__':
-    print 'test'
     main()
