@@ -134,15 +134,15 @@ class NautilusWindow(window_utils.CCPEMTaskWindow):
             args=self.args)
         pipeline_control_frame.add_extension_widget(ref_ncyle_input)
 
-        # Local refinement option
-        self.local_refinement_input = window_utils.ChoiceArgInput(
+        # Masked refinement option
+        self.masked_refinement_input = window_utils.ChoiceArgInput(
             parent=self,
-            arg_name='local_refinement_on',
+            arg_name='masked_refinement_on',
             args=self.args)
         pipeline_control_frame.add_extension_widget(
-            self.local_refinement_input)
+            self.masked_refinement_input)
 
-        # Local refinement on, mask radius
+        # Masked refinement on, mask radius
         self.mask_radius_input = window_utils.NumberArgInput(
             parent=self,
             decimals=1,
