@@ -74,7 +74,7 @@ class NautilusTest(unittest.TestCase):
         stdout_nau = run_task.pipeline.pipeline[-3][-1].stdout
         stdout_suffix = run_task.args.ncycle.value
         assert os.path.basename(
-            stdout_ref) == 'refmacrefineglobal' + str(stdout_suffix) + '_stdout.txt'
+            stdout_ref) == 'refmacrefineglobalviaservalcat' + str(stdout_suffix) + '_stdout.txt'
         assert os.path.basename(stdout_nau) == 'nautilusbuild' + \
             str(stdout_suffix) + '_stdout.txt'
         assert os.path.basename(stdout_libg) == 'dnaorrnabasepairrestraints' + \
@@ -98,7 +98,10 @@ class NautilusTest(unittest.TestCase):
                         # Check Nautilus output exists
                         nautilus_pdb = \
                             run_task.process_nautilus_pipeline.pdbout
-                        if os.path.exists(nautilus_pdb):
+                        refined_pdb = \
+                            run_task.process_refine.pdbout_path
+                        if os.path.exists(nautilus_pdb) and \
+                           os.path.exists(refined_pdb):
                             job_completed = True
                         # Get result summary
                         getResultLines_nau(stdout_nau)
@@ -114,6 +117,10 @@ class NautilusTest(unittest.TestCase):
         assert job_completed
         # Check program.xml produced
         assert xmlout_found, 'xml output not found'
+        # Check if output refined{lastcyc}.pdb is produced
+        assert os.path.exists('refined{0}.pdb'.format(stdout_suffix))
+        # Check if output build{lastcyc}.pdb is produced
+        assert os.path.exists('build{0}.pdb'.format(stdout_suffix))
         # Check fragment length
         #assert longest_fragment >= 4
 
