@@ -426,7 +426,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 1,
             minimum                           = 0,
             maximum                           = 9999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.bandwidth.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.bandwidthLimit_input )
     
         # -> Integration order input
@@ -438,7 +438,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 1,
             minimum                           = 0,
             maximum                           = 9999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.integOrder.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.integOrder_input )
         
         # -> Distances between spheres input
@@ -451,7 +451,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 0.5,
             minimum                           = 0,
             maximum                           = 999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.sphDistance.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.sphDistance_input )
         
         # -> Number of speres input
@@ -463,7 +463,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 1,
             minimum                           = 0,
             maximum                           = 9999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.sphNumber.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.sphNumber_input )
         
         # -> Number of interquartile ranges from median for map masking threshohld
@@ -476,7 +476,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 0.25,
             minimum                           = 0,
             maximum                           = 999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.mapMaskThres.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.mapMaskThres_input )
 
         # -> Blurring factor for map masking
@@ -489,7 +489,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 1.0,
             minimum                           = 0,
             maximum                           = 999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.mapMaskBlur.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.mapMaskSharpen_input )
 
         # -> Number of points forming each single peak
@@ -501,7 +501,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 1,
             minimum                           = 0,
             maximum                           = 20,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.symPeakSize.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.pointsPerPeak_input )
 
         # -> Number of interquartile ranges from median to decide peak is real
@@ -514,7 +514,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 0.25,
             minimum                           = 0,
             maximum                           = 999,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.symPeakThres.metavar)*7 ))
         self.advanced_options_frame.add_extension_widget ( self.iqrsPerPeak_input )
 
         # -> Tolerance value on matching rotation axes of different peaks
@@ -527,7 +527,7 @@ class ProShadeWindow ( window_utils.CCPEMTaskWindow ):
             step                              = 0.025,
             minimum                           = 0.0,
             maximum                           = 1.0,
-            label_width                       = 200 )
+            label_width                       = max(300,len(self.task.args.symPeakThres.metavar)*7 ) )
         self.advanced_options_frame.add_extension_widget ( self.peakAxisTolerance_input )
 
     def set_mode ( self ):
