@@ -423,8 +423,8 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
 
         # Keyword frame
         keyword_frame = window_utils.CCPEMExtensionFrame(
-            button_name='Keywords',
-            button_tooltip='Optional user-supplied keywords')
+            button_name='Additional arguments',
+            button_tooltip='Optional user-supplied arguments')
         self.args_widget.args_layout.addLayout(keyword_frame)
 
         # -> Keyword entry
@@ -432,7 +432,7 @@ class ProSMARTWindow(window_utils.CCPEMTaskWindow):
             parent=self,
             arg_name='keywords',
             args=self.args,
-            label='Keyword file')
+            label='Additional arguments')
         keyword_frame.add_extension_widget(self.keyword_entry_new)
 
     def set_mode(self):
