@@ -11,6 +11,7 @@
 Task window for Refmac5.
 '''
 import os
+import textwrap
 
 from PyQt4 import QtGui, QtCore, QtWebKit
 
@@ -350,8 +351,16 @@ class extRestraintInput(QtGui.QWidget):
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
 
+        def set_tooltip(widget, text):
+            widget.setToolTip(textwrap.fill(text, 60))
+
         # restraints_file
+        restraints_file_widget = QtGui.QWidget()
+        set_tooltip(restraints_file_widget,
+                    'File containing additional restraints, for example as produced by'
+                    ' ProSMART')
         restraints_file_box = QtGui.QHBoxLayout()
+        restraints_file_box.setContentsMargins(0, 0, 0, 0)
         self.restraints_file_label = QtGui.QLabel('Restraints file')
         self.restraints_file_label.setFixedWidth(label_width)
         restraints_file_box.addWidget(self.restraints_file_label)
@@ -362,11 +371,16 @@ class extRestraintInput(QtGui.QWidget):
         self.restraints_file_value = QtGui.QLineEdit()
         self.restraints_file_value.editingFinished.connect(self.edit_finished_restraints_file)
         restraints_file_box.addWidget(self.restraints_file_value)
-        self.layout.addLayout(restraints_file_box)
-
+        restraints_file_widget.setLayout(restraints_file_box)
+        self.layout.addWidget(restraints_file_widget)
 
         # external_weight_scale
+        ext_scale_widget = QtGui.QWidget()
+        set_tooltip(ext_scale_widget,
+                    'External restraints weight. Increasing this weight increases the'
+                    ' influence of external restraints during refinement.')
         external_weight_scale_box = QtGui.QHBoxLayout()
+        external_weight_scale_box.setContentsMargins(0, 0, 0, 0)
         self.external_weight_scale_label = QtGui.QLabel('Weight')
         self.external_weight_scale_label.setFixedWidth(label_width)
         external_weight_scale_box.addWidget(self.external_weight_scale_label)
@@ -378,11 +392,19 @@ class extRestraintInput(QtGui.QWidget):
         self.external_weight_scale_value.valueChanged.connect(self.set_external_weight_scale)
         external_weight_scale_box.addWidget(self.external_weight_scale_value)
         external_weight_scale_box.setAlignment(self.external_weight_scale_value, QtCore.Qt.AlignLeft)
-        self.layout.addLayout(external_weight_scale_box)
-
+        ext_scale_widget.setLayout(external_weight_scale_box)
+        self.layout.addWidget(ext_scale_widget)
 
         # external_weight_gmwt
+        ext_gmwt_widget = QtGui.QWidget()
+        set_tooltip(ext_gmwt_widget,
+                    'Geman-McClure parameter, which controls robustness to outliers.'
+                    ' Increasing this value reduces the influence of outliers (i.e.'
+                    ' restraints that are very different from the current inter-atomic'
+                    ' distance). Note this parameter will be ignored by Refmac from'
+                    ' CCP4 8.0 onwards.')
         external_weight_gmwt_box = QtGui.QHBoxLayout()
+        external_weight_gmwt_box.setContentsMargins(0, 0, 0, 0)
         self.external_weight_gmwt_label = QtGui.QLabel('GMWT')
         self.external_weight_gmwt_label.setFixedWidth(label_width)
         external_weight_gmwt_box.addWidget(self.external_weight_gmwt_label)
@@ -394,16 +416,15 @@ class extRestraintInput(QtGui.QWidget):
         self.external_weight_gmwt_value.valueChanged.connect(self.set_external_weight_gmwt)
         external_weight_gmwt_box.addWidget(self.external_weight_gmwt_value)
         external_weight_gmwt_box.setAlignment(self.external_weight_gmwt_value, QtCore.Qt.AlignLeft)
-
-
         # Remove
         remove_button = QtGui.QPushButton('Remove')
         remove_button.setFixedWidth(button_width)
-        remove_button.setToolTip('Remove restraints set')
+        remove_button.setToolTip('Remove this restraints file')
         remove_button.clicked.connect(self.remove)
         external_weight_gmwt_box.addWidget(remove_button)
         external_weight_gmwt_box.setAlignment(external_weight_gmwt_box, QtCore.Qt.AlignRight)
-        self.layout.addLayout(external_weight_gmwt_box)
+        ext_gmwt_widget.setLayout(external_weight_gmwt_box)
+        self.layout.addWidget(ext_gmwt_widget)
 
         # Set initial values
         # restraints_file
@@ -484,15 +505,12 @@ class extRestraintsInput(QtGui.QWidget):
         # Layout
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
-
-        # Label
-        ds_label = QtGui.QLabel('Input External restraints')
-        self.layout.addWidget(ds_label)
+        self.setToolTip('External restraints')
 
         # Add dataset
         add_button = QtGui.QPushButton('Add')
         add_button.setFixedWidth(width)
-        add_button.setToolTip('Add another dataset')
+        add_button.setToolTip('Add another restraints file')
         add_button.clicked.connect(self.handle_add_button)
         self.layout.addWidget(add_button)
 
@@ -533,7 +551,7 @@ class extRestraintsInput(QtGui.QWidget):
         # Check at least one dataset
         if len(children) == 0:
             # Warn no datasets provided
-            text = 'No input datasets provided'
+            text = 'No input external restraints provided'
             QtGui.QMessageBox.warning(self,
                 'Error',
                 text)
@@ -545,7 +563,8 @@ class extRestraintsInput(QtGui.QWidget):
                 warning = True
         if warning:
             # Warn datasets incomplete information
-            text = 'Dataset(s) incomplete (requires external restraints file, weight and GMWT)'
+            text = ('Restraint(s) incomplete (each entry requires external restraints'
+                    ' file, weight and GMWT)')
             QtGui.QMessageBox.warning(self,
                 'Error',
                 text)
@@ -571,13 +590,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
     '''
     Refmac window.
     '''
-    gui_test_args = get_test_data_path(test_data, 'unittest_args_local_hb_validation.json')
-
-    def __init__(self,
-                 task,
-                 parent=None):
-        super(Refmac5Window, self).__init__(task=task,
-                                            parent=parent)
+    gui_test_args = get_test_data_path(test_data, 'unittest_args_masked_hb_validation.json')
 
     def set_args(self):
         '''
@@ -592,31 +605,99 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.title_input.value_line.editingFinished.connect(
             self.handle_title_set)
 
-        # Set dc mode
-        self.dc_input = window_utils.ChoiceArgInput(
+        # Input pdb
+        self.pdb_input = window_utils.FileArgInput(
             parent=self,
-            arg_name='dc_mode',
-            args=self.args)
-        self.args_widget.args_layout.addWidget(self.dc_input)
-        self.dc_input.value_line.currentIndexChanged.connect(self.set_dc_mode)
+            arg_name='start_pdb',
+            args=self.args,
+            label='Input model',
+            file_types=ccpem_file_types.pdb_ext,
+            required=True)
+        self.args_widget.args_layout.addWidget(
+            self.pdb_input)
 
-        # XXX Oleg option for dc prototyping
-        if not self.args.dc_proto():
-            self.dc_input.hide()
-
-        # Find in map (i.e. run Molrep)
-        self.find_in_map_input = window_utils.ChoiceArgInput(
+        # -> Input ligand cif library
+        self.lib_input = window_utils.FileArgInput(
             parent=self,
-            arg_name='find_in_map',
-            args=self.args)
-        self.args_widget.args_layout.addWidget(self.find_in_map_input)
+            label='Restraints dictionary',
+            arg_name='lib_in',
+            args=self.args,
+            file_types=ccpem_file_types.lib_ext,
+            required=False)
+        self.args_widget.args_layout.addWidget(
+            self.lib_input)
 
-        self.local_refinement_input = window_utils.CheckArgInput(
+        # Resolution
+        self.resolution_input = window_utils.NumberArgInput(
+                parent=self,
+                arg_name='resolution',
+                args=self.args,
+                required=True)
+        self.args_widget.args_layout.addWidget(
+            self.resolution_input)
+
+        # Half map vs full map refinement
+        self.half_map_refinement_input = window_utils.ChoiceArgInput(
+                parent=self,
+                arg_name='half_map_refinement',
+                args=self.args,
+                required=True)
+        self.args_widget.args_layout.addWidget(
+            self.half_map_refinement_input)
+        self.half_map_refinement_input.value_line.currentIndexChanged.connect(
+            self.set_maps_visible)
+
+        # Input map
+        self.map_input = window_utils.FileArgInput(
             parent=self,
-            arg_name='local_refinement_on',
+            arg_name='input_map',
+            args=self.args,
+            label='Input map',
+            file_types=ccpem_file_types.mrc_ext,
+            required=False)
+        self.args_widget.args_layout.addWidget(
+            self.map_input)
+
+        self.half_map_1_input = window_utils.FileArgInput(
+            parent=self,
+            arg_name='half_map_1',
+            args=self.args,
+            required=True)
+        self.args_widget.args_layout.addWidget(
+            self.half_map_1_input)
+
+        self.half_map_2_input = window_utils.FileArgInput(
+            parent=self,
+            arg_name='half_map_2',
+            args=self.args,
+            required=True)
+        self.args_widget.args_layout.addWidget(
+            self.half_map_2_input)
+
+        # -> FoFc Mask
+        mask_for_fofc_input = window_utils.FileArgInput(
+            parent=self,
+            arg_name='mask_for_fofc',
             args=self.args)
         self.args_widget.args_layout.addWidget(
-            self.local_refinement_input)
+            mask_for_fofc_input)
+
+        # -> Validation on
+        self.validation_button = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='validate_on',
+            label='Cross validation',
+            dependants=[self.half_map_1_input, self.half_map_2_input],
+            args=self.args)
+        self.args_widget.args_layout.addWidget(
+            self.validation_button)
+
+        self.masked_refinement_input = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='masked_refinement_on',
+            args=self.args)
+        self.args_widget.args_layout.addWidget(
+            self.masked_refinement_input)
 
         # Refinement options frame
         self.refinement_options_frame = window_utils.CCPEMExtensionFrame(
@@ -636,6 +717,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.libg_input = window_utils.ChoiceArgInput(
             parent=self,
             arg_name='libg',
+            label='Add RNA/DNA restraints',
             args=self.args)
         self.refinement_options_frame.add_extension_widget(
             self.libg_input)
@@ -664,6 +746,7 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.weight_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='weight',
+            label='Auto weight scale',
             args=self.args,
             decimals = 5)
         self.refinement_options_frame.add_extension_widget(
@@ -703,7 +786,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             args=self.args)
         self.refinement_options_frame.add_extension_widget(
             hydrogens_input)
-
         # Reset input PDB b-factor
         bfactor_frame = window_utils.CCPEMExtensionFrame(
             button_name='Edit input model',
@@ -727,14 +809,14 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         # ->-> Set bfactor value
         bfactor_frame.add_extension_widget(bfactor_input)
 
-        # -> Local refinement options
-        local_refinement_frame = window_utils.CCPEMExtensionFrame(
-            button_name='Local refinement options',
+        # -> Masked refinement options
+        masked_refinement_frame = window_utils.CCPEMExtensionFrame(
+            button_name='Masked refinement options',
             button_tooltip='Refine around radius of supplied molecule only')
         self.refinement_options_frame.add_extension_frame(
-            local_refinement_frame)
+            masked_refinement_frame)
 
-        # ->-> Local refinement on
+        # ->-> Masked refinement on
         mask_radius_input = window_utils.NumberArgInput(
             parent=self,
             arg_name='mask_radius',
@@ -743,7 +825,24 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             label='Mask radius')
 
         # ->-> Mask Radius
-        local_refinement_frame.add_extension_widget(mask_radius_input)
+        masked_refinement_frame.add_extension_widget(mask_radius_input)
+
+        # -> NCSC options
+        ncsc_frame = window_utils.CCPEMExtensionFrame(
+            button_name='Strict symmetry',
+            button_tooltip='Refine asymmetric unit')
+        self.refinement_options_frame.add_extension_frame(
+            ncsc_frame)
+
+        # ->-> NCSC on
+        self.ncsc_relion_symbol = window_utils.StrArgInput(
+            parent=self,
+            arg_name='ncsc_relion_symbol',
+            args=self.args,
+            label='Point group (RELION)')
+
+        # ->-> NCSC relion symbol
+        ncsc_frame.add_extension_widget(self.ncsc_relion_symbol)
 
         # External restraints frame
         self.external_restraints_frame = window_utils.CCPEMExtensionFrame(
@@ -794,66 +893,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.external_restraints_frame.add_extension_widget(
             input_main_chain)
 
-        # Validation frame
-        self.validation_frame = window_utils.CCPEMExtensionFrame(
-            button_name='Validate options',
-            button_tooltip='Validate refinement pipeline')
-        self.args_widget.args_layout.addLayout(self.validation_frame)
-
-        self.half_map_1_input = window_utils.FileArgInput(
-            parent=self,
-            arg_name='half_map_1',
-            args=self.args,
-            required=True)
-
-        self.half_map_2_input = window_utils.FileArgInput(
-            parent=self,
-            arg_name='half_map_2',
-            args=self.args,
-            required=True)
-
-        # -> Validation on
-        self.validation_button = window_utils.CheckArgInput(
-            parent=self,
-            arg_name='validate_on',
-            dependants=[self.half_map_1_input, self.half_map_2_input],
-            args=self.args)
-
-        self.validation_frame.add_extension_widget(
-            self.validation_button)
-
-        # -> Half map 1
-        self.validation_frame.add_extension_widget(
-            self.half_map_1_input)
-
-        # -> Half map 2
-        self.validation_frame.add_extension_widget(
-            self.half_map_2_input)
-
-        # -> Reference map
-        # Validation frame
-        self.validation_advanced_frame = window_utils.CCPEMExtensionFrame(
-            button_name='Advanced options',
-            button_tooltip='Show advanced validation options')
-        self.validation_frame.add_extension_frame(
-            self.validation_advanced_frame)
-
-        self.reference_map_input = window_utils.FileArgInput(
-            parent=self,
-            arg_name='reference_map',
-            args=self.args,
-            label='Reference map',
-            tooltip_text='Optional: for map sharpening',
-            required=False)
-        if self.args.reference_map() is None:
-            input_map = self.args.input_map()
-            if input_map is not None:
-                if isinstance(input_map, list):
-                    input_map = input_map[0]
-                self.reference_map_input.set_arg_value(input_map)
-        self.validation_advanced_frame.add_extension_widget(
-            self.reference_map_input)
-
         # Keyword frame
         keyword_frame = window_utils.CCPEMExtensionFrame(
             button_name='Keywords',
@@ -868,7 +907,8 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             label='Keywords')
         keyword_frame.add_extension_widget(self.keyword_entry_new)
 
-        # Set dependancies
+        # Set dependencies
+        self.set_maps_visible()
         self.weight_auto_input.value_line.stateChanged.connect(
             self.set_weight_auto)
         self.weight_auto_input.value_line.stateChanged.connect(
@@ -879,14 +919,17 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         self.restraints_button.value_line.stateChanged.connect(
             self.show_prosmart_jelly_body_warning)
 
-        # Change map / pdb / resolution input depending on DC mode
-        self.set_dc_mode()
-
-    def set_reference_map(self):
-        '''
-        Reference map should automatically pick up input structure by default
-        '''
-        self.reference_map_input.set_arg_value(self.map_input.action.value)
+    def set_maps_visible(self):
+        if self.args.half_map_refinement():
+            self.map_input.hide()
+            self.half_map_1_input.show()
+            self.half_map_2_input.show()
+            self.validation_button.show()
+        else:
+            self.map_input.show()
+            self.half_map_1_input.hide()
+            self.half_map_2_input.hide()
+            self.validation_button.hide()
 
     def set_weight_auto(self):
         if self.args.weight_auto.value:
@@ -895,53 +938,16 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
             self.weight_input.show()
 
     def set_validate_on(self):
-        '''
-        Switch of auto weight & jelly body and show information message
-        '''
-        # Disable auto weight
-        if self.validation_button.value_line.isChecked() and \
-                self.weight_auto_input.value_line.isChecked():
-            self.weight_auto_input.value_line.setChecked(False)
-            self.weight_auto_input.setEnabled(False)
-            self.show_validation_weight_message()
-        elif not self.validation_button.value_line.isChecked():
-            self.weight_auto_input.setEnabled(True)
-        # Disable jelly body
-        if self.validation_button.value_line.isChecked() and \
-                self.jelly_body_input.value_line.currentText() == 'True':
-            self.jelly_body_input.value_line.setCurrentIndex(
-                self.jelly_body_input.choices.index('False'))
-            self.jelly_body_input.value_line.setEnabled(False)
-            self.show_validation_jelly_body_message()
-        elif not self.validation_button.value_line.isChecked():
-            self.jelly_body_input.value_line.setEnabled(True)
-
-    def show_validation_weight_message(self):
-        message = \
-            ('Please set weight. \nN.B. auto weight option cannot be '
-             'used in conjuction with validation.  Please manually set '
-             'the weight (this can be found from previous jobs in the '
-             'results tab)')
-        QtGui.QMessageBox.information(self,
-                                      'CCP-EM | Refmac5',
-                                      message)
-
-    def show_validation_jelly_body_message(self):
-        message = \
-            ('Jelly body restraints are not compatible with the '
-             'validation pipeline and have been disabled')
-        QtGui.QMessageBox.information(self,
-                                      'CCP-EM | Refmac5',
-                                      message)
+        pass
 
     def show_prosmart_jelly_body_warning(self):
         if self.jelly_body_input.value_line.currentText() == 'True' and \
                 self.restraints_button.value_line.isChecked():
             message = \
-                ('Jelly body restraints are not compatible with '
-                 'ProSMART external restraints so we recommend you '
-                 'turn off the jelly body restraints if using'
-                 'ProSMART restraints')
+                ('Jelly body restraints are not compatible with'
+                 ' ProSMART external restraints. We recommend you'
+                 ' turn off the jelly body restraints if using'
+                 ' ProSMART restraints.')
             QtGui.QMessageBox.information(self,
                                           'CCP-EM | Refmac5',
                                           message)
@@ -992,8 +998,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
 #                required=True)
 #            self.args_widget.args_layout.insertWidget(4, self.cutoff_input)
 
-            self.find_in_map_input.hide()
-            self.reference_map_input.hide()
             self.external_restraints_frame.hide()
             self.validation_frame.hide()
 
@@ -1033,8 +1037,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                 label='Input map',
                 file_types=ccpem_file_types.mrc_ext,
                 required=True)
-            self.map_input.value_line.textChanged.connect(
-                self.set_reference_map)
             self.args_widget.args_layout.insertWidget(4, self.map_input)
 
             # Resolution
@@ -1044,8 +1046,6 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                     args=self.args,
                     required=True)
             self.args_widget.args_layout.insertWidget(5, self.resolution_input)
-            self.find_in_map_input.show()
-            self.reference_map_input.show()
             self.external_restraints_frame.button.show()
             self.validation_frame.button.show()
 
@@ -1075,6 +1075,15 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
         Override from baseclass to allow validation of multiple datasets
         '''
         ready = super(Refmac5Window, self).validate_input()
+        if self.args.half_map_refinement():
+            if not (self.args.half_map_1.value and self.args.half_map_2.value):
+                QtGui.QMessageBox.warning(self, 'Error', 'Half maps not specified')
+                ready = False
+        else:
+            if not self.args.input_map.value:
+                QtGui.QMessageBox.warning(self, 'Error', 'Input map not specified')
+                ready = False
+
         if ready and self.args.dc_mode():
             # Validate inputs for multiple datasets
             if not self.datasets_input.validate_datasets():
@@ -1092,43 +1101,131 @@ class Refmac5Window(window_utils.CCPEMTaskWindow):
                   restraints_files_arg=self.args.restraints_files,
                   external_weight_scales_arg=self.args.external_weight_scales,
                   external_weight_gmwts_arg=self.args.external_weight_gmwts)
-        return ready
 
+        if ready and self.args.ncsc_relion_symbol.value and self.args.ncsc_relion_symbol.value.strip():
+            from servalcat.utils import symmetry
+
+            try:
+                symmetry.operators_from_symbol(self.args.ncsc_relion_symbol.value)
+            except:
+                QtGui.QMessageBox.warning(self,
+                                          'Error',
+                                          'Invalid point group symbol ({})'.format(self.args.ncsc_relion_symbol.value))
+                ready = False
+
+        return ready
 
     def set_on_job_running_custom(self):
         if not self.args.dc_mode():
             # Set inputs for launcher
-            self.launcher.add_file(
-                arg_name='input_map',
-                file_type='map',
-                description=self.args.input_map.help,
-                selected=True)
+            # If half maps are given as input, Servalcat calculates its best estimate
+            # of the observed map density (Fo) and saves it in the output diffmap.mtz
+            # file. By opening diffmap.mtz we get both Fo and Fo-Fc maps and so we leave
+            # the input half maps deselected by default.
+            # If a full map is given, diffmap.mtz contains only a difference map and
+            # not an observed map, so in that case we select the full map input in the
+            # launcher by default to ensure an Fo map is visualised.
+            if self.args.half_map_refinement.value:
+                self.launcher.add_file(
+                    arg_name='half_map_1',
+                    file_type='map',
+                    description='Input half map 1',
+                    selected=False)
+                self.launcher.add_file(
+                    arg_name='half_map_2',
+                    file_type='map',
+                    description='Input half map 2',
+                    selected=False)
+            else:
+                self.launcher.add_file(
+                    arg_name='input_map',
+                    file_type='map',
+                    description='Input full map',
+                    selected=True)
+            if self.args.mask_for_fofc.value:
+                self.launcher.add_file(
+                    arg_name='mask_for_fofc',
+                    file_type='map',
+                    description='Mask used for difference map calculation',
+                    selected=False)
             self.launcher.add_file(
                 arg_name='start_pdb',
                 file_type='pdb',
                 description=self.args.start_pdb.help,
                 selected=True)
+        self.launcher.set_mg_default('Coot')
         self.launcher_dock.show()
 
-
     def set_on_job_finish_custom(self):
         '''
-        Actions to run on job completion.  For now show starting, refined
-        pdb and experimental map.
+        Actions to run on job completion.
         '''
-        # Refined model
+        # Add various output files to launcher
         if hasattr(self.task, 'process_refine'):
+            # Maps
+            refined_maps = os.path.join(
+                self.task.job_location,
+                'diffmap.mtz')
+            if self.args.half_map_refinement.value:
+                desc = 'Sharpened and weighted observed and difference maps (Fo and Fo-Fc)'
+            else:
+                desc = 'Sharpened and weighted difference map (Fo-Fc)'
+            self.launcher.add_file(
+                path=refined_maps,
+                file_type='mtz',
+                description=desc,
+                selected=True)
+            fo_mrc = os.path.join(
+                self.task.job_location,
+                'diffmap_normalized_fo.mrc')
+            if os.path.isfile(fo_mrc):
+                self.launcher.add_file(
+                    path=fo_mrc,
+                    file_type='map',
+                    description='Sharpened and weighted Fo map (normalized within mask)',
+                    selected=False)
+            fofc_mrc = os.path.join(
+                self.task.job_location,
+                'diffmap_normalized_fofc.mrc')
+            if os.path.isfile(fofc_mrc):
+                self.launcher.add_file(
+                    path=fofc_mrc,
+                    file_type='map',
+                    description='Sharpened and weighted Fo-Fc map (normalized within mask)',
+                    selected=False)
+
+            # Models
             if os.path.isfile(self.task.process_refine.cifout_path):
                 self.launcher.add_file(
                     path=self.task.process_refine.cifout_path,
                     file_type='pdb',
                     description='Refined mmCIF file',
                     selected=False)
-            self.launcher.add_file(
-                path=self.task.process_refine.pdbout_path,
-                file_type='pdb',
-                description='Refined PDB file',
-                selected=True)
+            if os.path.isfile(self.task.process_refine.pdbout_path):
+                self.launcher.add_file(
+                    path=self.task.process_refine.pdbout_path,
+                    file_type='pdb',
+                    description='Refined PDB file',
+                    selected=True)
+            expanded_cif = os.path.join(
+                self.task.job_location,
+                'refined_expanded.mmcif')
+            if os.path.isfile(expanded_cif):
+                self.launcher.add_file(
+                    path=expanded_cif,
+                    file_type='pdb',
+                    description='Symmetry-expanded refined PDB file',
+                    selected=False)
+            expanded_pdb = os.path.join(
+                self.task.job_location,
+                'refined_expanded.pdb')
+            if os.path.isfile(expanded_pdb):
+                self.launcher.add_file(
+                    path=expanded_pdb,
+                    file_type='pdb',
+                    description='Symmetry-expanded refined PDB file',
+                    selected=False)
+            
         self.launcher.set_tree_view()
         self.launcher_dock.raise_()
         self.launcher_dock.show()
