@@ -46,7 +46,7 @@ class RefmacTest(unittest.TestCase):
     def test_refmac_window_integration_full(self):
         '''
         Test refmac refinement pipeline via GUI.
-            Long example dataset with hb map, local refinement, 
+            Long example dataset with hb map, masked refinement, 
             with validation.
         '''
         ccpem_utils.print_header(message='Unit test - Refmac full Hb')
@@ -54,7 +54,7 @@ class RefmacTest(unittest.TestCase):
         os.chdir(os.path.dirname(os.path.realpath(__file__)))
         args_path = os.path.join(
             self.test_data,
-            'unittest_args_local_hb_validation.json')
+            'unittest_args_masked_hb_validation.json')
         run_task = refmac_task.Refmac(job_location=self.test_output,
                                       args_json=args_path)
         # Run w/ gui
@@ -69,7 +69,7 @@ class RefmacTest(unittest.TestCase):
         # Wait for results stdout (i.e. last job in pipeline)
         stdout = run_task.pipeline.pipeline[-1][-1].stdout
         assert os.path.basename(stdout) == 'refmacresults_stdout.txt'
-        delay = 5.0
+        delay = 5
         timeout_limit = 1200
         while not job_completed and timeout < timeout_limit:
             print('Refmac running for {0} secs (timeout = {1})'
@@ -92,7 +92,7 @@ class RefmacTest(unittest.TestCase):
         # Read RVAPI table to check end result
         filename = os.path.join(
             self.test_output,
-            'Refmac5_1/rvapi_data/refine_table.0_0.1_1.table')
+            'Refmac_Servalcat_1/rvapi_data/refine_table.0_0.1_1.table')
         with open(filename, 'r') as f:
             page = f.read()
         tree = html.fromstring(page)
@@ -182,7 +182,6 @@ class RefmacTest(unittest.TestCase):
         while not job_completed and timeout < timeout_limit:
             print('Refmac running for {0} secs (timeout = {1})'
                   .format(timeout, timeout_limit))
-            print('\n'.join(sorted(os.listdir(run_task.job_location))))
             time.sleep(delay)
             timeout += delay
             status =\
@@ -200,49 +199,51 @@ class RefmacTest(unittest.TestCase):
         # Check job completed
         assert job_completed
 
+        ###
+#         Removed for now.  Will revisit for future use with servalcat
 
-    def test_refmac_dac_window_integration(self):
-        '''
-        Test refmac DAC refinement pipeline via GUI.
-        '''
-        ccpem_utils.print_header(message='Unit test - Refmac DaC mode')
-        # Unit test args contain relative paths, must change to this directory
-        os.chdir(os.path.dirname(os.path.realpath(__file__)))
-        args_path = os.path.join(self.test_data, 'unittest_args_dac.json')
-        run_task = refmac_task.Refmac(job_location=self.test_output,
-                                      args_json=args_path)
-        print run_task.args.output_args_as_text()
-        # Run w/out gui
-#         run_task.run_task()
-        # Run w/ gui
-        window = refmac_window.Refmac5Window(task=run_task)
-        # Mouse click run
-        QTest.mouseClick(
-            window.tool_bar.widgetForAction(window.tb_run_button),
-            QtCore.Qt.LeftButton)
-        # Wait for run to complete
-        job_completed = False
-        timeout = 0
-        # Global refine stdout (i.e. last job in pipeline)
-        stdout = run_task.pipeline.pipeline[-1][-1].stdout
-        assert os.path.basename(stdout) == 'refinechainbychain_stdout.txt'
-        delay = 5.0
-        timeout_limit = 200
-        while not job_completed and timeout < timeout_limit:
-            print('Refmac DaC running for {0} secs (timeout = {1})'
-                  .format(timeout, timeout_limit))
-            time.sleep(delay)
-            timeout += delay
-            status = process_manager.get_process_status(run_task.pipeline.json)
-            if status == 'finished':
-                if os.path.isfile(stdout):
-                    tail = ccpem_utils.tail(stdout, maxlen=10)
-                    if tail.find('CCP-EM process finished') != -1:
-                        job_completed = True
-        # Check timeout
-        assert timeout < timeout_limit
-        # Check job completed
-        assert job_completed
+#     def test_refmac_dac_window_integration(self):
+#         '''
+#         Test refmac DAC refinement pipeline via GUI.
+#         '''
+#         ccpem_utils.print_header(message='Unit test - Refmac DaC mode')
+#         # Unit test args contain relative paths, must change to this directory
+#         os.chdir(os.path.dirname(os.path.realpath(__file__)))
+#         args_path = os.path.join(self.test_data, 'unittest_args_dac.json')
+#         run_task = refmac_task.Refmac(job_location=self.test_output,
+#                                       args_json=args_path)
+#         print run_task.args.output_args_as_text()
+#         # Run w/out gui
+# #         run_task.run_task()
+#         # Run w/ gui
+#         window = refmac_window.Refmac5Window(task=run_task)
+#         # Mouse click run
+#         QTest.mouseClick(
+#             window.tool_bar.widgetForAction(window.tb_run_button),
+#             QtCore.Qt.LeftButton)
+#         # Wait for run to complete
+#         job_completed = False
+#         timeout = 0
+#         # Global refine stdout (i.e. last job in pipeline)
+#         stdout = run_task.pipeline.pipeline[-1][-1].stdout
+#         assert os.path.basename(stdout) == 'refinechainbychain_stdout.txt'
+#         delay = 5.0
+#         timeout_limit = 200
+#         while not job_completed and timeout < timeout_limit:
+#             print('Refmac DaC running for {0} secs (timeout = {1})'
+#                   .format(timeout, timeout_limit))
+#             time.sleep(delay)
+#             timeout += delay
+#             status = process_manager.get_process_status(run_task.pipeline.json)
+#             if status == 'finished':
+#                 if os.path.isfile(stdout):
+#                     tail = ccpem_utils.tail(stdout, maxlen=10)
+#                     if tail.find('CCP-EM process finished') != -1:
+#                         job_completed = True
+#         # Check timeout
+#         assert timeout < timeout_limit
+#         # Check job completed
+#         assert job_completed
 
 if __name__ == '__main__':
     unittest.main()
