@@ -10,7 +10,7 @@
 import unittest
 import os
 import sys
-import shutil
+import shutil, glob
 import time
 import tempfile
 from PyQt4 import QtGui, QtCore
@@ -79,8 +79,10 @@ class Test(unittest.TestCase):
         assert timeout < 500
         # Check job completed
         assert self.job_completed
-        assert os.path.exists(os.path.join(self.window.task.job_location,
-                                           'flexem_mdl1.clustlog'))
+        pdb_outdir = '.'.join(os.path.basename(run_task.args.input_pdb.value).split('.')[:-1])
+        ribfind_outdir = os.path.join(run_task.job_location,pdb_outdir,'protein')
+        list_clust_files = glob.glob(ribfind_outdir + '/*denclust*')
+        assert len(list_clust_files) > 0
 
 if __name__ == '__main__':
     unittest.main()
