@@ -88,7 +88,7 @@ class ShakeWindow(window_utils.CCPEMTaskWindow):
                     arg_name=None,
                     path=self.task.pdbout_path,
                     file_type='pdb',
-                    description='Output PDB file',
+                    description='Output atomic model',
                     selected=True)
                 self.launcher.set_tree_view()
 
