@@ -8,7 +8,7 @@
 #
 import os
 
-from PyQt4 import QtCore
+from PyQt4 import QtCore, QtGui
 
 from ccpem_gui.utils import window_utils
 from ccpem_core.tasks.tempy.difference_map import difference_map_task,\
@@ -16,8 +16,13 @@ from ccpem_core.tasks.tempy.difference_map import difference_map_task,\
 from ccpem_core.settings import which
 from ccpem_gui.utils import command_line_launch
 from ccpem_core.ccpem_utils import get_test_data_path
+from ccpem_core.ccpem_utils import ccpem_file_types
 from ccpem_core.test_data.tasks.tempy import difference_map as test_data
 
+from ccpem_core.process_manager import job_register
+from ccpem_gui.project_database import sqlite_project_database
+from ccpem_core.tasks.map_process import mapprocess_task
+from ccpem_gui.tasks.map_process import mapprocess_window
 
 # To Do
 # Add spectra plot
@@ -58,6 +63,29 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             required=True,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_input_1)
+        #add mapprocess button
+        self.task.mapprocess_task1 = None
+        self.mapprocess_window1 = None
+        self.mapprocess_list1 = [None,None]
+        self.mp_button1 = QtGui.QRadioButton('Process input map1')
+        self.mp_button1.setToolTip('Process input map1')
+        self.args_widget.args_layout.addWidget(self.mp_button1)
+        self.mp_button1.clicked.connect(lambda: self.handle_mapprocess_task(
+                                                    self.mapprocess_window1))
+        #self.mp_button1.setEnabled(False)
+        #self.set_mapprocess_button(self.mp_button1)
+        self.map_input_1.select_button.clicked.connect(
+                lambda: self.enable_mapprocess_button(self.mp_button1, 
+                                                      self.args.map_path_1.value,
+                                                      self.mapprocess_list1
+                                                      ))
+        
+        self.map_input_1.value_line.editingFinished.connect(
+                lambda: self.enable_mapprocess_button(self.mp_button1, 
+                                                      self.args.map_path_1.value,
+                                                      self.mapprocess_list1
+                                                      ))
+        
         # Map 1 resolution
         self.map_resolution_1 = window_utils.NumberArgInput(
             parent=self,
@@ -65,7 +93,10 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             required=True,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_resolution_1)
-
+        #check for processed map
+        self.map_resolution_1.value_line.editingFinished.connect(
+            self.check_processed_maps)
+        
         # Input map or PDB
         self.map_or_pdb = window_utils.ChoiceArgInput(
             parent=self,
@@ -83,6 +114,27 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             required=False,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_input_2)
+        #add mapprocess button
+        self.task.mapprocess_task2 = None
+        self.mapprocess_window2 = None
+        self.mapprocess_list2 = [None,None]
+        self.mp_button2 = QtGui.QRadioButton('Process input map2')
+        self.mp_button2.setToolTip('Process input map2')
+        self.args_widget.args_layout.addWidget(self.mp_button2)
+        self.mp_button2.clicked.connect(lambda: self.handle_mapprocess_task(
+                                                    self.mapprocess_window2))
+        #self.mp_button2.setEnabled(False)
+        #self.set_mapprocess_button(self.mp_button1)
+        self.map_input_2.select_button.clicked.connect(
+                lambda: self.enable_mapprocess_button(self.mp_button2, 
+                                                      self.args.map_path_2.value,
+                                                      self.mapprocess_list2
+                                                      ))
+        self.map_input_2.value_line.editingFinished.connect(
+                lambda: self.enable_mapprocess_button(self.mp_button2, 
+                                                      self.args.map_path_2.value,
+                                                      self.mapprocess_list2
+                                                      ))
         # Map 2 resolution
         self.map_resolution_2 = window_utils.NumberArgInput(
             parent=self,
@@ -90,6 +142,9 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             required=False,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.map_resolution_2)
+        #check for processed map
+        self.map_resolution_2.value_line.editingFinished.connect(
+            self.check_processed_maps)
         # Input pdb
         self.pdb_input = window_utils.FileArgInput(
             parent=self,
@@ -97,6 +152,30 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             required=False,
             args=self.args)
         self.args_widget.args_layout.addWidget(self.pdb_input)
+        # -> Use Refmac for model-map conversion
+        self.use_refmac = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='use_refmac',
+            args=self.args,
+            label_width=245)
+        self.args_widget.args_layout.addWidget(self.use_refmac)
+        self.use_refmac.value_line.stateChanged.connect(self.set_modelmap)
+        # Ligand library input for Refmac5
+        self.lib_input = window_utils.FileArgInput(
+            parent=self,
+            arg_name='lib_in',
+            args=self.args,
+            file_types=ccpem_file_types.lib_ext,
+            required=False)
+        self.args_widget.args_layout.addWidget(self.lib_input)
+
+        # Disable low pass filter of input maps?
+        self.no_lowpass_filter = window_utils.CheckArgInput(
+            parent=self,
+            arg_name='nofilt',
+            args=self.args)
+        self.args_widget.args_layout.addWidget(self.no_lowpass_filter)
+        #self.no_lowpass_filter.value_line.stateChanged.connect(self.set_lowpass_filter)
         
         # global or local mode
         self.global_or_local = window_utils.ChoiceArgInput(
@@ -120,23 +199,23 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             args=self.args)
         self.local_options_frame.add_extension_widget(self.maskmap)
         
-#         self.use_mpi_input = window_utils.ChoiceArgInput(
-#             parent=self,
-#             arg_name='use_mpi',
-#             required=False,
-#             args=self.args)
-#         self.local_options_frame.add_extension_widget(self.use_mpi_input)
-#         self.use_mpi_input.value_line.currentIndexChanged.connect(
-#             self.set_n_mpi_visible)
-#         
-#         if self.args.n_mpi.value == 1:
-#             self.args.n_mpi.value = QtCore.QThread.idealThreadCount() / 2
-#         self.n_mpi_input = window_utils.NumberArgInput(
-#             parent=self,
-#             arg_name='n_mpi',
-#             required=False,
-#             args=self.args)
-#         self.local_options_frame.add_extension_widget(self.n_mpi_input)
+        self.use_mpi_input = window_utils.ChoiceArgInput(
+            parent=self,
+            arg_name='use_mpi',
+            required=False,
+            args=self.args)
+        self.local_options_frame.add_extension_widget(self.use_mpi_input)
+        self.use_mpi_input.value_line.currentIndexChanged.connect(
+            self.set_n_mpi_visible)
+         
+        if self.args.n_mpi.value == 1:
+            self.args.n_mpi.value = QtCore.QThread.idealThreadCount() / 2
+        self.n_mpi_input = window_utils.NumberArgInput(
+            parent=self,
+            arg_name='n_mpi',
+            required=False,
+            args=self.args)
+        self.local_options_frame.add_extension_widget(self.n_mpi_input)
 
         self.window_size = window_utils.NumberArgInput(
             parent=self,
@@ -160,10 +239,18 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
 #             arg_name='map_alignment',
 #             args=self.args)
 #         options_frame.add_extension_widget(map_alignment)
-        self.set_pdb_or_map_input()
+        self.set_pdb_or_map_input(autoreset=False)
         self.set_mode_options()
         self.set_dust_prob()
-        #self.set_n_mpi_visible()
+        self.enable_mapprocess_button(self.mp_button1, 
+                                     self.args.map_path_1.value,
+                                     self.mapprocess_list1
+                                    )
+        self.enable_mapprocess_button(self.mp_button2, 
+                                     self.args.map_path_2.value,
+                                     self.mapprocess_list2
+                                    )
+        self.set_n_mpi_visible()
         #add files to launcher
         self.add_diffmap_input_files_to_launcher()
 
@@ -223,35 +310,62 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
                 selected=True)
 
 
-    def set_pdb_or_map_input(self):
+    def set_pdb_or_map_input(self,autoreset=True):
         #index = self.args.map_or_pdb_selection.choices.index(
         #    self.args.map_or_pdb_selection.value)
         #sel = self.args.map_or_pdb_selection.choices[index]
         sel = self.args.map_or_pdb_selection.value
         if sel == 'Model':
+            #self.task.args.map_or_pdb_selection.value = 'Model'
             self.map_input_2.required=False
             self.map_input_2.set_required(False)
             self.map_input_2.hide()
+            self.mp_button2.hide()
             self.map_resolution_2.required=False
             self.map_resolution_2.set_required(False)
             self.map_resolution_2.hide()
             self.pdb_input.set_required(True)
             self.pdb_input.show()
+            self.use_refmac.show()
+            self.lib_input.show()
             self.task.args.map_path_2.value = None
-            self.task.args.refscale.value = True
-            self.reference_scaling.value_line.setChecked(True)
-            
+            if autoreset:
+                self.reference_scaling.value_line.setChecked(True)
+                self.task.args.refscale.value = True
+                self.no_lowpass_filter.value_line.setChecked(True)
+                self.task.args.nofilt.value = True
+        
         elif sel == 'Map':
             self.map_input_2.set_required(True)
             self.map_input_2.show()
+            self.mp_button2.show()
             self.map_resolution_2.show()
             self.map_resolution_2.set_required(True)
             self.pdb_input.required=False
             self.pdb_input.set_required(False)
             self.pdb_input.hide()
+            self.use_refmac.hide()
+            self.lib_input.hide()
             self.task.args.pdb_path.value = None
-            self.task.args.refscale.value = False
-            self.reference_scaling.value_line.setChecked(False)
+            if autoreset:
+                self.reference_scaling.value_line.setChecked(False)
+                self.task.args.refscale.value = False
+                self.no_lowpass_filter.value_line.setChecked(False)
+                self.task.args.nofilt.value = False
+            
+#     def set_lowpass_filter(self):
+#         if self.no_lowpass_filter.value_line.isChecked():
+#             self.task.args.nofilt.value = True
+#         else:
+#             self.task.args.nofilt.value = False
+    
+    def set_modelmap(self):
+        if self.use_refmac.value_line.isChecked():
+            self.task.args.use_refmac.value = True
+            self.no_lowpass_filter.value_line.setChecked(False)
+            self.task.args.nofilt.value = False
+        else:
+            self.task.args.use_refmac.value = False
     
     def set_ref_scale(self):
         if self.reference_scaling.value_line.isChecked():
@@ -277,6 +391,8 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             self.window_size.hide()
             #self.use_mpi_input.hide()
             self.task.args.noscale.value = True
+        #check for processed maps
+        self.check_processed_maps()
     
     def set_dust_prob(self):
         if self.args.dust_filter.value:
@@ -292,7 +408,7 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
         
 
     def set_on_job_running_custom(self):
-        if self.args.map_or_pdb_selection.value == 'PDB':
+        if self.args.map_or_pdb_selection.value == 'Model':
             self.launcher.add_file(
                 arg_name='pdb_path',
                 file_type='pdb',
@@ -303,7 +419,7 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
         # Set expected output files as implemented in TEMPy/difference_map
         diff_map1, diff_map2 = self.get_difference_map_names()
         # Add output files to launcher
-        if self.args.map_or_pdb_selection.value == 'PDB':
+        if self.args.map_or_pdb_selection.value == 'Model':
             self.launcher.add_file(
                 arg_name=None,
                 path=self.get_synthetic_map_name(),
@@ -362,9 +478,11 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
         m1_name =  os.path.basename(self.args.map_path_1.value).split('.')[0]
         if self.args.map_or_pdb_selection.value == 'Model':
             m2_name = self.args.pdb_path.value
+            m2_name =  os.path.basename(m2_name).split('.')[0]+'_syn'
         else:
             m2_name = self.args.map_path_2.value
-        m2_name =  os.path.basename(m2_name).split('.')[0]
+            m2_name =  os.path.basename(m2_name).split('.')[0]
+            
         diff_map1 = os.path.join(self.task.job_location,
                                  (m1_name + '-' + m2_name+'_diff.mrc'))
         diff_map2 = os.path.join(self.task.job_location,
@@ -398,7 +516,7 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
                 if os.path.exists(map_):
                     map_path = map_
             map_args += ' ' + map_path
-        if self.args.map_or_pdb_selection.value == 'PDB':
+        if self.args.map_or_pdb_selection.value == 'Model':
             map_args += (' ' + self.args.pdb_path.value)
         else:
             map_args += (' no_pdb')
@@ -410,7 +528,68 @@ class DifferenceMapWindow(window_utils.CCPEMTaskWindow):
             print 'Chimera executable not found (add executable to system PATH)'
         else:
             process.startDetached(chimera_bin, run_args)
-
+        
+    def enable_mapprocess_button(self,mp_button,map_path,list_mapprocess):
+        if map_path is not None and \
+            os.path.isfile(map_path):
+                mp_button.setEnabled(True)
+                list_mapprocess[0], list_mapprocess[1] = \
+                    self.generate_mapprocess_task(map_path)
+                self.task.mapprocess_task1,self.mapprocess_window1 = \
+                    self.mapprocess_list1[0],self.mapprocess_list1[1]
+                self.task.mapprocess_task2,self.mapprocess_window2 = \
+                    self.mapprocess_list2[0],self.mapprocess_list2[1]
+        else:
+            mp_button.setEnabled(False)
+    
+    def check_mapprocess_button(self,mp_button,map_path):
+        if map_path is not None and \
+            os.path.isfile(map_path):
+                mp_button.setEnabled(True)
+        else:
+            mp_button.setEnabled(False)
+        
+    def generate_mapprocess_task(self,map_path,
+                                 db_inject=None, job_title=None):
+        if self.task.database_path is not None:
+            path = os.path.dirname(self.task.database_path)
+            db_inject = sqlite_project_database.CCPEMInjector(
+                database_path=self.task.database_path)
+        # Set task args
+        args = mapprocess_task.MapProcess().args
+        #args.job_title.value = job_title
+        args.map_path.value = map_path
+        #args_json = args.output_args_as_json()
+        task = mapprocess_task.MapProcess(
+            parent=self,
+            args=args,
+            database_path=self.task.database_path)
+            #job_location=job_location)
+        window = mapprocess_window.MapProcessWindow(
+            parent=self,
+            task=task)
+        return task, window
+    
+    def handle_mapprocess_task(self,window):
+        if not window is None: window.show()
+        
+    def check_processed_maps(self):
+        if self.args.map_path_1.value is not None:
+            processed_map1_path = os.path.splitext(
+                                os.path.basename(self.args.map_path_1.value))[0] \
+                                +'_processed.mrc'
+            
+            if os.path.isfile(processed_map1_path) and \
+                self.task.mapprocess_task1 is not None:
+                self.map_input_1.value_line.setText(processed_map1_path)
+        
+        if self.args.map_path_2.value is not None:
+            processed_map2_path = os.path.splitext(
+                            os.path.basename(self.args.map_path_2.value))[0] \
+                            +'_processed.mrc'
+            if os.path.isfile(processed_map2_path) and \
+                self.task.mapprocess_task2 is not None:
+                self.map_input_2.value_line.setText(processed_map2_path)
 
 def main():
     '''
