@@ -46,7 +46,7 @@ class PBBDatasets(object):
 
 class PDBInput(QtGui.QWidget):
     def __init__(self,
-                 label='PDB',
+                 label='Atomic model',
                  pdb_path=None,
                  chains=None,
                  parent=None):
@@ -58,7 +58,7 @@ class PDBInput(QtGui.QWidget):
         label_width = 150
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
-        self.setToolTip('Add PDB')
+        self.setToolTip('Add model')
 
         # PDB
         pdb_box = QtGui.QHBoxLayout()
@@ -346,7 +346,8 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
             parent=self,
             arg_name='map_contour_level',
             required=False,
-            args=self.args)
+            args=self.args,
+            decimals=5)
         advanced_options_frame.add_extension_widget(self.input_contour_level)
         self.title_input.value_line.editingFinished.connect(
             self.set_auto_contour)
@@ -355,7 +356,7 @@ class GlobScoreWindow(window_utils.CCPEMTaskWindow):
     def set_auto_contour(self):
         if self.args.auto_contour_level.value:
             self.input_contour_level.hide()
-            self.task.args.map_contour_level.value = self.args.map_contour_level.value = 0.0
+            self.task.args.map_contour_level.value = self.args.map_contour_level.value = None
         else:
             self.input_contour_level.show()
             self.task.args.map_contour_level.value = self.args.map_contour_level.value
