@@ -46,7 +46,7 @@ class PBBDatasets(object):
 
 class PDBInput(QtGui.QWidget):
     def __init__(self,
-                 label='PDB',
+                 label='Atomic model',
                  pdb_path=None,
                  chains=None,
                  parent=None):
@@ -58,7 +58,7 @@ class PDBInput(QtGui.QWidget):
         label_width = 150
         self.layout = QtGui.QVBoxLayout()
         self.setLayout(self.layout)
-        self.setToolTip('Add PDB')
+        self.setToolTip('Add model')
 
         # PDB
         pdb_box = QtGui.QHBoxLayout()
@@ -544,18 +544,21 @@ class SMOCMapWindow(window_utils.CCPEMTaskWindow):
         if not isinstance(pdbs, list):
             pdbs = [pdbs]
         list_pdbs = []
+        l = 1
         for pdb in pdbs:
+            pdb_id = os.path.splitext(os.path.basename(pdb))[0]+'_'+str(l)
             scored_pdb = os.path.join(self.task.job_location,
-                        os.path.basename(str(pdb)).split('.')[0]+'_smoc.pdb')
+                        pdb_id+'_smoc.pdb')
             if os.path.isfile(scored_pdb):
                 list_pdbs.append(scored_pdb)
-                
+            l += 1
         #include the map
         list_pdbs.append(self.args.map_path.value)
         pdb_str = ' '.join(list_pdbs)
         chimera_command = '{} {} bfactor' .format(
             str(chim_script),
             str(pdb_str))
+        
         arg_list_chimera = ['--script', '%s' % (chimera_command)]
         process = QtCore.QProcess()
         chimera_bin = which('chimera')
@@ -586,6 +589,7 @@ class SMOCMapWindow(window_utils.CCPEMTaskWindow):
             'rvapi_data/index.html')
         if os.path.exists(rv_index):
             self.rv_view = QtWebKit.QWebView()
+            rvapi_layout = QtGui.QHBoxLayout()
             assert os.path.exists(rv_index)
             self.rv_view.load(QtCore.QUrl(rv_index))
             results_dock_layout = QtGui.QVBoxLayout()
@@ -599,8 +603,11 @@ class SMOCMapWindow(window_utils.CCPEMTaskWindow):
             self.results_dock.setWidget(results_dock_widget)#self.rv_view)
             self.tabifyDockWidget(self.setup_dock, self.results_dock)
             chimera_view_button = self.set_chimera_button()
+            self.rv_view.setMinimumHeight(300)
+            self.rv_view.setLayout(rvapi_layout)
             results_dock_layout.addWidget(chimera_view_button)
             results_dock_layout.addWidget(self.rv_view)
+            results_dock_layout.addStretch(1)
             self.results_dock.raise_()
             
     def set_bokeh_ui(self):
