@@ -31,6 +31,7 @@ class LaunchFile(object):
                  path=None,
                  group='Files',
                  selected=True,
+                 checkable=True,
                  display_from='running',
                  chimera_script=None):
         self.arg_name = arg_name
@@ -43,6 +44,7 @@ class LaunchFile(object):
             self.selected = 2
         else:
             self.selected = 0
+        self.checkable = checkable
         self.display_from = display_from
         assert self.display_from in process_manager.statuses
 
@@ -62,11 +64,13 @@ class CCPEMLauncher(QtGui.QGroupBox):
     '''
     View / launch job files.
     '''
-    all_mg_progs = {'ccp4mg':'CCP4mg',
-                    'coot':'Coot',
-                    'chimera':'Chimera',
+    # ChimeraX can be installed as 'chimerax' or 'ChimeraX'
+    all_mg_progs = {'ccp4mg': 'CCP4mg',
+                    'coot': 'Coot',
+                    'chimera': 'Chimera',
                     'pymol': 'PyMOL',
-                    'ChimeraX':'ChimeraX'}
+                    'ChimeraX': 'ChimeraX',
+                    'chimerax': 'ChimeraX'}
 
     def __init__(self,
                  parent,
@@ -86,8 +90,7 @@ class CCPEMLauncher(QtGui.QGroupBox):
 
         self.mg_files = {'map': [],
                          'mtz': [],
-                         'pdb': [],
-                         'cif': []}
+                         'pdb': []}
 
         # Setup layout
         self.layout = QtGui.QVBoxLayout()
@@ -106,6 +109,8 @@ class CCPEMLauncher(QtGui.QGroupBox):
             menu.addAction('Coot', self.set_coot_default)
         if 'Chimera' in self.mg_progs:
             menu.addAction('Chimera', self.set_chimera_default)
+        if 'ChimeraX' in self.mg_progs:
+            menu.addAction('ChimeraX', self.set_chimera_x_default)
         if 'CCP4mg' in self.mg_progs:
             menu.addAction('CCP4mg', self.set_ccp4mg_default)
         if 'PyMOL' in self.mg_progs:
@@ -142,7 +147,8 @@ class CCPEMLauncher(QtGui.QGroupBox):
         self.tree_widget.doubleClicked.connect(self.on_double_click)
 
     def on_mg_button_release(self):
-        print '\n\ntest release'
+        pass
+        # print '\n\ntest release'
 
     def set_message_label(self, message):
         self.message_label.setText(message)
@@ -163,6 +169,9 @@ class CCPEMLauncher(QtGui.QGroupBox):
     def set_chimera_default(self):
         self.set_mg_default('Chimera')
 
+    def set_chimera_x_default(self):
+        self.set_mg_default('ChimeraX')
+
     def set_ccp4mg_default(self):
         self.set_mg_default('CCP4mg')
 
@@ -176,6 +185,7 @@ class CCPEMLauncher(QtGui.QGroupBox):
                  path=None,
                  display_from='running',
                  selected=True,
+                 checkable=True,
                  group='Files'):
         lf = LaunchFile(
             arg_name=arg_name,
@@ -184,6 +194,7 @@ class CCPEMLauncher(QtGui.QGroupBox):
             description=description,
             display_from=display_from,
             selected=selected,
+            checkable=checkable,
             group=group)
         append = True
 
@@ -245,6 +256,10 @@ class CCPEMLauncher(QtGui.QGroupBox):
                         file_info)
                     file_item.ccpem_file = ccpem_file
                     file_item.setCheckState(0, ccpem_file.selected)
+                    
+                    if not ccpem_file.checkable:
+                        file_item.setFlags(
+                            file_item.flags() & ~QtCore.Qt.ItemIsUserCheckable) 
                     self.tree_widget.expandItem(file_item)
                     self.tree_widget.expandItem(group_item)
 
@@ -295,8 +310,7 @@ class CCPEMLauncher(QtGui.QGroupBox):
     def clear_mg_files(self):
         self.mg_files = {'map': [],
                          'mtz': [],
-                         'pdb': [],
-                         'cif': []}
+                         'pdb': []}
 
     def launch_mg_viewers(self,
                           mg_viewer='Default',
@@ -340,9 +354,7 @@ class CCPEMLauncher(QtGui.QGroupBox):
         for map_ in self.mg_files['map']:
             args += ['--map', map_]
         for mtz in self.mg_files['mtz']:
-            args += ['--data', mtz]
-        for cif in self.mg_files['cif']:
-            args += ['--cif', cif]
+            args += ['--auto', mtz]
         gui_process.run_coot(args=args)
 
     def run_selected_chimera(self):
@@ -351,8 +363,6 @@ class CCPEMLauncher(QtGui.QGroupBox):
             args.append(pdb)
         for map_ in self.mg_files['map']:
             args.append(map_)
-        for cif in self.mg_files['cif']:
-            args.append(cif)
         if len(self.mg_files['mtz']) > 0:
             print 'Warning: cannot open MTZ files in Chimera'
         if self.task_window is not None:
@@ -366,8 +376,6 @@ class CCPEMLauncher(QtGui.QGroupBox):
             args.append(pdb)
         for map_ in self.mg_files['map']:
             args.append(map_)
-        for cif in self.mg_files['cif']:
-            args.append(cif)
         if len(self.mg_files['mtz']) > 0:
             print 'Warning: cannot open MTZ files in Chimera'
         if self.task_window is not None:
@@ -387,8 +395,6 @@ class CCPEMLauncher(QtGui.QGroupBox):
             args.append(map_)
         for mtz in self.mg_files['mtz']:
             args.append(mtz)
-        for cif in self.mg_files['cif']:
-            args.append(cif)
         gui_process.run_ccp4mg(args=args)
 
     def run_selected_pymol(self):
@@ -399,6 +405,4 @@ class CCPEMLauncher(QtGui.QGroupBox):
             args.append(map_)
         for mtz in self.mg_files['mtz']:
             args.append(mtz)
-        for cif in self.mg_files['cif']:
-            args.append(cif)
         gui_process.run_pymol(args=args)
