@@ -31,7 +31,7 @@ def run_terminal(working_directory=None):
                 elif 'konsole' in command:
                     args = '--workdir {0}'.format(working_directory)
                 elif 'xterm' in command:
-                    print 'Xterm not terminal launch surported'
+                    print 'Xterm terminal launch not supported'
                     # Can't reliably pass working directory to xterm
                     pass
             run_detatched_process(command=command,
@@ -111,14 +111,17 @@ def run_chimera_x(args=None):
 
     args must be a list or None
     '''
-    chimera_command = settings.which('ChimeraX')
-    if chimera_command is None:
+    # ChimeraX can be installed as 'chimerax' or 'ChimeraX'
+    chimera_x_command = settings.which('ChimeraX')
+    if chimera_x_command is None:
+        chimera_x_command = settings.which('chimerax')
+    if chimera_x_command is None:
         text = 'Warning: ChimeraX not found'
         ccpem_utils.print_error(message=text)
     else:
         if args is None:
             args = []
-        run_detatched_process(command=chimera_command,
+        run_detatched_process(command=chimera_x_command,
                               args=args)
 
 def run_pymol(args=None):
