@@ -145,7 +145,8 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
 
     def __init__(self,
                  parent=None,
-                 task=None):
+                 task=None,
+                 display_name=None):
         super(CCPEMTaskWindow, self).__init__(parent)
         self.task = task
         self.args = self.task.args
@@ -155,6 +156,7 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.job_status_timer = QtCore.QTimer()
         self.job_status_timer.timeout.connect(self.check_job_status)
         self.rv_view = None
+        self.display_name = display_name
         # Set toolbar
         self.set_toolbar()
         # Set dock
@@ -307,7 +309,11 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         return layout
 
     def set_window_title(self):
-        window_title = 'CCP-EM | ' + self.task.task_info.name
+        if self.display_name is None:
+            name = self.task.task_info.name
+        else:
+            name = self.display_name
+        window_title = 'CCP-EM | ' + name
         if self.args.job_title.value is not None:
             if self.args.job_title.value != 'None':
                 window_title += ' | '
@@ -361,6 +367,15 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 'Chimera',
                 self.run_chimera)
         #
+        if (settings.which(program='ChimeraX') is not None
+            or settings.which(program='chimerax') is not None):
+            chimera_x_icon = os.path.join(icon_utils.get_other_icons_path(),
+                                          'ChimeraX_32x32.png')
+            self.tb_chimera_x_button = self.tool_bar.addAction(
+                QtGui.QIcon(chimera_x_icon),
+                'ChimeraX',
+                self.run_chimera_x)
+        #
         if settings.which(program='ccp4mg') is not None:
             ccp4mg_icon = os.path.join(icon_utils.get_other_icons_path(),
                                        'ccp4mg_32x32.png')
@@ -377,14 +392,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
                 'PyMOL',
                 self.run_pymol)
         #
-        if settings.which(program='ChimeraX') is not None:
-            pymol_icon = os.path.join(icon_utils.get_other_icons_path(),
-                                      'ChimeraX_32x32.png')
-            self.tb_pymol_button = self.tool_bar.addAction(
-                QtGui.QIcon(pymol_icon),
-                'ChimeraX',
-                self.run_chimera_x)
-        #
         self.tool_bar.addSeparator()
         #
         terminal_icon = os.path.join(icon_utils.get_icons_path(),
@@ -430,50 +437,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         self.status_action = self.tool_bar.addWidget(self.status_widget)
         self.addToolBar(self.tool_bar)
 
-    def check_error_logs(self):
-        '''
-        Check error log files and display.
-        '''
-        for jobs in self.task.pipeline.pipeline:
-            for job in jobs:
-                if job.stderr is not None:
-                    statinfo = os.stat(job.stderr)
-                    if statinfo.st_size > 0:
-                        # Show as dock tab
-                        dock_name = 'Error: ' + job.name
-                        self.set_error_log_dock(log_path=job.stderr,
-                                                dock_name=dock_name)
-                        # Add to launcher
-                        self.launcher.add_file(
-                            arg_name=None,
-                            file_type='standard',
-                            path=job.stderr,
-                            description='Error file',
-                            display_from='running',
-                            selected=True)
-
-    def set_error_log_dock(self, log_path, dock_name):
-        '''
-        Dock to display stdout_dockempeak.txt.
-        '''
-        # Set peak browser
-        log_widget = QtGui.QWidget()
-        log_widget_layout = QtGui.QVBoxLayout()
-        # Setup layout
-        log_tb = ccpem_widgets.CCPEMTextBrowser(
-            filepath=log_path,
-            parent=self)
-        log_widget_layout.addWidget(log_tb)
-        log_widget.setLayout(log_widget_layout)
-        # Set peak dock
-        log_dock = QtGui.QDockWidget(dock_name,
-                                     self,
-                                     QtCore.Qt.Widget)
-        log_dock.setWidget(log_widget)
-        log_dock.setVisible(True)
-        log_dock.setToolTip('View log file')
-        self.tabifyDockWidget(self.launcher_dock, log_dock)
-
     def run_coot(self):
         '''
         Run coot viewer.
@@ -724,7 +687,7 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
     def set_on_job_running_custom(self):
         pass
 
-    def set_on_job_finish(self, show_error_logs=True):
+    def set_on_job_finish(self):
         '''
         Actions to run on job completion.
         '''
@@ -745,8 +708,6 @@ class CCPEMTaskWindow(QtGui.QMainWindow):
         if len(self.launcher.files) > 0:
             self.launcher_dock.setVisible(True)
             self.launcher.set_tree_view()
-        if show_error_logs:
-            self.check_error_logs()
         self.set_on_job_finish_custom()
 
     def set_on_job_finish_custom(self):
