@@ -10,8 +10,8 @@ import sys
 import os
 
 def load_rigid(path,mdl,sel_rigid,rand_rigid,rigid_filename,nochain=False):
-
-    in_file = open(os.path.join(path,rigid_filename),"r")
+    
+    in_file = open(rigid_filename,"r")
     
     flag = 0
     while True:
@@ -27,7 +27,7 @@ def load_rigid(path,mdl,sel_rigid,rand_rigid,rigid_filename,nochain=False):
         else:
             resnum = in_line.split()
             ##remove chain id for single chain
-            if nochain: resnum = [el.split(':')[0] for el in resnum] #added
+            #resnum = [el.split(':')[0] for el in resnum] #added
             i=0
             list=selection()
             if resnum[-1] == 'nr':
