@@ -16,7 +16,7 @@ def str_object(pdbfile):
     '''
     if pdbfile.rsplit('.')[-1] == 'pdb':
         parser = PDBParser()
-    elif pdbfile.rsplit('.')[0] == 'cif':
+    elif pdbfile.rsplit('.')[-1] == 'cif' or pdbfile.rsplit('.')[-1] == 'mmcif':
         parser = MMCIFParser()
     else:
         print 'Not a valid PDB format'
@@ -941,7 +941,7 @@ def main_protein(prot_structure,protsec,prot_cutoff):
     if not os.path.exists(outPath):
         os.makedirs(outPath)
     file1_base = outPath+'/'+file1_base
-    os.system('cp '+ sys.argv[1] + ' ' + outPath +'/.')
+    os.system("cp '"+ sys.argv[1] + "' '" + outPath +"/.'")
     cutoff = prot_cutoff
     obj.find_loop()
     hx = []
@@ -1297,7 +1297,7 @@ def main_rna(structure_file,rnasec,rna_cutoff):
     if not os.path.exists(outPath):
         os.makedirs(outPath)
     file1_base = outPath+'/'+file1_base
-    os.system('cp '+ sys.argv[1] + ' ' + outPath +'/.')
+    os.system("cp '"+ sys.argv[1] + "' '" + outPath +"/.'")
     cutoff = rna_cutoff
     #print "done loops initilization"
     hx = []
