@@ -1,8 +1,8 @@
 !=******************************************************************************
-!=* ShapeMv1.0.f90                  		          AUTHOR: A.ROSEMAN    *
+!=* ShapeEMv1.4.f90                  		          AUTHOR: A.ROSEMAN    *
 !=*                                    		                               *
 !=*									       *
-!=* ShapeM - Programs		       					       *
+!=* ShapeEM - Programs		       					       *
 !=*									       *
 !=* ShapeM is a set of software programs to match 3D density object shapes.    *
 !=* Specifically, it has been designed to locate known molecular shapes within *
@@ -51,6 +51,9 @@
 !ShapeMv1.0
 !v1.3c shift cccmap, circular
 
+!v1.4, padding to eliminate border artefacts
+
+! to add in still: writemrcmap2(), writes part of map, without the borde
 
 ! 1. read map, search object, mask, angles
 ! 2. rotate sobj,mask, calc flcf, store max, loop over angles
@@ -69,7 +72,7 @@
 
 
 
-        program ShapeM
+        program ShapeEM
   
   
         Use  image_arrays2
@@ -96,8 +99,8 @@
 	character*3 num
 	logical t,f
 	real x,y,z,maskth
-	integer lx,ly,lz,bnx,bny,bnz
-	integer nm8,numatoms
+	integer lx,ly,lz,bnx,bny,bnz,pdx,pdy,pdz
+	integer nm8,numatoms,pdnxp1,pdnxm1,pdnym1,pdnzm1,pdnxp2
 	real*8 summap,sumcccs,sumnumccc,stdccc
 	real cx,cy,cz
 	real deg,rad
@@ -111,7 +114,7 @@
 	t=.true.
 	f=.false.
 
-        print*, 'ShapeM, V1.3c'
+        print*, 'ShapeM, V1.4d'
         print*, '============='
 
 
@@ -140,6 +143,10 @@
         read (5,30) runcode
 30      format (I3)
 
+! for parallel operation: enter the angle file range.
+! GUI will allow easy, flexible way to submit range of jobs,
+! and then combine the outmaps.
+
         pdbfile = 'com'//num(runcode)//'.pdb'       
 
 33	print*,'Origin of rotation at Center-of-mass of search object, or the Box center.  Type> C or B'
@@ -175,16 +182,6 @@
 
         nxp1=nx+1
         nxp2=nx+2
-        
-!C allocate  image_files 
-        allocate (map(0:nxp1,0:nym1,0:nzm1), sobj(0:nxp1,0:nym1,0:nzm1))
-        allocate (mask(0:nxp1,0:nym1,0:nzm1),pmask(0:nxp1,0:nym1,0:nzm1))
-        allocate (commap(0:nxp1,0:nym1,0:nzm1),cmap(0:nxm1,0:nym1,0:nzm1))
-        
-        allocate (rotsobj(0:nxp1,0:nym1,0:nzm1),rotmask(0:nxp1,0:nym1,0:nzm1))
-        allocate (AA(0:nxp1,0:nym1,0:nzm1))
-	   
-        CALL READMRCMAP(1,filename,map,nx,ny,nz,T,F,T,err) !read, is open, dont close, add 2 bytes
 
 
         CALL IMOPEN(2,sobjfilename,'RO')
@@ -192,15 +189,38 @@
 	lx=nx
 	ly=ny
 	lz=nz
+        
+        pdx = bnx + lx
+  	pdy = bny + ly
+	pdz = bnz + lz
+
+        pdnxp1 = pdx+1
+        pdnxp2 = pdx+2
+        pdnxm1 = pdx-1
+  	pdnym1 = pdy-1
+	pdnzm1 = pdz-1
+
+!C allocate  image_files 
+        allocate (map(0:pdnxp1,0:pdnym1,0:pdnzm1), sobj(0:pdnxp1,0:pdnym1,0:pdnzm1))
+        allocate (mask(0:pdnxp1,0:pdnym1,0:pdnzm1),pmask(0:pdnxp1,0:pdnym1,0:pdnzm1))
+        allocate (commap(0:pdnxp1,0:pdnym1,0:pdnzm1),cmap(0:pdnxm1,0:pdnym1,0:pdnzm1))
+        
+        allocate (rotsobj(0:pdnxp1,0:pdnym1,0:pdnzm1),rotmask(0:pdnxp1,0:pdnym1,0:pdnzm1))
+        allocate (AA(0:pdnxp1,0:pdnym1,0:pdnzm1))
+	   
+        map=0
+        CALL READMRCMAP2(1,filename,map,pdx,pdy,pdz,bnx,bny,bnz,T,F,T,err) !read, is open, dont close, add 2 bytes
 
 
-        CALL READMRCMAP2(2,sobjfilename,sobj,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes 
+        sobj=0
 
+        CALL READMRCMAP2(2,sobjfilename,sobj,pdx,pdy,pdz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes 
 
+        mask=0
 
         CALL IMOPEN(2,maskfilename,'RO')
         CALL IRDHDR(2,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
-        CALL READMRCMAP2(2,maskfilename,mask,bnx,bny,bnz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes  
+        CALL READMRCMAP2(2,maskfilename,mask,pdx,pdy,pdz,lx,ly,lz,F,T,T,err) !read, is open,  close, add 2 bytes  
 	
 
         CALL IRDHDR(1,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
@@ -209,7 +229,7 @@
 !make mask binary
 
 ! vs maskth
-	where (mask.ge.0.0) 
+	where (mask.ge.maskth) 
 			  pmask=1.0
 	elsewhere
 			pmask=0.0
@@ -217,7 +237,7 @@
 	
 	nm = int(sum(pmask(0:nxp1,0:nym1,0:nzm1)))			!number of non zero mask points
 
-	sobj=sobj*mask	  !this will speed up the rotations, uninteresting regions are now 0.
+	sobj=sobj*pmask	  !this will speed up the rotations, uninteresting regions are now 0.
 	
 	print*, nm
 	
@@ -227,9 +247,9 @@
         where (sobj.lt.0) commap=0  ! eliminate negative regions
 
 ! v1.3 on 27-5-15
-	cx=lx/2+1
-	cy=ly/2+1
-	cz=lz/2+1
+	cx=int(lx/2)
+	cy=int(ly/2)
+	cz=int(lz/2)
 	r=nx/2-1
 
 ! v1.3 on 27-5-15
@@ -330,9 +350,9 @@
 !C ***********************************************
 !C  set up and open  output image_files
 
-        allocate (cccmaxmap(0:nxp1,0:nym1,0:nzm1),phimap(0:nxp1,0:nym1,0:nzm1))
-        allocate (thetamap(0:nxp1,0:nym1,0:nzm1), psimap(0:nxp1,0:nym1,0:nzm1))
-        allocate (cnv2(0:nxp1,0:nym1,0:nzm1),lcf1(0:nxp1,0:nym1,0:nzm1),scalemap(0:nxp1,0:nym1,0:nzm1))          
+        allocate (cccmaxmap(0:pdnxp1,0:pdnym1,0:pdnzm1),phimap(0:pdnxp1,0:pdnym1,0:pdnzm1))
+        allocate (thetamap(0:pdnxp1,0:pdnym1,0:pdnzm1), psimap(0:pdnxp1,0:pdnym1,0:pdnzm1))
+        allocate (cnv2(0:pdnxp1,0:pdnym1,0:pdnzm1),lcf1(0:pdnxp1,0:pdnym1,0:pdnzm1),scalemap(0:pdnxp1,0:pdnym1,0:pdnzm1))          
 
 !C ***********************************************
 	cccmaxmap = -1.2
@@ -360,25 +380,29 @@
 ! fft map, mapsq, 
 ! A,AA     
 		print*, "001"
-		nm8=nx*ny*nz
+	!	nm8=nx*ny*nz
+		nm8 =pdx*pdy*pdz
 		print*,nm,nm8
 
 		val=minval(map(0:nxm1,0:nym1,0:nzm1))
 		print*,val
 		map(0:nxm1,0:nym1,0:nzm1)=map(0:nxm1,0:nym1,0:nzm1)-val
-		call msdset(map,nx,ny,nz,nm8,val,err)
+!		map = map -val
+		call msdset(map,pdx,pdy,pdz,nm8,val,err)
 		print*,nm,nm8		
-		call msd(map,nx,ny,nz,nm8,meanmap,stdmap,err)
+		call msd(map,pdx,pdy,pdz,nm8,meanmap,stdmap,err)
 		PRINT*,'MSD t ',meanmap,stdmap
 		
 		print*,val
 		AA=map*map
-		call msd(AA,nx,ny,nz,nm8,meanaa,stdaa,err)
+		call msd(AA,pdx,pdy,pdz,nm8,meanaa,stdaa,err)
 		print*,nm8,meanaa,stdaa,err
 		print*,NXP2,NX,NY,NZ
-                CALL BCKW_FT(map,NXP2,NX,NY,NZ)
+		print*,"hello"
+		print*,pdNXP2,pdX,pdY,pdZ
+                CALL BCKW_FT(map,pdNXP2,pdX,pdY,pdZ)
                 print*,'ft map done'
-		CALL BCKW_FT(AA,NXP2,NX,NY,NZ)
+		CALL BCKW_FT(AA,pdNXP2,pdX,pdY,pdZ)
 		print*,'ft aa done'
 	print*,'done fts'
 
@@ -426,9 +450,10 @@
 			do sloop=0,ssteps
 			iscale=sloop*s3+s1
        			print*,iscale,sloop,ssteps
-       			call rotobjS(sobj,rotsobj,psi,theta,phi,nx,ny,nz,comx,comy,comz,iscale)
-       		
-  		        call rotobjS(mask,rotmask,psi,theta,phi,nx,ny,nz,comx,comy,comz,iscale)
+			rotsobj=0
+       			call rotobjSL(sobj,rotsobj,psi,theta,phi,pdx,pdy,pdz,comx,comy,comz,iscale,lx,ly,lz)
+       		        rotmask=0
+  		        call rotobjSL(pmask,rotmask,psi,theta,phi,pdx,pdy,pdz,comx,comy,comz,iscale,lx,ly,lz)
 	
 !make mask binary, get rid of feeble edge points
 			where (rotmask.ge.0.5)  
@@ -444,18 +469,18 @@
 			call msd(rotmask,nx,ny,nz,nm8,meanmask,stdmask,err)
 	
 		ni=nx*ny*nz
-	 	call msdset(rotsobj,nx,ny,nz,nm,val,err)	!set the msd of sobj to 0,1
+	 	call msdset(rotsobj,pdx,pdy,pdz,nm,val,err)	!set the msd of sobj to 0,1
 			
 		rotsobj=rotsobj*rotmask				! zero background region
 		
 			
-		call msd(rotsobj,nx,ny,nz,nm,meanrot,stdrot,err)
+		call msd(rotsobj,pdx,pdy,pdz,nm,meanrot,stdrot,err)
 
  	  		    
-    		    CALL BCKW_FT(rotsobj,NXP2,NX,NY,NZ)
-		    CALL BCKW_FT(rotmask,NXP2,NX,NY,NZ)
+    		    CALL BCKW_FT(rotsobj,pdNXP2,pdX,pdY,pdZ)
+		    CALL BCKW_FT(rotmask,pdNXP2,pdX,pdY,pdZ)
 	   
-      		    call FLCF3D(nx,ny,nz,nm) ! map, mapsq,     
+      		    call FLCF3D(pdx,pdy,pdz,nm) ! map, mapsq,     
 				print*,'done flcf',b
 				
 				
@@ -482,26 +507,26 @@
 
 	CALL IMOPEN(7,'cccmaxmap'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(7,1)
-	CALL WRITEMRCMAP(7,cccmaxmap,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
+	CALL WRITEMRCMAP2(7,cccmaxmap,pdx,pdy,pdz,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
 
 	CALL IMOPEN(8,'phimap'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(8,1)
-        CALL WRITEMRCMAP(8,phimap,nx,ny,nz,sampling,err)
+        CALL WRITEMRCMAP2(8,phimap,pdx,pdy,pdz,nx,ny,nz,sampling,err)
 	        
 	CALL IMOPEN(9,'thetamap'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(9,1)
-	CALL WRITEMRCMAP(9,thetamap,nx,ny,nz,sampling,err)
+	CALL WRITEMRCMAP2(9,thetamap,pdx,pdy,pdz,nx,ny,nz,sampling,err)
 
         CALL IMOPEN(10,'psimap'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(10,1)
-	CALL WRITEMRCMAP(10,psimap,nx,ny,nz,sampling,err)
+	CALL WRITEMRCMAP2(10,psimap,pdx,pdy,pdz,nx,ny,nz,sampling,err)
 
 	CALL IMOPEN(11,'scalemap'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(11,1)
-	CALL WRITEMRCMAP(11,scalemap,nx,ny,nz,sampling,err)
+	CALL WRITEMRCMAP2(11,scalemap,pdx,pdy,pdz,nx,ny,nz,sampling,err)
 	
 	
-	val=maxval(cccmaxmap)
+	val=maxval(cccmaxmap(0:nxm1,0:nym1,0:nzm1))
 	print*,'max ccc is :',val
 	print*,'at ', maxloc(cccmaxmap)
 	vec=maxloc(cccmaxmap)
@@ -522,18 +547,25 @@
 
 ! write a shifted cccmaxmap
      
-	cmap(0:nxm1, 0:nym1, 0:nzm1)  = cccmaxmap(0:nxm1, 0:nym1, 0:nzm1 )	
-        cmap= cshift(cmap,shift=comix,dim=1)
-        cmap= cshift(cmap,shift=comiy,dim=2)
-        cmap= cshift(cmap,shift=comiz,dim=3)
+	cmap(0:pdnxm1, 0:pdnym1, 0:pdnzm1)  = cccmaxmap(0:pdnxm1, 0:pdnym1, 0:pdnzm1 )	
+        cmap= cshift(cmap,shift=-comix,dim=1)
+        cmap= cshift(cmap,shift=-comiy,dim=2)
+        cmap= cshift(cmap,shift=-comiz,dim=3)
 
 	cccmaxmap(0:nxm1, 0:nym1, 0:nzm1)  = cmap(0:nxm1, 0:nym1, 0:nzm1 )	
 
 	CALL IMOPEN(7,'cccmaxmap-shifted'//num(runcode)//'.mrc','UNKNOWN')
         CALL ITRHDR(7,1)
-	CALL WRITEMRCMAP(7,cccmaxmap,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
-
+	CALL WRITEMRCMAP2(7,cccmaxmap,pdx,pdy,pdz,nx,ny,nz,sampling,err) !open already, close it, subtract 2 from nx
 
+	val=maxval(cccmaxmap(0:nxm1,0:nym1,0:nzm1))
+        print*,"corrected max ccc =",val
+ 	print*, "at ", maxloc(cccmaxmap(0:nxm1,0:nym1,0:nzm1))
+! maxloc doesn't recognise subregion
+	ix=vec(1)-1
+	iy=vec(2)-1
+	iz=vec(3)-1
+        print*,ix,iy,iz
 
 
 	goto 999
@@ -615,7 +647,7 @@
  
         Use mrc_image
 
-         INTEGER  X,Y,Z,err
+         INTEGER  X,Y,Z,err,lx,ly,lz
          INTEGER  stream, IX,IY,IZ,xm1
          real, DIMENSION (0:X+1,0:Y-1,0:Z-1) :: map  
          INTEGER S(3),S1
@@ -627,21 +659,21 @@
        		       CALL IRDHDR(stream,NXYZ,MXYZ,MODE,DMIN,DMAX,DMEAN)
 	  endif
             
-         
+         map=0
       
       
 !     read in file 
 
-      DO 1350 IZ = 0,nz-1
-          DO 1350 IY = 0,ny-1
+      DO 1350 IZ = 0,lz-1
+          DO 1350 IY = 0,ly-1
             CALL IRDLIN(stream,ALINE,*1998)
-            DO 1300 IX = 0,nx-1       
+            DO 1300 IX = 0,lx-1       
        !     print*,ix
                 map(ix,iy,iz) = ALINE(IX+1)
 1300         CONTINUE  
 	if(add2) then  
-     		       map(X+0,iy,iz)=0
-      		       map(X+1,iy,iz)=0
+     		       map(lX+0,iy,iz)=0
+      		       map(lX+1,iy,iz)=0
         endif
         
 !           print*,ix,iy,iz
@@ -715,6 +747,59 @@
       END SUBROUTINE WRITEMRCMAP
 	
 	
+	      
+      SUBROUTINE WRITEMRCMAP2(stream,map,x,y,z,lx,ly,lz,sampling,err)
+      Use  mrc_image
+      REAL val,sampling
+      
+      integer x,y,z,err,stream,ix,iy,iz,lx,ly,lz
+      real map(0:x+1,0:y-1,0:z-1)
+
+      print*,'write_mrcimage2'         
+
+      print*,NX,NY,NZ  
+!     write file 
+
+      DMIN =  1.E10
+      DMAX = -1.E10
+      DOUBLMEAN = 0.0
+
+      DO 1450 IZ = 0,lZ-1
+      DO 1450 IY = 0,lY-1
+            
+	!    if (IY.gt.ly) cycle
+	 !   if (IZ.gt.lz) cycle
+            DO 1400 IX = 0,lx-1
+     
+                val = map(IX,IY,IZ)
+                ALINE(IX+1) = val
+                
+                DOUBLMEAN = DOUBLMEAN + val         
+                IF (val .LT. DMIN) DMIN = val
+                IF (val .GT. DMAX) DMAX = val
+
+1400         CONTINUE   
+
+      CALL IWRLIN(stream,ALINE)
+1450   CONTINUE
+      DMEAN = DOUBLMEAN/(NX*NY*NZ)
+
+      cell(1) = sampling *NX
+      cell(2) = sampling *NY
+      cell(3) = sampling *NZ
+      cell(4) = 90
+      cell(5) = 90
+      cell(6) = 90
+
+      CALL IALCEL(STREAM,CELL)  
+      CALL IWRHDR(stream,TITLE,-1,DMIN,DMAX,DMEAN)
+      CALL IMCLOSE(stream)
+      
+      return
+1999   STOP 'Error on file write2.'
+ 
+      END SUBROUTINE WRITEMRCMAP2
+	
 	
 	
 	SUBROUTINE rotobj(obj,therotobj,psi,theta,phi,nx,ny,nz,cx,cy,cz)
@@ -1043,12 +1128,15 @@
       if (nm.le.0) STOP 'Mistake, nm=0'
       
       err=0
-      lsum = sum(map(0:nxm1,0:nym1,0:nzm1))
-      mean=lsum/nm8
-
+  
 	map8=map
+
+       lsum = sum(map8(0:nxm1,0:nym1,0:nzm1))
+       mean=lsum/nm8
+
+
 	map8=map8*map8
-       sum_sqs=sum(map8(0:nxm1,0:nym1,0:nzm1))
+        sum_sqs=sum(map8(0:nxm1,0:nym1,0:nzm1))
  
  	 lsum=lsum*lsum
  	 sum_sqs=nm8*sum_sqs
@@ -1082,7 +1170,7 @@
 	
 	
 	
-	SUBROUTINE rotobjS(obj,therotobj,psi,theta,phi,nx,ny,nz,cx,cy,cz,iscale)
+	SUBROUTINE rotobjSL(obj,therotobj,psi,theta,phi,nx,ny,nz,cx,cy,cz,iscale,lx,ly,lz)
 	
 	
 	    
@@ -1095,7 +1183,7 @@
      
 	real obj(0:nx+1,0:ny-1,0:nz-1),therotobj(0:nx+1,0:ny-1,0:nz-1)
         real cx,cy,cz,psi,phi,theta,x,y,z,scx,scy,scz
-        integer nx,ny,nz,ix,iy,iz,nxm1,nym1,nzm1
+        integer nx,ny,nz,ix,iy,iz,nxm1,nym1,nzm1,lx,ly,lz
 	real rad,deg
         
         real mat(3,3),mata(3,3),matb(3,3),matc(3,3),matd(3,3)
@@ -1147,11 +1235,13 @@
         call matmult(mata,mat,matd)
 
 
+
 !	print*,matd
 
-	do iz=0,nzm1
-		do iy=0,nym1
-			do ix=0,nxm1
+
+	do iz=0,lz-1
+		do iy=0,ly-1
+			do ix=0,lx-1
 			
 				x=float(ix)*iscale
 				y=float(iy)*iscale
@@ -1173,7 +1263,7 @@
 	therotobj(nx:nx+1,0:ny-1,0:nz-1)=0
         return
 
-	END SUBROUTINE rotobjS
+	END SUBROUTINE rotobjSL
 
     real function radius(x,y,z,cx,cy,cz)
     integer x,y,z
@@ -1181,4 +1271,4 @@
     radius = sqrt (  (x-cx)**2 + (y-cy)**2 + (z-cz)**2  )
     end function radius
 
-	end program ShapeM
+	end program ShapeEM
