@@ -35,7 +35,7 @@ def start_jsrview(reportdir, ccp4, html='index.html', ostream=sys.stdout):
   jsrv_stdo = os.path.join(reportdir, 'stdout.txt')
   jsrv_stde = os.path.join(reportdir, 'stderr.txt')
   jsrv_html = os.path.join(reportdir, html)
-  print >>ostream, 'Qt browser:         ' + jsrview_exe
+  ostream.write('Qt browser:         ' + jsrview_exe + '\n')
   with open(jsrv_stdo, 'w') as stdo, open(jsrv_stde, 'w') as stde:
     SP.Popen((jsrview_exe, jsrv_html), cwd=reportdir, stdout=stdo, stderr=stde)
 
@@ -69,7 +69,7 @@ def main():
   logfile = os.path.join(testdir, 'output.log')
   xmlfile = os.path.join(testdir, 'output.xml')
 
-  print 'PyRVAPI Demo'
+  sys.stdout.write('PyRVAPI Demo\n')
   d = API.document.newdoc(
     wintitle='RVAPI Demo 1',
     xml=xmlfile,
