@@ -162,9 +162,9 @@ class arpwarp_log_parser(RT.LogDataParser):
         self.refinement.add_action(listener.refinement_step_finished)
         self.success.add_action(listener.cycle_finished, listener.job_finished)
 
-def arpwarp_parser(rvapi_grid, job_params=None, flush_pause=-1, resfile=None, **kwargs):
+def arpwarp_parser(rvapi_grid, job_params=None, pause=-1, resfile=None, **kwargs):
     parser = arpwarp_log_parser()
-    parser.add_listener(arpwarp_rvapi_calls(job_params, rvapi_grid, flush_pause, resfile))
+    parser.add_listener(arpwarp_rvapi_calls(job_params, rvapi_grid, pause, resfile))
     return parser
 
 def main():
