@@ -59,8 +59,20 @@ def main():
         action='store_true'
     )
     parser.add_argument(
-        '-p', '--pause',
-        help='pause in seconds after each recognised line and before any associaded action',
+        '-p', '--flush-pause',
+        help='''
+          pause in seconds before each call pyrvapi_ext.flush
+        ''',
+        default=0,
+        type=float,
+        metavar='<float>'
+    )
+    parser.add_argument(
+        '-a', '--action-pause',
+        help='''
+          pause in seconds after each regexp match
+          and before any associaded action
+        ''',
         default=0,
         type=float,
         metavar='<float>'
@@ -117,13 +129,14 @@ def main():
         show_progs = opt.split,
         hide_refs = opt.no_references,
         job_params = job_params,
-        pause = opt.pause,
+        pause = opt.flush_pause,
         summary = summary,
         graph_tables = not opt.hide_tables,
       ).parse_stream(
         istream,
         ostream = ostream,
         verbose = opt.verbose,
+        pause = opt.action_pause,
         patches = [fix_fsc_table, fix_stars],
       )
       API.flush()
