@@ -71,18 +71,19 @@ pre_list = ["redefine_functions.py",
             "parse_pisa_xml.py",
             "cns2coot.py",
             "clear_backup.py",
-            "tips.py",
+#            "tips.py",
             "3d_generator_import.py",
             "dictionary_generators.py",
             "jligand.py",
             "americanisms.py",
             "group_settings.py"]
 post_list = ["coot_gui.py",
-            "tips_gui.py",
+#            "tips_gui.py",
             "gui_hole.py",
             "gui_prosmart.py",
             "gui_add_linked_cho.py",
             "cho_restraints_from_models.py",
+            "add_linked_cho.py",
             "gui_contact_score_isolated_ligand.py",
             "jligand_gui.py",
             "get_recent_pdbe.py",
@@ -92,6 +93,7 @@ post_list = ["coot_gui.py",
             "ligand_check.py",
             "acedrg_link.py",
             "sharpen_blur.py",
+            "dynamic_atom_overlaps_and_other_outliers.py",
             "interactive_nudge_residues.py",
             "gui_ligand_sliders.py",
             "find_baddies.py",
@@ -171,6 +173,15 @@ def load_from_search_load_path(file):
     else:
         print "Error finding", file
 
+# coot_toolbar_button must exist if we are in non-graphics-mode because there isn't any
+# "non-graphics" protection in ~/.coot-preferences/coot_toolbuttons.py
+
+def coot_toolbar_button(button_label, cb_function, icon_name=False, tooltip=False, toggle_button=False, use_button=False):
+    pass
+
+def toggle_backrub_rotamers(widget=None):
+    pass
+
 
 for coot_python_file in python_list:
     filename = os.path.join(search_load_path, coot_python_file)
