@@ -40,6 +40,14 @@ if (use_gui_qm != 2):
         "Hydrogenate region",
         lambda func: hydrogenate_region(6))
 
+    add_simple_coot_menu_menuitem(
+        menu,
+        "Contact Dots for Ligand",
+        lambda func:
+        using_active_atom(coot_contact_dots_for_ligand,
+                          "aa_imol",
+                          ["aa_chain_id", "aa_res_no", "aa_ins_code"]))
+
     add_simple_coot_menu_menuitem(
           menu,
           "SMILES -> 2D",
@@ -85,10 +93,23 @@ if (use_gui_qm != 2):
 
         add_simple_coot_menu_menuitem(
             menu,
-            "Toggle Ligand Interactions",
+            "Toggle FLEV Ligand Interactions",
             lambda func: toggle_idle_ligand_interactions()
             )
 
+        def go_solid_func(state):
+            set_display_generic_objects_as_solid(state)
+            graphics_draw()
+
+        add_simple_coot_menu_menuitem(
+             menu, "Solid Generic Objects",
+             lambda func: go_solid_func(1))
+
+        add_simple_coot_menu_menuitem(
+             menu, "Unsolid Generic Objects",
+             lambda func: go_solid_func(0))
+
+
         def show_chem_func():
             set_display_generic_objects_as_solid(1) # there may be consequences...
             with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
@@ -131,7 +152,7 @@ if (use_gui_qm != 2):
     add_simple_coot_menu_menuitem(
          menu, "Unsolid Generic Objects",
          lambda func: go_solid_func(0))
-        
+
 
     def tab_ligand_distortions_func():
         with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
@@ -155,6 +176,12 @@ if (use_gui_qm != 2):
          "Display Ligand Distortions",
          lambda func: display_ligand_distortions_func())
 
+    add_simple_coot_menu_menuitem(
+        menu,
+        "Quick Ligand Validate",
+        lambda func: gui_ligand_check_dialog_active_residue())
+
+
 ##        # not interesting for the normal user!?
 ##        def density_ligand_score_func():
 ##            with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
@@ -189,7 +216,8 @@ if (use_gui_qm != 2):
 
 
     def probe_ligand_func():
-         with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
+        global probe_command
+        with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
                             aa_ins_code, aa_atom_name, aa_alt_conf]:
             ss = "//" + aa_chain_id + "/" + str(aa_res_no)
             imol_selection = new_molecule_by_atom_selection(aa_imol, ss)
