@@ -53,9 +53,27 @@ if (have_coot_python):
 
      menu = coot_menubar_menu("Validate")
      if menu:
+       add_simple_coot_menu_menuitem(menu, "Atom Overlaps (Coot)",
+                                     lambda func:
+                                     using_active_atom(
+                                       coot_all_atom_contact_dots,
+                                       "aa_imol"))
+       add_simple_coot_menu_menuitem(menu, "All-Atom Contact Dots (Molprobity)",
+                                     lambda func:
+                                     using_active_atom(probe, "aa_imol"))
+
+       add_simple_coot_menu_menuitem(menu,"Atom Overlaps Dialog",
+                                     lambda func:
+                                     using_active_atom(
+                                       molecule_atom_overlaps_gui, "aa_imol"))
+
        add_simple_coot_menu_menuitem(menu, "Highly coordinated waters...",
                                      lambda func: water_coordination_gui())
 
+       add_simple_coot_menu_menuitem(menu, "Pepflips from Difference Map...",
+                                     lambda func: pepflips_by_difference_map_gui())
+
+
        def validation_outliers_func():
          with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
                                     aa_ins_code, aa_atom_name, aa_alt_conf]:
@@ -69,85 +87,96 @@ if (have_coot_python):
 
        add_simple_coot_menu_menuitem(menu, "List Ramachandran outliers...",
                                      lambda func: rama_outlier_gui())
+       add_simple_coot_menu_menuitem(
+         menu,
+         "Read REFMAC logfile...",
+         lambda func: generic_chooser_and_file_selector("Read Refmac log file",
+                                     valid_model_molecule_qm, "Logfile name: ", "",
+                                     lambda imol, text: read_refmac_log(imol, text)))
 
 
      # --------------------------------------------------
      #           user_define_restraints plugin
      # --------------------------------------------------
 
-     def add_module_user_defined_restraints():
-       menu = coot_menubar_menu("Restraints")
-       load_from_search_load_path("user_define_restraints.py")
+     # def add_module_user_defined_restraints():
+     #   menu = coot_menubar_menu("Restraints")
+     #   load_from_search_load_path("user_define_restraints.py")
      
 
      
      # ---------------------------------------------
      #           extensions
+     #
+     # NOT ANY MORE, they are within everything else now...
      # ---------------------------------------------
 
-     menu = coot_menubar_menu("E_xtensions")
+     # show_extensions = False
+     # extensions_menu = coot_menubar_menu("E_xtensions")
+
+     # return the menuitem with menuitem_label in menubar_menu_label
+     # if not there return False
+     #
+     def get_coot_menu_from_item(menubar_menu_label, menuitem_label):
+       menu = coot_menubar_menu(menubar_menu_label)
+       for menu_child in menu.get_children():
+         if not isinstance(menu_child, gtk.SeparatorMenuItem):
+           label = menu_child.get_property('label') # changed
+           if label == menuitem_label:
+             # found it, return it
+             return menu_child
+       return False
+
+     # Add submenu to the existing menuitem, if not found make a new one
+     # under extensions
+     # return True on success or the newly created menuitem
+     #
+     def coot_menu_add_submenu(menubar_menu_label, menuitem_label, submenu):
+       # Now AttributeError: 'gtk.MenuItem' object has no attribute 'get_label'
+       # now we use get_property('label')
+       menuitem = get_coot_menu_from_item(menubar_menu_label, menuitem_label)
+       if menuitem:
+         menuitem.set_submenu(submenu)
+         return True
+       else:
+         return False
+         # add to extensions - not really working since I somehow cant
+         # remove/hide the Extensions Menu once it's created
+         # menuitem = gtk.MenuItem(menuitem_label)
+         # menuitem.set_submenu(submenu)
+         # extensions_menu.append(menuitem)
+         # menuitem.show()
+         # return menuitem
 
      # make submenus:
      submenu_all_molecule = gtk.Menu()
-     menuitem_2 = gtk.MenuItem("All Molecule...")
+     menuitem_2 = coot_menu_add_submenu("Calculate", "All Molecule...", submenu_all_molecule)
+     print("debug menuitem_2", menuitem_2)
+
      submenu_maps = gtk.Menu()
-     menuitem_3 = gtk.MenuItem("Maps...")
+     menuitem_3 = coot_menu_add_submenu("Calculate", "Map Tools...", submenu_maps)
+
      submenu_models = gtk.Menu()
-     menuitem_4 = gtk.MenuItem("Modelling...")
-     submenu_refine = gtk.Menu()
-     menuitem_5 = gtk.MenuItem("Refine...")
-     submenu_representation = gtk.Menu()
-     menuitem_6 = gtk.MenuItem("Representations")
-     submenu_settings = gtk.Menu()
-     menuitem_7 = gtk.MenuItem("Settings...")
+     menuitem_4 = coot_menu_add_submenu("Calculate", "Modelling...", submenu_models)
+
      submenu_pisa = gtk.Menu()
-     menuitem_pisa = gtk.MenuItem("PISA...")
-     submenu_pdbe = gtk.Menu()
-     menuitem_pdbe = gtk.MenuItem("PDBe...")
+     menuitem_pisa = coot_menu_add_submenu("Calculate", "PISA...", submenu_pisa)
+
      submenu_modules = gtk.Menu()
-     menuitem_modules = gtk.MenuItem("Modules...")
+     menuitem_modules = coot_menu_add_submenu("Calculate", "Modules...", submenu_modules)
+
      submenu_ncs = gtk.Menu()
-     menuitem_ncs = gtk.MenuItem("NCS...")
+     menuitem_ncs = coot_menu_add_submenu("Calculate", "NCS Tools...", submenu_ncs)
 
-     menuitem_2.set_submenu(submenu_all_molecule)
-     menu.append(menuitem_2)
-     menuitem_2.show()
-     
-     menuitem_3.set_submenu(submenu_maps)
-     menu.append(menuitem_3)
-     menuitem_3.show()
-     
-     menuitem_4.set_submenu(submenu_models)
-     menu.append(menuitem_4)
-     menuitem_4.show()
-     
-     menuitem_ncs.set_submenu(submenu_ncs)
-     menu.append(menuitem_ncs)
-     menuitem_ncs.show()
-     
-     menuitem_5.set_submenu(submenu_refine)
-     menu.append(menuitem_5)
-     menuitem_5.show()
-     
-     menuitem_6.set_submenu(submenu_representation)
-     menu.append(menuitem_6)
-     menuitem_6.show()
-     
-     menuitem_pisa.set_submenu(submenu_pisa)
-     menu.append(menuitem_pisa)
-     menuitem_pisa.show()
-     
-     menuitem_7.set_submenu(submenu_settings)
-     menu.append(menuitem_7)
-     menuitem_7.show()
+     submenu_representation = gtk.Menu()
+     menuitem_6 = coot_menu_add_submenu("Draw", "Representation Tools...", submenu_representation)
 
-     menuitem_modules.set_submenu(submenu_modules)
-     menu.append(menuitem_modules)
-     menuitem_modules.show()
+     submenu_settings = gtk.Menu()
+     menuitem_7 = coot_menu_add_submenu("Edit", "Settings...", submenu_settings)
 
-     menuitem_pdbe.set_submenu(submenu_pdbe)
-     menu.append(menuitem_pdbe)
-     menuitem_pdbe.show()
+     #menuitem_pdbe.set_submenu(submenu_pdbe)
+     #menu.append(menuitem_pdbe)
+     #menuitem_pdbe.show()
      
      
 
@@ -229,13 +258,12 @@ if (have_coot_python):
          global continue_multi_refine
          continue_multi_refine = True
          interruptible_fit_protein(imol, fit_protein_rama_fit_function)
-         
-     add_simple_coot_menu_menuitem(
+
+         add_simple_coot_menu_menuitem(
        submenu_all_molecule,
        "Refine/Improve Ramachandran Plot...",
        lambda func: molecule_chooser_gui("Refine Protein with Ramachanran Plot Optimization: ",
                 lambda imol: fit_protein_func3(imol)))
-                                         
 
      #---------------------------------------------------------------------
      #     Map functions
@@ -243,22 +271,22 @@ if (have_coot_python):
      #---------------------------------------------------------------------
 
      def mask_map_func():
-	f = ""
-	molecule_list = molecule_number_list()
-	if not molecule_list == []:
+       f = ""
+       molecule_list = molecule_number_list()
+       if not molecule_list == []:
           for i in molecule_list:
             if is_valid_map_molecule(molecule_list[i]):
-              print "%s is a valid map molecule" %molecule_list[i]
+              print( "%s is a valid map molecule" %molecule_list[i])
               f = str(molecule_list[i])
               break
-	else:
-		print "BL WARNING:: dunno what to do!? No map found"
-                f = False
-	return f
-      
+       else:
+         print( "BL WARNING:: dunno what to do!? No map found")
+         f = False
+       return f
+
      def mask_map_func1(active_state):
-	print "changed active_state to ", active_state
-        
+       print("changed active_state to ", active_state)
+
      def mask_map_func2(imol, texts_list, invert_mask_qm):
        # map imol
        text_1 = texts_list[0]
@@ -310,24 +338,24 @@ if (have_coot_python):
      add_simple_coot_menu_menuitem(
        submenu_maps,
        "Copy Map...",
-       lambda func: map_molecule_chooser_gui("Map to Copy...", 
+       lambda func: map_molecule_chooser_gui("Map to Copy...",
 		lambda imol: copy_molecule(imol)))
 
-     
+
      add_simple_coot_menu_menuitem(
        submenu_maps,
-       "Make a Smoother Copy...", 
-       lambda func: map_molecule_chooser_gui("Map Molecule to Smoothenize...", 
+       "Make a Smoother Copy...",
+       lambda func: map_molecule_chooser_gui("Map Molecule to Smoothenize...",
 		lambda imol: smooth_map(imol, 1.25)))
 
-     
+
      add_simple_coot_menu_menuitem(
        submenu_maps,
-       "Make a Very Smooth Copy...", 
-       lambda func: map_molecule_chooser_gui("Map Molecule to Smoothenize...", 
+       "Make a Very Smooth Copy...",
+       lambda func: map_molecule_chooser_gui("Map Molecule to Smoothenize...",
 		lambda imol: smooth_map(imol, 2.0)))
 
-     
+
      add_simple_coot_menu_menuitem(
        submenu_maps,
        "Make a Difference Map...",
@@ -393,7 +421,7 @@ if (have_coot_python):
 
      def set_diff_map_func(imol):
        print "setting map number %s to be a difference map" %imol
-       set_map_is_difference_map(imol)
+       set_map_is_difference_map(imol, 1)
         
      add_simple_coot_menu_menuitem(
        submenu_maps,
@@ -429,10 +457,10 @@ if (have_coot_python):
        with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
                                   aa_ins_code, aa_atom_name, aa_alt_conf]:
          add_hydrogens_using_refmac(aa_imol)
-     
+
      add_simple_coot_menu_menuitem(
        submenu_models,
-       "Add Hydrogens",
+       "Add Hydrogen Atoms",
        lambda func: add_hydrogens_with_coot_reduce())
 
 
@@ -496,6 +524,15 @@ if (have_coot_python):
 
      # --- D ---
 
+     add_simple_coot_menu_menuitem(
+       submenu_models, "Delete Hydrogen Atoms",
+       lambda func: using_active_atom(delete_hydrogens, "aa_imol"))
+
+     add_simple_coot_menu_menuitem(
+       submenu_models, "Delete Side-chains for Active Chain",
+       lambda func: using_active_atom(
+         delete_sidechains_for_chain, "aa_imol", "aa_chain_id"))
+
      # now in main menu
 ##     add_simple_coot_menu_menuitem(
 ##       submenu_models,
@@ -505,7 +542,7 @@ if (have_coot_python):
      
      # errr... move this...(??)
      submenu = gtk.Menu()
-     menuitem2 = gtk.MenuItem("Dock Sequence...")
+     menuitem2 = gtk.MenuItem("Assign Sequence...")
 
      menuitem2.set_submenu(submenu)
      menu.append(menuitem2)
@@ -513,9 +550,13 @@ if (have_coot_python):
      
      add_simple_coot_menu_menuitem(
        submenu,
-       "Dock Sequence...", 
-       lambda func: cootaneer_gui_bl())
+       "1: Associate Sequence to Chain...",
+       lambda func: associate_sequence_with_chain_gui()) # no alignment on OK press
 
+     add_simple_coot_menu_menuitem(
+       submenu,
+       "2: Assign Sequence...", 
+       lambda func: cootaneer_gui_bl())
 
      def associate_seq_func(imol, chain_id, pir_file):
        import os, re
@@ -560,11 +601,6 @@ if (have_coot_python):
      #                                            sequence_file_name)
      #  ))
      
-     add_simple_coot_menu_menuitem(
-       submenu,
-       "Associate Sequence to Chain...",
-       lambda func: associate_sequence_with_chain_gui()) # no alignment on OK press
-
 
      add_simple_coot_menu_menuitem(
        submenu_models,
@@ -615,6 +651,12 @@ if (have_coot_python):
        lambda func: generic_single_entry("Fetch PDBe Ligand Desciption for comp_id:",
                                          "", " Fetch ", lambda comp_id: get_pdbe_ligand_func(comp_id)))
 
+     def fpr():
+         with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no,
+                                    aa_ins_code, aa_atom_name, aa_alt_conf]:
+           fill_partial_residues(aa_imol)
+
+     add_simple_coot_menu_menuitem(submenu_models, "Fill Partial Residues", lambda m: fpr())
 
      add_simple_coot_menu_menuitem(
        submenu_models,
@@ -767,13 +809,13 @@ if (have_coot_python):
        lambda func: phosphorylate_active_residue())
 
 
-     # FIXME:: for now only when prodrg in path
-     if (command_in_path_qm("cprodrg")):
-       add_simple_coot_menu_menuitem(
-       submenu_models,
-       "Prodrg-ify this residue (generate restraints)",
-       lambda func: using_active_atom(prodrg_ify,
-                                      "aa_imol", "aa_chain_id", "aa_res_no", "aa_ins_code"))
+     # # FIXME:: for now only when prodrg in path
+     # if (command_in_path_qm("cprodrg")):
+     #   add_simple_coot_menu_menuitem(
+     #   submenu_models,
+     #   "Prodrg-ify this residue (generate restraints)",
+     #   lambda func: using_active_atom(prodrg_ify,
+     #                                  "aa_imol", "aa_chain_id", "aa_res_no", "aa_ins_code"))
      
 
      # ---- R ---------
@@ -1108,7 +1150,7 @@ if (have_coot_python):
      #
 
      add_simple_coot_menu_menuitem(
-       submenu_refine,
+       submenu_settings,
        "Set Refinement Options...",
        lambda func: refinement_options_gui())
  
@@ -1116,7 +1158,7 @@ if (have_coot_python):
      menuitem2 = gtk.MenuItem("Peptide Restraints...")
 
      menuitem2.set_submenu(submenu)
-     submenu_refine.append(menuitem2)
+     submenu_settings.append(menuitem2)
      menuitem2.show()
 
      def add_restr_func1():
@@ -1137,61 +1179,54 @@ if (have_coot_python):
        submenu, "Remove Planar Peptide Restraints",
        lambda func: add_restr_func2())
 
+     # Shelx has its own module, so should be there!?!?
+     # def shelx_ref_func():
+     #   window = gtk.Window(gtk.WINDOW_TOPLEVEL)
+     #   vbox = gtk.VBox(False, 0)
+     #   hbox = gtk.HBox(False, 0)
+     #   go_button = gtk.Button("  Refine  ")
+     #   cancel_button = gtk.Button("  Cancel  ")
+     #   entry_hint_text = "HKL data filename \n(leave blank for default)"
+     #   chooser_hint_text = " Choose molecule for SHELX refinement  "
+     #   h_sep = gtk.HSeparator()
 
-     def shelx_ref_func():
-       window = gtk.Window(gtk.WINDOW_TOPLEVEL)
-       vbox = gtk.VBox(False, 0)
-       hbox = gtk.HBox(False, 0)
-       go_button = gtk.Button("  Refine  ")
-       cancel_button = gtk.Button("  Cancel  ")
-       entry_hint_text = "HKL data filename \n(leave blank for default)"
-       chooser_hint_text = " Choose molecule for SHELX refinement  "
-       h_sep = gtk.HSeparator()
+     #   window.add(vbox)
+     #   option_menu_mol_list_pair = generic_molecule_chooser(vbox, chooser_hint_text)
+     #   entry = file_selector_entry(vbox, entry_hint_text)
 
-       window.add(vbox)
-       option_menu_mol_list_pair = generic_molecule_chooser(vbox, chooser_hint_text)
-       entry = file_selector_entry(vbox, entry_hint_text)
+     #   def shelx_delete_event(*args):
+     #     window.destroy()
+     #     return False
 
-       def shelx_delete_event(*args):
-         window.destroy()
-         return False
+     #   def shelx_go_funcn_event(*args):
+     #     import operator
+     #     txt = entry.get_text()
+     #     imol = get_option_menu_active_molecule(*option_menu_mol_list_pair)
+     #     if (operator.isNumberType(imol)):
+     #       if (len(txt) == 0):
+     #         shelxl_refine(imol)
+     #       else:
+     #         shelxl_refine(imol, txt)
+     #     window.destroy()
+     #     return False
 
-       def shelx_go_funcn_event(*args):
-         import operator
-         txt = entry.get_text()
-         imol = get_option_menu_active_molecule(*option_menu_mol_list_pair)
-         if (operator.isNumberType(imol)):
-           if (len(txt) == 0):
-             shelxl_refine(imol)
-           else:
-             shelxl_refine(imol, txt)
-         window.destroy()
-         return False
+     #   go_button.connect("clicked", shelx_go_funcn_event)
+     #   cancel_button.connect("clicked", shelx_delete_event)
 
-       go_button.connect("clicked", shelx_go_funcn_event)
-       cancel_button.connect("clicked", shelx_delete_event)
-
-       vbox.pack_start(h_sep, False, False, 2)
-       vbox.pack_start(hbox, False, False, 2)
-       hbox.pack_start(go_button, True, False, 0)
-       hbox.pack_start(cancel_button, True, False, 0)
-       window.show_all()
+     #   vbox.pack_start(h_sep, False, False, 2)
+     #   vbox.pack_start(hbox, False, False, 2)
+     #   hbox.pack_start(go_button, True, False, 0)
+     #   hbox.pack_start(cancel_button, True, False, 0)
+     #   window.show_all()
        
-     add_simple_coot_menu_menuitem(
-       submenu_refine,
-       "SHELXL Refine...", 
-       lambda func: shelx_ref_func())
+     # add_simple_coot_menu_menuitem(
+     #   submenu_refine,
+     #   "SHELXL Refine...",
+     #   lambda func: shelx_ref_func())
 
 
      add_simple_coot_menu_menuitem(
-       submenu_refine,
-       "Read REFMAC logfile...",
-       lambda func: generic_chooser_and_file_selector("Read Refmac log file",
-                       valid_model_molecule_qm, "Logfile name: ", "",
-                       lambda imol, text: read_refmac_log(imol, text)))
-                       
-     add_simple_coot_menu_menuitem(
-       submenu_refine,
+       submenu_settings,
        "Occupancy refinement input for REFMAC...",
        lambda func: generic_chooser_and_file_selector("Extra restraints file",
                        valid_model_molecule_qm, "Restraints file name: ",
@@ -1204,7 +1239,7 @@ if (have_coot_python):
      submenu = gtk.Menu()
      menuitem2 = gtk.MenuItem("Refinement Speed...")
      menuitem2.set_submenu(submenu)
-     submenu_refine.append(menuitem2)
+     submenu_settings.append(menuitem2)
      menuitem2.show()
 
      add_simple_coot_menu_menuitem(
@@ -1235,13 +1270,13 @@ if (have_coot_python):
 
 
      add_simple_coot_menu_menuitem(
-       submenu_refine,
+       submenu_settings,
        "Auto-weight refinement",
        lambda func: auto_weight_for_refinement())
      
 
      add_simple_coot_menu_menuitem(
-       submenu_refine,
+       submenu_settings,
        "Set Undo Molecule...",
        lambda func: molecule_chooser_gui("Set the Molecule for 'Undo' Operations",
                     lambda imol: set_undo_molecule(imol)))
@@ -1249,41 +1284,30 @@ if (have_coot_python):
 
      # BL says: has no checking for text = number yet
      add_simple_coot_menu_menuitem(
-       submenu_refine,
+       submenu_settings,
        "B factor bonds scale factor...",
        lambda func: generic_chooser_and_entry("Choose a molecule to which the B-factor colour scale is applied:",
 		"B-factor scale:", "1.0", 
 		lambda imol, text: set_b_factor_bonds_scale_factor(imol,float(text))))
 
 
-     def set_mat_func(text):
-	import operator
-	t = float(text)
-	if operator.isNumberType(t):
-		s = "Matrix set to " + text
-		set_matrix(t)
-		add_status_bar_text(s)
-	else:
-		add_status_bar_text("Failed to read a number")
-
-     add_simple_coot_menu_menuitem(
-       submenu_refine,
-       "Set Matrix (Refinement Weight)...",
-       lambda func: generic_single_entry("set matrix: (smaller means better geometry)", 
-		str(matrix_state()), "Set it", 
-		lambda text: set_mat_func(text)))
-
-
-     def set_den_gra_func(text):
-	import operator
-	t = float(text)
-	if operator.isNumberType(t):
-		s = "Density Fit scale factor set to " + text
-		set_residue_density_fit_scale_factor(t)
-		add_status_bar_text(s)
-	else:
-		add_status_bar_text("Failed to read a number")
+     # actually in refinement settings...
+     # def set_mat_func(text):
+     #    import operator
+     #    t = float(text)
+     #    if operator.isNumberType(t):
+     #    	s = "Matrix set to " + text
+     #    	set_matrix(t)
+     #    	add_status_bar_text(s)
+     #    else:
+     #    	add_status_bar_text("Failed to read a number")
 
+     # add_simple_coot_menu_menuitem(
+     #   submenu_refine,
+     #   "Set Matrix (Refinement Weight)...",
+     #   lambda func: generic_single_entry("set matrix: (smaller means better geometry)",
+     #    	str(matrix_state()), "Set it",
+     #    	lambda text: set_mat_func(text)))
 
 
 #      # ---------------------------------------------------------------------
@@ -1381,6 +1405,23 @@ if (have_coot_python):
          "Choose a molecule from which to clear Ball&Stick objects",
          lambda imol: clear_ball_and_stick(imol)))
 
+     def make_grey_atoms_func(state):
+       with UsingActiveAtom() as [aa_imol, aa_chain_id, aa_res_no, aa_ins_code,
+                                  aa_atom_name, aa_alt_conf]:
+         set_use_grey_carbons_for_molecule(aa_imol, state)       
+
+     add_simple_coot_menu_menuitem(
+       submenu_representation,
+       "Grey Carbons for Molecule",
+       lambda func: make_grey_atoms_func(1)
+)
+
+
+     add_simple_coot_menu_menuitem(
+       submenu_representation,
+       "Coloured Carbons for Molecule",
+       lambda func: make_grey_atoms_func(0))
+
 
      add_simple_coot_menu_menuitem(
        submenu_representation,
@@ -1669,30 +1710,38 @@ if (have_coot_python):
      # ---------------------------------------------------------------------
 
      add_simple_coot_menu_menuitem(
-       submenu_modules, "CCP4...",
+         submenu_modules, "Carbohydrate",
+         lambda func: add_module_carbohydrate_gui())
+
+     add_simple_coot_menu_menuitem(
+       submenu_modules, "CCP4",
        lambda func: add_module_ccp4())
 
      add_simple_coot_menu_menuitem(
-       submenu_modules, "SHELX...",
-       lambda func: add_module_shelx())
+         submenu_modules, "Cryo-EM",
+         lambda func: add_module_cryo_em()) # where are the jiggle-fit functions?
 
      add_simple_coot_menu_menuitem(
-       submenu_modules, "User-defined Restraints...",
-       lambda func: add_module_user_defined_restraints())
+       submenu_modules, "Restraints",
+       lambda func: add_module_restraints())
+
+     add_simple_coot_menu_menuitem(
+       submenu_modules, "Refine",
+       lambda func: add_module_refine()) # where is this now? Is it in curlew?
+
+     add_simple_coot_menu_menuitem(
+       submenu_modules, "PDBe",
+       lambda func: add_module_pdbe())
 
      add_simple_coot_menu_menuitem(
          submenu_modules, "ProSMART",
          lambda func: add_module_prosmart())
 
      add_simple_coot_menu_menuitem(
-         submenu_modules, "Carbohydrate",
-         lambda func: add_module_carbohydrate_gui())
-     
-     add_simple_coot_menu_menuitem(
-         submenu_modules, "Cryo-EM",
-         lambda func: add_module_cryo_em())
+       submenu_modules, "SHELX",
+       lambda func: add_module_shelx())
+
 
-     
      # ---------------------------------------------------------------------
      #     Settings
      # ---------------------------------------------------------------------
@@ -1714,6 +1763,16 @@ if (have_coot_python):
        lambda func: set_rotate_translate_zone_rotates_about_zone_centre(0))
 
 
+     def set_den_gra_func(text):
+	import operator
+	t = float(text)
+	if operator.isNumberType(t):
+		s = "Density Fit scale factor set to " + text
+		set_residue_density_fit_scale_factor(t)
+		add_status_bar_text(s)
+	else:
+		add_status_bar_text("Failed to read a number")
+
      add_simple_coot_menu_menuitem(
        submenu_settings,
        "Set Density Fit Graph Weight...",
@@ -1748,7 +1807,7 @@ if (have_coot_python):
 
 
      add_simple_coot_menu_menuitem(
-       submenu_refine, "Question Accept Refinement", 
+       submenu_settings, "Question Accept Refinement",
        lambda func: set_refinement_immediate_replacement(0))
 
 
