@@ -126,7 +126,7 @@ def dialog_box_of_buttons_with_async_ligands(window_name, geometry,
         for tlc in ligand_tlc_list:
             # image_url = "http://www.ebi.ac.uk/pdbe-srv/pdbechem/image/showNew?code=" + \
             #             tlc + "&size=" + str(image_size)
-            image_url = "http://www.ebi.ac.uk/pdbe/static/chem-files/" + \
+            image_url = "https://www.ebi.ac.uk/pdbe/static/chem-files/" + \
                         tlc + "-" + str(image_size) + ".gif"
             image_name = os.path.join(coot_pdbe_image_cache_dir,
                                       (tlc + "-" + str(image_size) + ".gif"))
@@ -138,7 +138,7 @@ def dialog_box_of_buttons_with_async_ligands(window_name, geometry,
         image_name_stub = "_deposited_chain_front_image-200x200.png"
         # image_url = "http://www.ebi.ac.uk/pdbe/entry-images/" + \
         #            image_name_stub
-        image_url = "http://www.ebi.ac.uk/pdbe/static/entry/" + \
+        image_url = "https://www.ebi.ac.uk/pdbe/static/entry/" + \
                     entry_id + image_name_stub
         
         entry_image_file_name = os.path.join(coot_pdbe_image_cache_dir,
@@ -228,7 +228,7 @@ def cache_or_net_get_image(image_url, image_name, hbox):
 
     def get_image(url, file_name):
         try:
-            file_name, url_info = urllib.urlretrieve(url, file_name)
+            file_name = coot_urlretrieve(url, file_name)
         except socket.timeout:
             print_thread("BL ERROR:: timout download", url[-50:])
         except:
@@ -247,7 +247,7 @@ def downloader_thread(thread_no):
             try:
                 url, file_name = coot_queue.get()
                 try:
-                    file_name, url_info = urllib.urlretrieve(url, file_name)
+                    file_name = coot_urlretrieve(url, file_name)
                 except socket.timeout:
                     print_thread("BL ERROR:: timout download", url[-50:])
                 except:
@@ -286,8 +286,25 @@ def refmac_calc_sfs_make_mtz_with_columns(pdb_in_file_name, mtz_file_name,
         refmac_extra_params.append("MAKE NEWLIGAND CONTINUE")
     else:
         refmac_extra_params = ["MAKE NEWLIGAND CONTINUE"]
-        
-    refmac_result = run_refmac_by_filename(pdb_in_file_name,
+
+    # this has now gone multi-threaded and that is not what Paule want.
+    # refmac_result = run_refmac_by_filename(pdb_in_file_name,
+    #                                        pdb_out_file_name,
+    #                                        mtz_file_name, mtz_out_file_name,
+    #                                        extra_cif_lib_filename,
+    #                                        imol_refmac_count,
+    #                                        swap_map_colours_post_refmac,
+    #                                        imol_mtz_molecule,
+    #                                        show_diff_map_flag,
+    #                                        phase_combine_flag,
+    #                                        phib_fom_pair,
+    #                                        force_n_cycles,
+    #                                        make_molecules_flag,
+    #                                        "", f_col, sigf_col, r_free_col)
+    # # ccp4i-project-dir, f-col, sig-f-col, r-free-col
+
+    # this function blocks until termination
+    refmac_result = run_refmac_by_filename_inner(pdb_in_file_name,
                                            pdb_out_file_name,
                                            mtz_file_name, mtz_out_file_name,
                                            extra_cif_lib_filename,
@@ -300,7 +317,6 @@ def refmac_calc_sfs_make_mtz_with_columns(pdb_in_file_name, mtz_file_name,
                                            force_n_cycles,
                                            make_molecules_flag,
                                            "", f_col, sigf_col, r_free_col)
-    # ccp4i-project-dir, f-col, sig-f-col, r-free-col
 
     # restore refmac-extra-params to what it used to be
     #
@@ -555,9 +571,9 @@ def pdbe_get_pdb_and_sfs_cif(include_get_sfs_flag,
 #                       entry_id + ".ent"
 #       sfs_cif_url = "http://www.ebi.ac.uk/pdbe-srv/view/files/r" + \
 #                       entry_id + "sf.ent"
-        pdb_url     = "http://www.ebi.ac.uk/pdbe/entry-files/pdb" + \
+        pdb_url     = "https://www.ebi.ac.uk/pdbe/entry-files/pdb" + \
                       entry_id + coords_type
-        sfs_cif_url = "http://www.ebi.ac.uk/pdbe/entry-files/r"   + entry_id + "sf.ent"
+        sfs_cif_url = "https://www.ebi.ac.uk/pdbe/entry-files/r"   + entry_id + "sf.ent"
         pdb_file_name = os.path.join("coot-download", entry_id + coords_type)
         sfs_cif_file_name = os.path.join("coot-download", "r" + entry_id + "sf.cif")
         sfs_mtz_file_name = os.path.join("coot-download", "r" + entry_id + "sf.mtz")
@@ -607,9 +623,9 @@ def pdbe_get_pdb_and_sfs_cif(include_get_sfs_flag,
             try:
                 #print "BL DEBUG:: start download", url
                 gobject.idle_add(sleeper)
-                file_name_local, url_info = urllib.urlretrieve(url, file_name,
-                                                               lambda nb, bs, fs, progress_bar=progress_bar:
-                                                               update_progressbar_in_download(nb, bs, fs, progress_bar))
+                file_name_local = coot_urlretrieve(url, file_name,
+                                                   lambda nb, bs, fs, progress_bar=progress_bar:
+                                                   update_progressbar_in_download(nb, bs, fs, progress_bar))
                 download_thread_status = "done-download"
             except socket.timeout:
                 print "BL ERROR:: timout download", url[-50:]
@@ -940,8 +956,8 @@ def pdbe_latest_releases_gui():
     import urllib
 
 
-    url = "http://www.ebi.ac.uk/pdbe/search/latest/select?facet=true&q=*%3A*&group=true&group.field=pdb_id&group.ngroups=true&&json.nl=map&fq=document_type%3Alatest_pdb&fq=entry_type:%28new%20OR%20revised%29&wt=json&fl=pdb_id,release_date,resolution,number_of_bound_molecules,experimental_method,citation_title,citation_doi,pubmed_author_list,journal,title,entry_type&rows=-1"
-    url = "http://www.ebi.ac.uk/pdbe/search/latest/select?facet=true&q=*%3A*&group=true&group.field=pdb_id&group.ngroups=true&&json.nl=map&fq=document_type%3Alatest_pdb&fq=entry_type:%28new%20OR%20revised%29&wt=json&fl=pdb_id,compound_id,release_date,resolution,number_of_bound_molecules,experimental_method,citation_title,citation_doi,pubmed_author_list,journal,title,entry_type&rows=-1"
+    url = "https://www.ebi.ac.uk/pdbe/search/latest/select?facet=true&q=*%3A*&group=true&group.field=pdb_id&group.ngroups=true&&json.nl=map&fq=document_type%3Alatest_pdb&fq=entry_type:%28new%20OR%20revised%29&wt=json&fl=pdb_id,release_date,resolution,number_of_bound_molecules,experimental_method,citation_title,citation_doi,pubmed_author_list,journal,title,entry_type&rows=-1"
+    url = "https://www.ebi.ac.uk/pdbe/search/latest/select?facet=true&q=*%3A*&group=true&group.field=pdb_id&group.ngroups=true&&json.nl=map&fq=document_type%3Alatest_pdb&fq=entry_type:%28new%20OR%20revised%29&wt=json&fl=pdb_id,compound_id,release_date,resolution,number_of_bound_molecules,experimental_method,citation_title,citation_doi,pubmed_author_list,journal,title,entry_type&rows=-1"
 
     # url = "http://www.ebi.ac.uk/pdbe-apps/jsonizer/latest/released/"
     json_file_name = "latest-releases.json"
@@ -982,7 +998,7 @@ def pdbe_latest_releases_gui():
             
         def run(self):
             try:
-                self.file_name, url_info = MyURLopener().retrieve(self.url, self.file_name, self.update_function)
+                self.file_name = coot_urlretrieve(self.url, self.file_name, self.update_function)
                 self.status = 0 #?
             except socket.timeout:
                 print "BL ERROR:: timout download", self.url
