@@ -588,6 +588,7 @@ class validation_entry_to_canvas:
     def on_drawing_area_expose(self, da, event):
 	style = da.get_style()
 	gc = style.fg_gc[gtk.STATE_NORMAL]
+	black_color = gtk.gdk.Color(red=0, green=0, blue=0)
 
 	n_sliders = self.draw_sliders(da, gc)
 	self.draw_top_labels(da, gc)
@@ -868,7 +869,7 @@ def sort_subgroups(subgroups):
 def pdb_validate(accession_code, imol):
 
     try:
-        if (len(accession_code) == 4):
+        if len(accession_code) == 4:
             middle_letters = accession_code[1] + accession_code[2]
             gz_file_name = "pdb-validation-" + accession_code + ".xml.gz"
             url = 'http://ftp.ebi.ac.uk/pub/databases/pdb/validation_reports/'
