@@ -21,7 +21,7 @@ import warnings
 import numpy as np
 
 from . import utils
-from .dtypes import HEADER_DTYPE, FEI_EXTENDED_HEADER_DTYPE
+from .dtypes import HEADER_DTYPE, FEI1_EXTENDED_HEADER_DTYPE, FEI2_EXTENDED_HEADER_DTYPE
 from .mrcobject import MrcObject
 from .constants import MAP_ID
 
@@ -197,19 +197,20 @@ class MrcInterpreter(MrcObject):
         # Use a recarray to allow access to fields as attributes
         # (e.g. header.mode instead of header['mode'])
         header = np.frombuffer(header_arr, dtype=HEADER_DTYPE).reshape(()).view(np.recarray)
-        
-        # Make header writeable, because fromstring() creates a read-only array
-        header.flags.writeable = True
-        
-        # Check this is an MRC file, and read machine stamp to get byte order
-        if header.map != MAP_ID:
+
+        # Check the map ID to make sure this is an MRC file. The full map ID
+        # should be 'MAP ', but we check only the first three bytes because
+        # this is the form specified in the MRC2014 paper and is used by some
+        # other software.
+        if bytes(header.map)[:3] != MAP_ID[:3]:
             msg = ("Map ID string not found - "
                    "not an MRC file, or file is corrupt")
             if self._permissive:
                 warnings.warn(msg, RuntimeWarning)
             else:
                 raise ValueError(msg)
-        
+
+        # Read the machine stamp to get the file's byte order
         try:
             byte_order = utils.byte_order_from_machine_stamp(header.machst)
         except ValueError as err:
@@ -253,7 +254,7 @@ class MrcInterpreter(MrcObject):
         extended_header attribute.
         
         If the extended header is recognised as FEI microscope metadata (by
-        'FEI1' in the header's ``exttyp`` field), its dtype is set
+        'FEI1' or 'FEI2' in the header's ``exttyp`` field), its dtype is set
         appropriately. Otherwise, the dtype is set as void (``'V1'``).
 
         Raises:
@@ -263,8 +264,8 @@ class MrcInterpreter(MrcObject):
 
         Warns:
             RuntimeWarning: If the header's ``exttyp`` field is set to 'FEI1'
-                but the extended header's size is not a multiple of the number
-                of bytes in the FEI metadata dtype.
+                or 'FEI2' but the extended header's size is not a multiple of
+                the number of bytes in the FEI metadata dtype.
             RuntimeWarning: If the stream is not long enough to contain the
                 extended header indicated by the header and ``permissive``
                 is :data:`True`.
@@ -285,7 +286,9 @@ class MrcInterpreter(MrcObject):
 
         try:
             if self.header.exttyp == b'FEI1':
-                self._extended_header.dtype = FEI_EXTENDED_HEADER_DTYPE
+                self._extended_header.dtype = FEI1_EXTENDED_HEADER_DTYPE
+            elif self.header.exttyp == b'FEI2':
+                self._extended_header.dtype = FEI2_EXTENDED_HEADER_DTYPE
         except ValueError:
             warnings.warn("File has exttyp '{}' but the extended header "
                           "cannot be interpreted as that type"
