@@ -17,11 +17,12 @@ from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
 from datetime import datetime
+import warnings
 
 import numpy as np
 
 from . import utils
-from .dtypes import HEADER_DTYPE, VOXEL_SIZE_DTYPE
+from .dtypes import HEADER_DTYPE, VOXEL_SIZE_DTYPE, NSTART_DTYPE
 from .constants import (MAP_ID, MRC_FORMAT_VERSION, IMAGE_STACK_SPACEGROUP,
                         VOLUME_SPACEGROUP, VOLUME_STACK_SPACEGROUP)
 
@@ -64,6 +65,7 @@ class MrcObject(object):
     * :attr:`extended_header`
     * :attr:`data`
     * :attr:`voxel_size`
+    * :attr:`nstart`
     
     Methods:
     
@@ -177,9 +179,10 @@ class MrcObject(object):
         
         If this :class:`MrcObject` was read from a file and the extended header
         type was recognised, its dtype will be set appropriately. (Currently
-        the only supported type is ``'FEI1'``.) Otherwise, the dtype will be
-        void (raw data, dtype ``'V'``). If the actual data type of the extended
-        header is known, the dtype of the array can be changed to match.
+        the only supported types are ``'FEI1'`` and ``'FEI2'``.) Otherwise, the
+        dtype will be void (raw data, dtype ``'V'``). If the actual data type
+        of the extended header is known, the dtype of the array can be changed
+        to match.
         
         The extended header may be modified in place. To replace it completely,
         call :meth:`set_extended_header`.
@@ -208,6 +211,9 @@ class MrcObject(object):
         and updates the header to match the new data dimensions. The data
         statistics (min, max, mean and rms) stored in the header will also be
         updated.
+
+        Warns:
+            RuntimeWarning: If the data array contains Inf or NaN values.
         """
         self._check_writeable()
         
@@ -241,11 +247,19 @@ class MrcObject(object):
     def voxel_size(self):
         """Get or set the voxel size in angstroms.
         
-        The voxel size is returned as a structured :class:`numpy record array
-        <numpy.recarray>` with three fields (x, y and z). Note that changing
-        the voxel_size array in-place will *not* change the voxel size in the
-        file -- to prevent this being overlooked accidentally, the writeable
-        on the voxel_size array.
+        The voxel size is returned as a structured NumPy :class:`record array
+        <numpy.recarray>` with three fields (x, y and z). For example:
+
+        >>> mrc.voxel_size
+        rec.array((0.44825, 0.3925, 0.45874998),
+          dtype=[('x', '<f4'), ('y', '<f4'), ('z', '<f4')])
+        >>> mrc.voxel_size.x
+        array(0.44825, dtype=float32)
+
+        Note that changing the voxel_size array in-place will *not* change the
+        voxel size in the file -- to prevent this being overlooked
+        accidentally, the writeable flag is set to :data:`False` on the
+        voxel_size array.
         
         To set the voxel size, assign a new value to the voxel_size attribute.
         You may give a single number, a 3-tuple ``(x, y ,z)`` or a modified
@@ -297,7 +311,84 @@ class MrcObject(object):
         self.header.cella.x = x_size * self.header.mx
         self.header.cella.y = y_size * self.header.my
         self.header.cella.z = z_size * self.header.mz
-    
+
+    @property
+    def nstart(self):
+        """Get or set the grid start locations.
+
+        This provides a convenient way to get and set the values of the
+        header's ``nxstart``, ``nystart`` and ``nzstart`` fields. Note that
+        these fields are integers and are measured in voxels, not angstroms.
+        The start locations are returned as a structured NumPy :class:`record
+        array <numpy.recarray>` with three fields (x, y and z). For example:
+
+        >>> mrc.header.nxstart
+        array(0, dtype=int32)
+        >>> mrc.header.nystart
+        array(-21, dtype=int32)
+        >>> mrc.header.nzstart
+        array(-12, dtype=int32)
+        >>> mrc.nstart
+        rec.array((0, -21, -12),
+          dtype=[('x', '<i4'), ('y', '<i4'), ('z', '<i4')])
+        >>> mrc.nstart.y
+        array(-21, dtype=int32)
+
+        Note that changing the nstart array in-place will *not* change the
+        values in the file -- to prevent this being overlooked accidentally,
+        the writeable flag is set to :data:`False` on the nstart array.
+
+        To set the start locations, assign a new value to the nstart
+        attribute. You may give a single number, a 3-tuple ``(x, y ,z)`` or a
+        modified version of the nstart array. The following examples are all
+        equivalent:
+
+        >>> mrc.nstart = -150
+
+        >>> mrc.nstart = (-150, -150, -150)
+
+        >>> starts = mrc.nstart
+        >>> starts.flags.writeable = True
+        >>> starts.x = -150
+        >>> starts.y = -150
+        >>> starts.z = -150
+        >>> mrc.nstart = starts
+        """
+        x = self.header.nxstart
+        y = self.header.nystart
+        z = self.header.nzstart
+        nstart = np.rec.array((x, y, z), NSTART_DTYPE)
+        nstart.flags.writeable = False
+        return nstart
+
+    @nstart.setter
+    def nstart(self, nstart):
+        self._check_writeable()
+        try:
+            # First, assume we have a single numeric value
+            starts = (int(nstart),) * 3
+        except TypeError:
+            try:
+                # Not a single value. Next, if nstart is an array (as
+                # produced by the nstart getter), item() gives a 3-tuple
+                starts = nstart.item()
+            except AttributeError:
+                # If the item() method doesn't exist, assume we have a 3-tuple
+                starts = nstart
+        self._set_nstart(*starts)
+
+    def _set_nstart(self, nxstart, nystart, nzstart):
+        """Set the grid start locations.
+
+        Args:
+            nxstart: The location of the first column in the unit cell
+            nystart: The location of the first row in the unit cell
+            nzstart: The location of the first section in the unit cell
+        """
+        self.header.nxstart = nxstart
+        self.header.nystart = nystart
+        self.header.nzstart = nzstart
+
     def is_single_image(self):
         """Identify whether the file represents a single image.
         
@@ -440,12 +531,23 @@ class MrcObject(object):
         
         Note that this can take some time with large files, particularly with
         files larger than the currently available memory.
+
+        Warns:
+            RuntimeWarning: If the data array contains Inf or NaN values.
         """
         self._check_writeable()
 
         if self.data.size > 0:
-            self.header.dmin = self.data.min()
-            self.header.dmax = self.data.max()
+            min = self.data.min()
+            max = self.data.max()
+
+            if np.isnan(min):
+                warnings.warn("Data array contains NaN values", RuntimeWarning)
+            if np.isinf(min) or np.isinf(max):
+                warnings.warn("Data array contains infinite values", RuntimeWarning)
+
+            self.header.dmin = min
+            self.header.dmax = max
 
             # Use a float64 accumulator to calculate mean and standard deviation
             # This prevents overflow errors during calculation
@@ -599,7 +701,7 @@ class MrcObject(object):
             valid = False
         
         # Check extended header type is set to a known value
-        valid_exttypes = [b'CCP4', b'MRCO', b'SERI', b'AGAR', b'FEI1']
+        valid_exttypes = [b'CCP4', b'MRCO', b'SERI', b'AGAR', b'FEI1', b'FEI2']
         if self.header.nsymbt > 0 and self.header.exttyp not in valid_exttypes:
             log("Extended header type is undefined or unrecognised: exttyp = "
                 "'{0}'".format(self.header.exttyp.item().decode('ascii')))
