@@ -47,6 +47,13 @@
 ;; set the prompt to be coot, not guile.
 (set-repl-prompt! "coot> ")
 
+;; 20210915-PE coot tips have been removed from the list in load-all-scheme
+;; but Clemens suggest that there may be users who have (no-coot-tips) in
+;; their ~/.coot script. Give it an empty function.
+;; 
+(define (no-coot-tips) 'null)
+
+
 ;; Note the position of coot-gui is important.  It seem that if there
 ;; are too many files in front of it (even blank ones!) coot barfs
 ;; when it gets to coot-gui.scm.
@@ -81,7 +88,7 @@
 			   "parse-pisa-xml.scm"
 			   "cns2coot.scm"
 			   "clear-backup.scm"
-			   "tips.scm"
+			   ;; "tips.scm"
 			   "3d-generator-import.scm"
 			   "dictionary-generators.scm"
 			   "cho-restraints-from-models.scm"
@@ -93,7 +100,7 @@
       (let ((scheme-list 
 	     (cond 
 	      ((eq? #t use-gui?) 
-	       (append pre-list (list "coot-gui.scm") post-list (list "tips-gui.scm"
+	       (append pre-list (list "coot-gui.scm") post-list (list ;; "tips-gui.scm"
 								      ;; "check-for-updates.scm"
 								      "gui-hole.scm"
 								      "gui-prosmart.scm"
@@ -106,6 +113,7 @@
 								      "ligand-check.scm"
 								      "acedrg-link.scm"
 								      "sharpen-blur.scm"
+                                                                      "dynamic-atom-overlaps-and-other-outliers.scm"
 								      "interactive-nudge-residues.scm"
 								      "gui-ligand-sliders.scm"
 								      "find-baddies.scm"
