@@ -46,21 +46,31 @@
 
 
 (if (defined? 'coot-main-menubar)
-    ;; --------------------------------------------------
-    ;;           coordinated water validation dialog
-    ;; --------------------------------------------------
     (let ((menu (coot-menubar-menu "Validate")))
+
+      (add-simple-coot-menu-menuitem
+       menu "Atom Overlaps (Coot)"
+       (lambda ()
+         (using-active-atom
+          (coot-all-atom-contact-dots aa-imol))))
+
+      (add-simple-coot-menu-menuitem
+       menu "All-Atom Contact Dots (Molprobity)"
+       (lambda ()
+         (using-active-atom
+          (probe  aa-imol))))
+
+      (add-simple-coot-menu-menuitem
+       menu "Atom Overlaps Dialog"
+       (lambda ()
+         (using-active-atom
+          (molecule-atom-overlaps-gui aa-imol))))
+
       (add-simple-coot-menu-menuitem 
        menu "Highly coordinated waters..."
        (lambda ()
 	 (water-coordination-gui)))
 
-      (add-simple-coot-menu-menuitem
-       menu "Atom Overlaps"
-       (lambda ()
-         (using-active-atom
-          (molecule-atom-overlaps-gui aa-imol))))
-
       (add-simple-coot-menu-menuitem
        menu "Pepflips from Difference Map..."
        (lambda ()
@@ -147,25 +157,25 @@
 	;; (gtk-menu-append menu menuitem-modules)
 	;; (gtk-widget-show menuitem-modules)
 
-	(let ((get-coot-menu-from-item
-	       (lambda (top-label sub-menu-label)
-		 (let ((top-menu (coot-menubar-menu top-label)))
-		   (if top-menu
-		       (let ((menu-bar-label-list
-			      (map
-			       (lambda (menu-child)
-				 (let* ((ac-lab-ls (gtk-container-children menu-child))
-					;; ac-lab-ls is a GtkAccelLabel in a list
-					;; (nov (format #t "##### ac-lab-ls: ~s~%" ac-lab-ls))
-					(ac-lab (if (null? ac-lab-ls) ;; e.g. a separator
-						    #f
-						    (car ac-lab-ls)))
-					;; ac-lab is a simple GtkAccelLabel
-					(label-text (if (not ac-lab)
-							"" ;; a non-matching/fake string
-							(gtk-label-get ac-lab))))
-				   (list menu-child label-text (gtk-menu-item-submenu menu-child))))
-			       (gtk-container-children top-menu))))
+        (let ((get-coot-menu-from-item
+               (lambda (top-label sub-menu-label)
+                 (let ((top-menu (coot-menubar-menu top-label)))
+                   (if top-menu
+                       (let ((menu-bar-label-list
+                              (map
+                               (lambda (menu-child)
+                                 (let* ((ac-lab-ls (gtk-container-children menu-child))
+                                        ;; ac-lab-ls is a GtkAccelLabel in a list
+                                        ;; (nov (format #t "##### ac-lab-ls: ~s~%" ac-lab-ls))
+                                        (ac-lab (if (null? ac-lab-ls) ;; e.g. a separator
+                                                    #f
+                                                    (car ac-lab-ls)))
+                                        ;; ac-lab is a simple GtkAccelLabel
+                                        (label-text (if (not ac-lab)
+                                                        "" ;; a non-matching/fake string
+                                                        (gtk-label-get ac-lab))))
+                                   (list menu-child label-text (gtk-menu-item-submenu menu-child))))
+                               (gtk-container-children top-menu))))
 
 			 (let f ((ls menu-bar-label-list))
 			   (cond
@@ -465,7 +475,7 @@
 				     (lambda (imol)
 				       (format #t "setting map number ~s to be a difference map~%"
 					       imol)
-				       (set-map-is-difference-map imol)))))
+				       (set-map-is-difference-map imol 1)))))
 
 
 	(add-simple-coot-menu-menuitem
@@ -490,7 +500,7 @@
 	;; ---------------------------------------------------------------------
 
 	(add-simple-coot-menu-menuitem
-	 submenu-models "Add Hydrogens"
+	 submenu-models "Add Hydrogen Atoms"
 	 (lambda ()
 	   (using-active-atom
 	    (coot-reduce aa-imol))))
@@ -524,7 +534,13 @@
 	 (lambda() 
 	   (molecule-chooser-gui "Assign HETATMs as per PDB definition"
 				 (lambda (imol)
-					  (assign-hetatms imol)))))
+                                   (assign-hetatms imol)))))
+
+        (add-simple-coot-menu-menuitem
+         submenu-models "Backrub Rotamers for Whole Chain"
+         (lambda ()
+           (using-active-atom
+            (backrub-rotamers-for-chain aa-imol aa-chain-id))))
 
 	(add-simple-coot-menu-menuitem
 	 submenu-models "Copy Coordinates Molecule...."
@@ -551,6 +567,12 @@
 
 	;; --- D ---
 
+	(add-simple-coot-menu-menuitem
+	 submenu-models "Delete Hydrogen Atoms"
+	 (lambda ()
+	   (using-active-atom
+	    (delete-hydrogens aa-imol))))
+
 	(add-simple-coot-menu-menuitem
 	 submenu-models "Delete Side-chains for Active Chain"
 	 (lambda ()
@@ -561,28 +583,28 @@
 
 	;; errr... move this...
 	(let ((submenu (gtk-menu-new))
-	      (menuitem2 (gtk-menu-item-new-with-label "Dock Sequence...")))
+	      (menuitem2 (gtk-menu-item-new-with-label "Assign Sequence...")))
 
 	  (gtk-menu-item-set-submenu menuitem2 submenu)
 	  (gtk-menu-append (coot-menubar-menu "Calculate") menuitem2)
 	  (gtk-widget-show menuitem2)
 	  
+	  (add-simple-coot-menu-menuitem
+	   submenu "1: Associate Sequence File...."
+	   (lambda ()
+	     (associate-sequence-file-with-molecule-gui)))
+
 	  ;; 
 	  (if (coot-has-pygtk?)
 	      (add-simple-coot-menu-menuitem
-	       submenu "Dock Sequence (py)..."
+	       submenu "2: Assign Sequence (py)..."
 	       (lambda ()
 		 (run-python-command "cootaneer_gui_bl()"))))
 	  
-	  (add-simple-coot-menu-menuitem
-	   submenu "Associate Sequence...."
-	   (lambda ()
-	     (associate-pir-with-molecule-gui #f))) ;; don't do alignement gui on OK press
-
 	  ;; only add this to the GUI if the python version is not available.
 	  (if (not (coot-has-pygtk?))
 	      (add-simple-coot-menu-menuitem
-	       submenu "Dock sequence on this fragment..."
+	       submenu "Assign the sequence to this fragment..."
 	       (lambda ()
 		 (molecule-chooser-gui "Choose a molecule to apply sequence assignment"
 				       (lambda (imol)
@@ -613,6 +635,12 @@
 				      (let ((status (get-SMILES-for-comp-id-from-pdbe comp-id)))
 					(get-monomer comp-id))))))
 
+          (add-simple-coot-menu-menuitem
+           submenu-models "Fill Partial Residues"
+           (lambda()
+             (using-active-atom
+              (fill-partial-residues aa-imol))))
+
 	  (add-simple-coot-menu-menuitem
 	   submenu "Find Helices"
 	   (lambda ()
@@ -623,7 +651,6 @@
 	   (lambda ()
 	     (find-strands))))
 
-
 	(add-simple-coot-menu-menuitem
 	 submenu-models "Fix Nomenclature Errors..."
 	 (lambda () 
@@ -759,12 +786,11 @@
 	 (lambda ()
 	   (phosphorylate-active-residue)))
 	
-	(add-simple-coot-menu-menuitem
-	 submenu-models "Prodrg-ify this residue (generate restraints)"
-	 (lambda ()
-	   (using-active-atom 
-	    (prodrg-ify aa-imol aa-chain-id aa-res-no aa-ins-code))))
-
+	;; (add-simple-coot-menu-menuitem
+        ;; submenu-models "Prodrg-ify this residue (generate restraints)"
+        ;; (lambda ()
+        ;;(using-active-atom
+        ;; (prodrg-ify aa-imol aa-chain-id aa-res-no aa-ins-code))))
 
 	;; ---- R ---------
 
@@ -1533,6 +1559,11 @@
 	 (lambda ()
 	   (add-module-cryo-em)))
 
+	(add-simple-coot-menu-menuitem
+	 submenu-modules "Refine"
+	 (lambda ()
+	   (add-module-refine)))
+
 	(add-simple-coot-menu-menuitem
 	 submenu-modules "Restraints"
 	 (lambda ()
